"""
Question
--------
How do the core metabolisms of Alphaproteobacteria and Betaproteobacteria compare?
Which neofunctionalised enzymes cause the core metabolism of Alphaproteobacteria or Betaproteobacteria to have increased redundancy? How much do they contribute?

Method
------
- get clades
- get core metabolisms
- calculate "neofunctionalised" ECs
- calculate redundancies
- REPEAT for each clade
-     print size of each core metabolism and "neofunctionalised" ECs, including their contribution to redundancy
-     print enzyme pairs of neofunctionalisations, which caused the EC to be considered "neofunctionalised", and are in return contributing to redundancy

Result
------

::
    
    core metabolism majority: 80%
    neofunctionalisation majority: 0% (this means that gene duplication within a single organism is enough)
    type of redundancy: ROBUSTNESS
    
    Alphaproteobacteria:
    
    core metabolism ECs: 215
    
    "neofunctionalised" ECs: 46 (21%)
    1.1.1.100
    1.1.1.42
    1.1.1.85
    1.17.7.4
    1.2.1.41
    1.2.4.1
    1.8.1.4
    1.8.1.7
    2.1.2.2
    2.1.3.2
    2.1.3.3
    2.2.1.1
    2.2.1.7
    2.3.1.12
    2.3.1.39
    2.3.1.61
    2.4.2.14
    2.5.1.90
    2.6.1.1
    2.6.1.16
    2.6.1.9
    2.7.4.9
    3.1.3.25
    3.1.3.7
    4.1.1.17
    4.1.1.20
    4.1.3.-
    4.1.3.27
    4.3.2.1
    4.3.2.2
    4.4.1.8
    5.3.1.16
    6.1.1.12
    6.1.1.15
    6.1.1.3
    6.1.1.4
    6.1.1.5
    6.1.1.6
    6.1.1.9
    6.2.1.1
    6.3.2.10
    6.3.2.13
    6.3.2.8
    6.3.2.9
    6.3.4.18
    6.3.5.5
    
    "neofunctionalised" ECs contributing to redundancy: 5 ( 2%)
    1.2.4.1 => [1.1.1.40]
    2.1.3.3 => [2.1.3.2]
    2.2.1.1 => [5.1.3.1, 5.3.1.6]
    2.6.1.1 => [2.1.3.2]
    4.1.3.- => [2.4.2.-]
    
    Neofunctionalisations contributing to redundancy: 828 (22%)
    (aace:A0U92_07025 [1.2.4.1],    aace:A0U92_07030 [2.3.1.12])    => [1.1.1.40]
    (aak:AA2016_3788 [1.2.4.1],     aak:AA2016_3787 [2.3.1.12])     => [1.1.1.40]
    (aay:WYH_00471 [1.2.4.1],       aay:WYH_00533 [2.3.1.12])       => [1.1.1.40]
    (abg:Asbog_01243 [1.2.4.1],     abg:Asbog_01244 [2.3.1.12])     => [1.1.1.40]
    (acr:Acry_2820 [1.2.4.1],       acr:Acry_2821 [2.3.1.12])       => [1.1.1.40]
    (ado:A6F68_02189 [1.2.4.1],     ado:A6F68_02343 [2.3.1.12])     => [1.1.1.40]
    (aep:AMC99_01209 [1.2.4.1],     aep:AMC99_01171 [2.3.1.12])     => [1.1.1.40]
    (aex:Astex_2920 [1.2.4.1],      aex:Astex_2919 [2.3.1.12])      => [1.1.1.40]
    (agc:BSY240_693 [1.2.4.1],      agc:BSY240_692 [2.3.1.12])      => [1.1.1.40]
    (agr:AGROH133_05921 [1.2.4.1],  agr:AGROH133_05922 [2.3.1.12])  => [1.1.1.40]
    (aht:ANTHELSMS3_03039 [1.2.4.1],aht:ANTHELSMS3_03037 [2.3.1.12])=> [1.1.1.40]
    (ahu:A6A40_05280 [1.2.4.1],     ahu:A6A40_05275 [2.3.1.12])     => [1.1.1.40]
    (amv:ACMV_31580 [1.2.4.1],      amv:ACMV_31590 [2.3.1.12])      => [1.1.1.40]
    (amx:AM2010_985 [1.2.4.1],      amx:AM2010_922 [2.3.1.12])      => [1.1.1.40]
    (anh:A6F65_01749 [1.2.4.1],     anh:A6F65_01679 [2.3.1.12])     => [1.1.1.40]
    (aol:S58_35510 [1.2.4.1],       aol:S58_35530 [2.3.1.12])       => [1.1.1.40]
    (apb:SAR116_0206 [1.2.4.1],     apb:SAR116_0207 [2.3.1.12])     => [1.1.1.40]
    (aper:A0U91_02040 [1.2.4.1],    aper:A0U91_02045 [2.3.1.12])    => [1.1.1.40]
    (apm:HIMB5_00012850 [1.2.4.1],  apm:HIMB5_00012840 [2.3.1.12])  => [1.1.1.40]
    (apom:CPF11_01350 [1.2.4.1],    apom:CPF11_01355 [2.3.1.12])    => [1.1.1.40]
    (apt:APA01_12170 [1.2.4.1],     apt:APA01_12160 [2.3.1.12])     => [1.1.1.40]
    (ara:Arad_2247 [1.2.4.1],       ara:Arad_2249 [2.3.1.12])       => [1.1.1.40]
    (aro:B0909_06395 [1.2.4.1],     aro:B0909_06390 [2.3.1.12])     => [1.1.1.40]
    (asv:WG31_06600 [1.2.4.1],      asv:WG31_06595 [2.3.1.12])      => [1.1.1.40]
    (asz:ASN_3632 [1.2.4.1],        asz:ASN_3633 [2.3.1.12])        => [1.1.1.40]
    (ati:AL072_12260 [1.2.4.1],     ati:AL072_12255 [2.3.1.12])     => [1.1.1.40]
    (ato:CIW82_12980 [1.2.4.1],     ato:CIW82_12975 [2.3.1.12])     => [1.1.1.40]
    (aua:M673_11260 [1.2.4.1],      aua:M673_11265 [2.3.1.12])      => [1.1.1.40]
    (avi:Avi_2114 [1.2.4.1],        avi:Avi_2115 [2.3.1.12])        => [1.1.1.40]
    (azc:AZC_1743 [1.2.4.1],        azc:AZC_1744 [2.3.1.12])        => [1.1.1.40]
    (azl:AZL_015200 [1.2.4.1],      azl:AZL_015190 [2.3.1.12])      => [1.1.1.40]
    (banc:PU02_1123 [1.2.4.1],      banc:PU02_1122 [2.3.1.12])      => [1.1.1.40]
    (bapi:BBC0122_009290 [1.2.4.1], bapi:BBC0122_009300 [2.3.1.12]) => [1.1.1.40]
    (bara:BA1379B_006780 [1.2.4.1], bara:BA1379B_006770 [2.3.1.12]) => [1.1.1.40]
    (barr:Bra60_007650 [1.2.4.1],   barr:Bra60_007640 [2.3.1.12])   => [1.1.1.40]
    (bart:BJB15x_004370 [1.2.4.1],  bart:BJB15x_004380 [2.3.1.12])  => [1.1.1.40]
    (barw:BWD162_003840 [1.2.4.1],  barw:BWD162_003850 [2.3.1.12])  => [1.1.1.40]
    (baus:BAnh1_05010 [1.2.4.1],    baus:BAnh1_05020 [2.3.1.12])    => [1.1.1.40]
    (bbk:BARBAKC583_0535 [1.2.4.1], bbk:BARBAKC583_0536 [2.3.1.12]) => [1.1.1.40]
    (bbt:BBta_4462 [1.2.4.1],       bbt:BBta_4460 [2.3.1.12])       => [1.1.1.40]
    (bcd:BARCL_0594 [1.2.4.1],      bcd:BARCL_0595 [2.3.1.12])      => [1.1.1.40]
    (bcet:V910_100859 [1.2.4.1],    bcet:V910_100860 [2.3.1.12])    => [1.1.1.40]
    (bcet:V910_100859 [1.2.4.1],    bcet:V910_200058 [2.3.1.12])    => [1.1.1.40]
    (bcs:BCAN_A1147 [1.2.4.1],      bcs:BCAN_A1146 [2.3.1.12])      => [1.1.1.40]
    (bcs:BCAN_A1147 [1.2.4.1],      bcs:BCAN_B0035 [2.3.1.12])      => [1.1.1.40]
    (bgr:Bgr_06590 [1.2.4.1],       bgr:Bgr_06600 [2.3.1.12])       => [1.1.1.40]
    (bhe:BH05760 [1.2.4.1],         bhe:BH05770 [2.3.1.12])         => [1.1.1.40]
    (bic:LMTR13_19285 [1.2.4.1],    bic:LMTR13_19295 [2.3.1.12])    => [1.1.1.40]
    (bid:Bind_1506 [1.2.4.1],       bid:Bind_1507 [2.3.1.12])       => [1.1.1.40]
    (bja:bll4782 [1.2.4.1],         bja:bll4779 [2.3.1.12])         => [1.1.1.40]
    (bju:BJ6T_49290 [1.2.4.1],      bju:BJ6T_49320 [2.3.1.12])      => [1.1.1.40]
    (blas:BSY18_579 [1.2.4.1],      blas:BSY18_1020 [2.3.1.12])     => [1.1.1.40]
    (bme:BMEI0855 [1.2.4.1],        bme:BMEI0856 [2.3.1.12])        => [1.1.1.40]
    (bme:BMEI0855 [1.2.4.1],        bme:BMEII0060 [2.3.1.12])       => [1.1.1.40]
    (bmf:BAB1_1151 [1.2.4.1],       bmf:BAB1_1150 [2.3.1.12])       => [1.1.1.40]
    (bmf:BAB1_1151 [1.2.4.1],       bmf:BAB2_0032 [2.3.1.12])       => [1.1.1.40]
    (bmr:BMI_I1140 [1.2.4.1],       bmr:BMI_II33 [2.3.1.12])        => [1.1.1.40]
    (bms:BR1128 [1.2.4.1],          bms:BR1127 [2.3.1.12])          => [1.1.1.40]
    (bms:BR1128 [1.2.4.1],          bms:BRA0033 [2.3.1.12])         => [1.1.1.40]
    (bne:DA69_05795 [1.2.4.1],      bne:DA69_05785 [2.3.1.12])      => [1.1.1.40]
    (bop:AXW83_07560 [1.2.4.1],     bop:AXW83_07555 [2.3.1.12])     => [1.1.1.40]
    (bos:BSY19_2691 [1.2.4.1],      bos:BSY19_2692 [2.3.1.12])      => [1.1.1.40]
    (bov:BOV_1086 [1.2.4.1],        bov:BOV_1085 [2.3.1.12])        => [1.1.1.40]
    (bpp:BPI_I1175 [1.2.4.1],       bpp:BPI_I1174 [2.3.1.12])       => [1.1.1.40]
    (bpp:BPI_I1175 [1.2.4.1],       bpp:BPI_II33 [2.3.1.12])        => [1.1.1.40]
    (bqu:BQ04920 [1.2.4.1],         bqu:BQ04930 [2.3.1.12])         => [1.1.1.40]
    (bra:BRADO4086 [1.2.4.1],       bra:BRADO4084 [2.3.1.12])       => [1.1.1.40]
    (brad:BF49_6759 [1.2.4.1],      brad:BF49_6762 [2.3.1.12])      => [1.1.1.40]
    (brc:BCCGELA001_20310 [1.2.4.1],brc:BCCGELA001_20295 [2.3.1.12])=> [1.1.1.40]
    (brd:JL11_12170 [1.2.4.1],      brd:JL11_12165 [2.3.1.12])      => [1.1.1.40]
    (brg:A4249_04935 [1.2.4.1],     brg:A4249_04945 [2.3.1.12])     => [1.1.1.40]
    (brk:CWS35_25570 [1.2.4.1],     brk:CWS35_25560 [2.3.1.12])     => [1.1.1.40]
    (brl:BZG35_09905 [1.2.4.1],     brl:BZG35_09895 [2.3.1.12])     => [1.1.1.40]
    (bro:BRAD285_3292 [1.2.4.1],    bro:BRAD285_3294 [2.3.1.12])    => [1.1.1.40]
    (brs:S23_33850 [1.2.4.1],       brs:S23_33880 [2.3.1.12])       => [1.1.1.40]
    (bsb:Bresu_1984 [1.2.4.1],      bsb:Bresu_1985 [2.3.1.12])      => [1.1.1.40]
    (btr:BT_0862 [1.2.4.1],         btr:BT_0863 [2.3.1.12])         => [1.1.1.40]
    (bvc:CEP68_16215 [1.2.4.1],     bvc:CEP68_16220 [2.3.1.12])     => [1.1.1.40]
    (bvl:BF3285c1_1939 [1.2.4.1],   bvl:BF3285c1_1938 [2.3.1.12])   => [1.1.1.40]
    (bvl:BF3285c1_1939 [1.2.4.1],   bvl:BF3285c2_0762 [2.3.1.12])   => [1.1.1.40]
    (bvn:BVwin_05150 [1.2.4.1],     bvn:BVwin_05160 [2.3.1.12])     => [1.1.1.40]
    (bvr:BVIR_1927 [1.2.4.1],       bvr:BVIR_1926 [2.3.1.12])       => [1.1.1.40]
    (bvv:BHK69_19470 [1.2.4.1],     bvv:BHK69_19475 [2.3.1.12])     => [1.1.1.40]
    (cak:Caul_2759 [1.2.4.1],       cak:Caul_2757 [2.3.1.12])       => [1.1.1.40]
    (cbot:ATE48_00565 [1.2.4.1],    cbot:ATE48_00550 [2.3.1.12])    => [1.1.1.40]
    (ccr:CC_1727 [1.2.4.1],         ccr:CC_1729 [2.3.1.12])         => [1.1.1.40]
    (cdq:BOQ54_09390 [1.2.4.1],     cdq:BOQ54_09395 [2.3.1.12])     => [1.1.1.40]
    (ceh:CEW89_06310 [1.2.4.1],     ceh:CEW89_05925 [2.3.1.12])     => [1.1.1.40]
    (ceh:CEW89_06310 [1.2.4.1],     ceh:CEW89_06315 [2.3.1.12])     => [1.1.1.40]
    (ceh:CEW89_06310 [1.2.4.1],     ceh:CEW89_12460 [2.2.1.7])      => [1.1.1.40]
    (chel:AL346_17915 [1.2.4.1],    chel:AL346_17920 [2.3.1.12])    => [1.1.1.40]
    (chq:AQ619_08905 [1.2.4.1],     chq:AQ619_08900 [2.3.1.12])     => [1.1.1.40]
    (cid:P73_1703 [1.2.4.1],        cid:P73_1702 [2.3.1.12])        => [1.1.1.40]
    (cij:WG74_09325 [1.2.4.1],      cij:WG74_09505 [2.3.1.12])      => [1.1.1.40]
    (cmag:CBW24_10350 [1.2.4.1],    cmag:CBW24_10345 [2.3.1.12])    => [1.1.1.40]
    (cman:A9D14_07905 [1.2.4.1],    cman:A9D14_07640 [2.3.1.12])    => [1.1.1.40]
    (cmar:IMCC12053_2102 [1.2.4.1], cmar:IMCC12053_2103 [2.3.1.12]) => [1.1.1.40]
    (cmb:CSW64_11565 [1.2.4.1],     cmb:CSW64_11555 [2.3.1.12])     => [1.1.1.40]
    (cna:AB433_08375 [1.2.4.1],     cna:AB433_01620 [2.2.1.7])      => [1.1.1.40]
    (cna:AB433_08375 [1.2.4.1],     cna:AB433_08610 [2.3.1.12])     => [1.1.1.40]
    (con:TQ29_08210 [1.2.4.1],      con:TQ29_08205 [2.3.1.12])      => [1.1.1.40]
    (cse:Cseg_1968 [1.2.4.1],       cse:Cseg_1969 [2.3.1.12])       => [1.1.1.40]
    (daa:AKL17_2657 [1.2.4.1],      daa:AKL17_2658 [2.3.1.12])      => [1.1.1.40]
    (deq:XM25_06740 [1.2.4.1],      deq:XM25_06735 [2.3.1.12])      => [1.1.1.40]
    (don:BSK21_07650 [1.2.4.1],     don:BSK21_07655 [2.3.1.12])     => [1.1.1.40]
    (dsh:Dshi_2159 [1.2.4.1],       dsh:Dshi_2160 [2.3.1.12])       => [1.1.1.40]
    (ead:OV14_2519 [1.2.4.1],       ead:OV14_2520 [2.3.1.12])       => [1.1.1.40]
    (efv:CHH26_08090 [1.2.4.1],     efv:CHH26_08270 [2.3.1.12])     => [1.1.1.40]
    (egn:BMF35_a1962 [1.2.4.1],     egn:BMF35_a1940 [2.3.1.12])     => [1.1.1.40]
    (eli:ELI_06400 [1.2.4.1],       eli:ELI_06130 [2.3.1.12])       => [1.1.1.40]
    (ery:CP97_09725 [1.2.4.1],      ery:CP97_10070 [2.3.1.12])      => [1.1.1.40]
    (esj:SJ05684_c12890 [1.2.4.1],  esj:SJ05684_c12900 [2.3.1.12])  => [1.1.1.40]
    (gal:A0U94_06330 [1.2.4.1],     gal:A0U94_06335 [2.3.1.12])     => [1.1.1.40]
    (gbe:GbCGDNIH1_1184 [1.2.4.1],  gbe:GbCGDNIH1_1185 [2.3.1.12])  => [1.1.1.40]
    (gdi:GDI1940 [1.2.4.1],         gdi:GDI1941 [2.3.1.12])         => [1.1.1.40]
    (gox:GOX2290 [1.2.4.1],         gox:GOX2291 [2.3.1.12])         => [1.1.1.40]
    (gxl:H845_1900 [1.2.4.1],       gxl:H845_1899 [2.3.1.12])       => [1.1.1.40]
    (gxy:GLX_07550 [1.2.4.1],       gxy:GLX_07540 [2.3.1.12])       => [1.1.1.40]
    (hat:RC74_15005 [1.2.4.1],      hat:RC74_15000 [2.3.1.12])      => [1.1.1.40]
    (hba:Hbal_1687 [1.2.4.1],       hba:Hbal_1686 [2.3.1.12])       => [1.1.1.40]
    (hbc:AEM38_08000 [1.2.4.1],     hbc:AEM38_07995 [2.3.1.12])     => [1.1.1.40]
    (hdi:HDIA_1538 [1.2.4.1],       hdi:HDIA_1539 [2.3.1.12])       => [1.1.1.40]
    (hjo:AY555_08080 [1.2.4.1],     hjo:AY555_08085 [2.3.1.12])     => [1.1.1.40]
    (hne:HNE_1976 [1.2.4.1],        hne:HNE_1975 [2.3.1.12])        => [1.1.1.40]
    (hoe:IMCC20628_02090 [1.2.4.1], hoe:IMCC20628_02089 [2.3.1.12]) => [1.1.1.40]
    (jan:Jann_1690 [1.2.4.1],       jan:Jann_1688 [2.3.1.12])       => [1.1.1.40]
    (kba:A0U89_06665 [1.2.4.1],     kba:A0U89_06670 [2.3.1.12])     => [1.1.1.40]
    (keu:S101446_01150 [1.2.4.1],   keu:S101446_01149 [2.3.1.12])   => [1.1.1.40]
    (kna:B0W47_03380 [1.2.4.1],     kna:B0W47_03375 [2.3.1.12])     => [1.1.1.40]
    (kro:BVG79_00934 [1.2.4.1],     kro:BVG79_00933 [2.3.1.12])     => [1.1.1.40]
    (kvu:EIO_1168 [1.2.4.1],        kvu:EIO_1167 [2.3.1.12])        => [1.1.1.40]
    (labr:CHH27_06240 [1.2.4.1],    labr:CHH27_06235 [2.3.1.12])    => [1.1.1.40]
    (lagg:B0E33_26190 [1.2.4.1],    lagg:B0E33_26195 [2.3.1.12])    => [1.1.1.40]
    (lap:ACP90_14360 [1.2.4.1],     lap:ACP90_14365 [2.3.1.12])     => [1.1.1.40]
    (lar:lam_319 [1.2.4.1],         lar:lam_318 [2.3.1.12])         => [1.1.1.40]
    (las:CLIBASIA_02800 [1.2.4.1],  las:CLIBASIA_02805 [2.3.1.12])  => [1.1.1.40]
    (lcc:B488_11020 [1.2.4.1],      lcc:B488_11030 [2.3.1.12])      => [1.1.1.40]
    (lmd:METH_09250 [1.2.4.1],      lmd:METH_09255 [2.3.1.12])      => [1.1.1.40]
    (lvs:LOKVESSMR4R_01694 [1.2.4.1],      lvs:LOKVESSMR4R_01695 [2.3.1.12])       => [1.1.1.40]
    (maad:AZF01_10055 [1.2.4.1],    maad:AZF01_10045 [2.3.1.12])    => [1.1.1.40]
    (mag:amb2317 [1.2.4.1],         mag:amb2318 [2.3.1.12])         => [1.1.1.40]
    (magn:WV31_06605 [1.2.4.1],     magn:WV31_06610 [2.3.1.12])     => [1.1.1.40]
    (magq:MGMAQ_2051 [1.2.4.1],     magq:MGMAQ_2050 [2.3.1.12])     => [1.1.1.40]
    (magx:XM1_3336 [1.2.4.1],       magx:XM1_3335 [2.3.1.12])       => [1.1.1.40]
    (malg:MALG_02099 [1.2.4.1],     malg:MALG_02101 [2.3.1.12])     => [1.1.1.40]
    (mam:Mesau_04179 [1.2.4.1],     mam:Mesau_04178 [2.3.1.12])     => [1.1.1.40]
    (mamo:A6B35_19500 [1.2.4.1],    mamo:A6B35_19495 [2.3.1.12])    => [1.1.1.40]
    (maqu:Maq22A_c16995 [1.2.4.1],  maqu:Maq22A_c16980 [2.3.1.12])  => [1.1.1.40]
    (mci:Mesci_3696 [1.2.4.1],      mci:Mesci_3697 [2.3.1.12])      => [1.1.1.40]
    (mes:Meso_1629 [1.2.4.1],       mes:Meso_1628 [2.3.1.12])       => [1.1.1.40]
    (meso:BSQ44_15320 [1.2.4.1],    meso:BSQ44_15310 [2.3.1.12])    => [1.1.1.40]
    (mesw:A9K65_019865 [1.2.4.1],   mesw:A9K65_019870 [2.3.1.12])   => [1.1.1.40]
    (met:M446_5897 [1.2.4.1],       met:M446_5900 [2.3.1.12])       => [1.1.1.40]
    (meta:Y590_13445 [1.2.4.1],     meta:Y590_13455 [2.3.1.12])     => [1.1.1.40]
    (mex:Mext_2787 [1.2.4.1],       mex:Mext_2789 [2.3.1.12])       => [1.1.1.40]
    (mey:TM49_16605 [1.2.4.1],      mey:TM49_16600 [2.3.1.12])      => [1.1.1.40]
    (mgy:MGMSRv2__0967 [1.2.4.1],   mgy:MGMSRv2__0968 [2.3.1.12])   => [1.1.1.40]
    (mln:A9174_23275 [1.2.4.1],     mln:A9174_23270 [2.3.1.12])     => [1.1.1.40]
    (mlo:mlr0384 [1.2.4.1],         mlo:mlr0385 [2.3.1.12])         => [1.1.1.40]
    (mmed:Mame_02759 [1.2.4.1],     mmed:Mame_02760 [2.3.1.12])     => [1.1.1.40]
    (mmr:Mmar10_1418 [1.2.4.1],     mmr:Mmar10_1420 [2.3.1.12])     => [1.1.1.40]
    (mno:Mnod_6516 [1.2.4.1],       mno:Mnod_6518 [2.3.1.12])       => [1.1.1.40]
    (moc:BB934_27340 [1.2.4.1],     moc:BB934_27350 [2.3.1.12])     => [1.1.1.40]
    (mop:Mesop_4545 [1.2.4.1],      mop:Mesop_4544 [2.3.1.12])      => [1.1.1.40]
    (mor:MOC_1206 [1.2.4.1],        mor:MOC_1209 [2.3.1.12])        => [1.1.1.40]
    (mphy:MCBMB27_00584 [1.2.4.1],  mphy:MCBMB27_00587 [2.3.1.12])  => [1.1.1.40]
    (mpo:Mpop_2910 [1.2.4.1],       mpo:Mpop_2912 [2.3.1.12])       => [1.1.1.40]
    (mrd:Mrad2831_0989 [1.2.4.1],   mrd:Mrad2831_0992 [2.3.1.12])   => [1.1.1.40]
    (msl:Msil_0520 [1.2.4.1],       msl:Msil_0521 [2.3.1.12])       => [1.1.1.40]
    (mza:B2G69_21495 [1.2.4.1],     mza:B2G69_21505 [2.3.1.12])     => [1.1.1.40]
    (nao:Y958_07910 [1.2.4.1],      nao:Y958_07905 [2.3.1.12])      => [1.1.1.40]
    (nar:Saro_1909 [1.2.4.1],       nar:Saro_1946 [2.3.1.12])       => [1.1.1.40]
    (ncb:C0V82_02645 [1.2.4.1],     ncb:C0V82_02650 [2.3.1.12])     => [1.1.1.40]
    (nch:A0U93_04645 [1.2.4.1],     nch:A0U93_04640 [2.3.1.12])     => [1.1.1.40]
    (ngl:RG1141_CH15540 [1.2.4.1],  ngl:RG1141_CH15550 [2.3.1.12])  => [1.1.1.40]
    (nha:Nham_1750 [1.2.4.1],       nha:Nham_1751 [2.3.1.12])       => [1.1.1.40]
    (npn:JI59_03450 [1.2.4.1],      npn:JI59_03675 [2.3.1.12])      => [1.1.1.40]
    (npn:JI59_03450 [1.2.4.1],      npn:JI59_10595 [2.2.1.7])       => [1.1.1.40]
    (npn:JI59_03450 [1.2.4.1],      npn:JI59_22060 [2.3.1.12])      => [1.1.1.40]
    (npp:PP1Y_AT26298 [1.2.4.1],    npp:PP1Y_AT2120 [2.2.1.7])      => [1.1.1.40]
    (npp:PP1Y_AT26298 [1.2.4.1],    npp:PP1Y_AT25743 [2.3.1.12])    => [1.1.1.40]
    (nre:BES08_04330 [1.2.4.1],     nre:BES08_03975 [2.3.1.12])     => [1.1.1.40]
    (nre:BES08_04330 [1.2.4.1],     nre:BES08_18280 [2.3.1.12])     => [1.1.1.40]
    (nwi:Nwi_1817 [1.2.4.1],        nwi:Nwi_1816 [2.3.1.12])        => [1.1.1.40]
    (oan:Oant_2060 [1.2.4.1],       oan:Oant_2061 [2.3.1.12])       => [1.1.1.40]
    (oar:OA238_c11030 [1.2.4.1],    oar:OA238_c11020 [2.3.1.12])    => [1.1.1.40]
    (oat:OAN307_c27940 [1.2.4.1],   oat:OAN307_c27950 [2.3.1.12])   => [1.1.1.40]
    (oca:OCAR_6285 [1.2.4.1],       oca:OCAR_6284 [2.3.1.12])       => [1.1.1.40]
    (och:CES85_1265 [1.2.4.1],      och:CES85_1264 [2.3.1.12])      => [1.1.1.40]
    (ops:A8A54_05250 [1.2.4.1],     ops:A8A54_05245 [2.3.1.12])     => [1.1.1.40]
    (otm:OSB_19370 [1.2.4.1],       otm:OSB_19380 [2.3.1.12])       => [1.1.1.40]
    (paby:Ga0080574_TMP4725 [1.2.4.1],      paby:Ga0080574_TMP142 [2.3.1.12])       => [1.1.1.40]
    (paby:Ga0080574_TMP4725 [1.2.4.1],      paby:Ga0080574_TMP4727 [2.3.1.12])      => [1.1.1.40]
    (pami:JCM7686_1054 [1.2.4.1],   pami:JCM7686_1053 [2.3.1.12])   => [1.1.1.40]
    (paro:CUV01_02990 [1.2.4.1],    paro:CUV01_02995 [2.3.1.12])    => [1.1.1.40]
    (paru:CYR75_07680 [1.2.4.1],    paru:CYR75_07685 [2.3.1.12])    => [1.1.1.40]
    (pbr:PB2503_08834 [1.2.4.1],    pbr:PB2503_08849 [2.3.1.12])    => [1.1.1.40]
    (pcon:B0A89_07015 [1.2.4.1],    pcon:B0A89_07005 [2.3.1.12])    => [1.1.1.40]
    (pde:Pden_3891 [1.2.4.1],       pde:Pden_3890 [2.3.1.12])       => [1.1.1.40]
    (pel:SAR11G3_00622 [1.2.4.1],   pel:SAR11G3_00621 [2.3.1.12])   => [1.1.1.40]
    (pga:PGA1_c17560 [1.2.4.1],     pga:PGA1_c17570 [2.3.1.12])     => [1.1.1.40]
    (pgd:Gal_01568 [1.2.4.1],       pgd:Gal_01567 [2.3.1.12])       => [1.1.1.40]
    (pgv:SL003B_1083 [1.2.4.1],     pgv:SL003B_3299 [2.2.1.7])      => [1.1.1.40]
    (phl:KKY_1384 [1.2.4.1],        phl:KKY_1385 [2.3.1.12])        => [1.1.1.40]
    (php:PhaeoP97_01777 [1.2.4.1],  php:PhaeoP97_01778 [2.3.1.12])  => [1.1.1.40]
    (pht:BLM14_08405 [1.2.4.1],     pht:BLM14_08410 [2.3.1.12])     => [1.1.1.40]
    (pla:Plav_3140 [1.2.4.1],       pla:Plav_3139 [2.3.1.12])       => [1.1.1.40]
    (pns:A9D12_12435 [1.2.4.1],     pns:A9D12_04905 [2.2.1.7])      => [1.1.1.40]
    (pns:A9D12_12435 [1.2.4.1],     pns:A9D12_12255 [2.3.1.12])     => [1.1.1.40]
    (porl:BG023_111981 [1.2.4.1],   porl:BG023_111945 [2.3.1.12])   => [1.1.1.40]
    (porl:BG023_111981 [1.2.4.1],   porl:BG023_11354 [2.2.1.7])     => [1.1.1.40]
    (pphr:APZ00_18065 [1.2.4.1],    pphr:APZ00_18070 [2.3.1.12])    => [1.1.1.40]
    (ppic:PhaeoP14_01654 [1.2.4.1], ppic:PhaeoP14_01655 [2.3.1.12]) => [1.1.1.40]
    (psf:PSE_3295 [1.2.4.1],        psf:PSE_3294 [2.3.1.12])        => [1.1.1.40]
    (psin:CAK95_23135 [1.2.4.1],    psin:CAK95_23140 [2.3.1.12])    => [1.1.1.40]
    (ptp:RCA23_c18000 [1.2.4.1],    ptp:RCA23_c18010 [2.3.1.12])    => [1.1.1.40]
    (pub:SAR11_0429 [1.2.4.1],      pub:SAR11_0430 [2.3.1.12])      => [1.1.1.40]
    (pye:A6J80_12750 [1.2.4.1],     pye:A6J80_12745 [2.3.1.12])     => [1.1.1.40]
    (pzh:CX676_18090 [1.2.4.1],     pzh:CX676_10325 [2.2.1.7])      => [1.1.1.40]
    (pzh:CX676_18090 [1.2.4.1],     pzh:CX676_18085 [2.3.1.12])     => [1.1.1.40]
    (pzu:PHZ_c1743 [1.2.4.1],       pzu:PHZ_c0912 [2.2.1.7])        => [1.1.1.40]
    (pzu:PHZ_c1743 [1.2.4.1],       pzu:PHZ_c1741 [2.3.1.12])       => [1.1.1.40]
    (rbg:BG454_12650 [1.2.4.1],     rbg:BG454_12655 [2.3.1.12])     => [1.1.1.40]
    (rbm:TEF_09655 [1.2.4.1],       rbm:TEF_09660 [2.3.1.12])       => [1.1.1.40]
    (rce:RC1_0120 [1.2.4.1],        rce:RC1_0121 [2.3.1.12])        => [1.1.1.40]
    (rcp:RCAP_rcc01704 [1.2.4.1],   rcp:RCAP_rcc01703 [2.3.1.12])   => [1.1.1.40]
    (rde:RD1_3013 [1.2.4.1],        rde:RD1_3014 [2.3.1.12])        => [1.1.1.40]
    (rdi:CMV14_08920 [1.2.4.1],     rdi:CMV14_07905 [2.3.1.12])     => [1.1.1.40]
    (ret:RHE_CH01934 [1.2.4.1],     ret:RHE_CH01935 [2.3.1.12])     => [1.1.1.40]
    (rga:RGR602_CH01828 [1.2.4.1],  rga:RGR602_CH01829 [2.3.1.12])  => [1.1.1.40]
    (rgi:RGI145_09000 [1.2.4.1],    rgi:RGI145_08995 [2.3.1.12])    => [1.1.1.40]
    (rhi:NGR_c12830 [1.2.4.1],      rhi:NGR_c12850 [2.3.1.12])      => [1.1.1.40]
    (rhl:LPU83_2559 [1.2.4.1],      rhl:LPU83_2558 [2.3.1.12])      => [1.1.1.40]
    (rhm:B5V46_11575 [1.2.4.1],     rhm:B5V46_00795 [2.2.1.7])      => [1.1.1.40]
    (rhm:B5V46_11575 [1.2.4.1],     rhm:B5V46_11580 [2.3.1.12])     => [1.1.1.40]
    (rhn:AMJ98_CH01997 [1.2.4.1],   rhn:AMJ98_CH01998 [2.3.1.12])   => [1.1.1.40]
    (rhp:LPB142_08045 [1.2.4.1],    rhp:LPB142_08040 [2.3.1.12])    => [1.1.1.40]
    (rht:NT26_1619 [1.2.4.1],       rht:NT26_1620 [2.3.1.12])       => [1.1.1.40]
    (rhx:AMK02_CH02005 [1.2.4.1],   rhx:AMK02_CH02006 [2.3.1.12])   => [1.1.1.40]
    (rhz:RHPLAN_39510 [1.2.4.1],    rhz:RHPLAN_39530 [2.3.1.12])    => [1.1.1.40]
    (rir:BN877_I1389 [1.2.4.1],     rir:BN877_I1390 [2.3.1.12])     => [1.1.1.40]
    (rle:RL2242 [1.2.4.1],          rle:RL2243 [2.3.1.12])          => [1.1.1.40]
    (rli:RLO149_c014190 [1.2.4.1],  rli:RLO149_c014180 [2.3.1.12])  => [1.1.1.40]
    (rmb:K529_008000 [1.2.4.1],     rmb:K529_008005 [2.3.1.12])     => [1.1.1.40]
    (rmm:ROSMUCSMR3_03446 [1.2.4.1],rmm:ROSMUCSMR3_00895 [2.2.1.7]) => [1.1.1.40]
    (rmm:ROSMUCSMR3_03446 [1.2.4.1],rmm:ROSMUCSMR3_03447 [2.3.1.12])=> [1.1.1.40]
    (ros:CTJ15_08415 [1.2.4.1],     ros:CTJ15_08420 [2.3.1.12])     => [1.1.1.40]
    (rpa:RPA2866 [1.2.4.1],         rpa:RPA2864 [2.3.1.12])         => [1.1.1.40]
    (rpha:AMC79_CH02115 [1.2.4.1],  rpha:AMC79_CH02116 [2.3.1.12])  => [1.1.1.40]
    (rru:Rru_A1880 [1.2.4.1],       rru:Rru_A1879 [2.3.1.12])       => [1.1.1.40]
    (rsp:RSP_4049 [1.2.4.1],        rsp:RSP_4050 [2.3.1.12])        => [1.1.1.40]
    (rsu:NHU_02744 [1.2.4.1],       rsu:NHU_02745 [2.3.1.12])       => [1.1.1.40]
    (rsu:NHU_02744 [1.2.4.1],       rsu:NHU_03965 [2.2.1.7])        => [1.1.1.40]
    (rtr:RTCIAT899_CH08600 [1.2.4.1],       rtr:RTCIAT899_CH08605 [2.3.1.12])       => [1.1.1.40]
    (rva:Rvan_1333 [1.2.4.1],       rva:Rvan_1331 [2.3.1.12])       => [1.1.1.40]
    (sagu:CDO87_01050 [1.2.4.1],    sagu:CDO87_01060 [2.3.1.12])    => [1.1.1.40]
    (sal:Sala_0526 [1.2.4.1],       sal:Sala_1235 [2.3.1.12])       => [1.1.1.40]
    (same:SAMCFNEI73_Ch1575 [1.2.4.1],      same:SAMCFNEI73_Ch1576 [2.3.1.12])      => [1.1.1.40]
    (sbd:ATN00_16165 [1.2.4.1],     sbd:ATN00_14290 [2.3.1.12])     => [1.1.1.40]
    (sch:Sphch_0554 [1.2.4.1],      sch:Sphch_1066 [2.3.1.12])      => [1.1.1.40]
    (sch:Sphch_0554 [1.2.4.1],      sch:Sphch_1123 [2.2.1.7])       => [1.1.1.40]
    (sch:Sphch_0554 [1.2.4.1],      sch:Sphch_3446 [2.3.1.12])      => [1.1.1.40]
    (sch:Sphch_3732 [1.2.4.1],      sch:Sphch_1066 [2.3.1.12])      => [1.1.1.40]
    (sch:Sphch_3732 [1.2.4.1],      sch:Sphch_1123 [2.2.1.7])       => [1.1.1.40]
    (sch:Sphch_3732 [1.2.4.1],      sch:Sphch_3446 [2.3.1.12])      => [1.1.1.40]
    (sclo:SCLO_1011100 [1.2.4.1],   sclo:SCLO_1007870 [2.3.1.12])   => [1.1.1.40]
    (sfla:SPHFLASMR4Y_01022 [1.2.4.1],      sfla:SPHFLASMR4Y_00806 [2.3.1.12])      => [1.1.1.40]
    (sgi:SGRAN_2407 [1.2.4.1],      sgi:SGRAN_2017 [2.3.1.12])      => [1.1.1.40]
    (shyd:CJD35_14800 [1.2.4.1],    shyd:CJD35_13420 [2.3.1.12])    => [1.1.1.40]
    (shyd:CJD35_14800 [1.2.4.1],    shyd:CJD35_19880 [2.3.1.12])    => [1.1.1.40]
    (shyd:CJD35_19885 [1.2.4.1],    shyd:CJD35_13420 [2.3.1.12])    => [1.1.1.40]
    (shyd:CJD35_19885 [1.2.4.1],    shyd:CJD35_19880 [2.3.1.12])    => [1.1.1.40]
    (shz:shn_09760 [1.2.4.1],       shz:shn_09755 [2.3.1.12])       => [1.1.1.40]
    (sil:SPO2241 [1.2.4.1],         sil:SPO2242 [2.3.1.12])         => [1.1.1.40]
    (sinb:SIDU_07350 [1.2.4.1],     sinb:SIDU_05035 [2.3.1.12])     => [1.1.1.40]
    (sino:SS05631_c12270 [1.2.4.1], sino:SS05631_c12280 [2.3.1.12]) => [1.1.1.40]
    (sit:TM1040_1078 [1.2.4.1],     sit:TM1040_1077 [2.3.1.12])     => [1.1.1.40]
    (six:BSY16_1059 [1.2.4.1],      six:BSY16_1060 [2.3.1.12])      => [1.1.1.40]
    (sjp:SJA_C1-14500 [1.2.4.1],    sjp:SJA_C1-20640 [2.3.1.12])    => [1.1.1.40]
    (sjp:SJA_C1-14500 [1.2.4.1],    sjp:SJA_C1-22860 [2.2.1.7])     => [1.1.1.40]
    (skr:BRX40_13200 [1.2.4.1],     skr:BRX40_18075 [2.3.1.12])     => [1.1.1.40]
    (smag:AN936_10165 [1.2.4.1],    smag:AN936_07930 [2.3.1.12])    => [1.1.1.40]
    (smd:Smed_1077 [1.2.4.1],       smd:Smed_1078 [2.3.1.12])       => [1.1.1.40]
    (sme:SMc01031 [1.2.4.1],        sme:SMc01032 [2.3.1.12])        => [1.1.1.40]
    (smy:BJP26_08800 [1.2.4.1],     smy:BJP26_12395 [2.3.1.12])     => [1.1.1.40]
    (sno:Snov_1793 [1.2.4.1],       sno:Snov_1792 [2.3.1.12])       => [1.1.1.40]
    (span:AWL63_13955 [1.2.4.1],    span:AWL63_12490 [2.3.1.12])    => [1.1.1.40]
    (sphb:EP837_00372 [1.2.4.1],    sphb:EP837_02576 [2.3.1.12])    => [1.1.1.40]
    (sphc:CVN68_05200 [1.2.4.1],    sphc:CVN68_09945 [2.3.1.12])    => [1.1.1.40]
    (sphc:CVN68_05200 [1.2.4.1],    sphc:CVN68_09985 [2.2.1.7])     => [1.1.1.40]
    (sphg:AZE99_06590 [1.2.4.1],    sphg:AZE99_07785 [2.3.1.12])    => [1.1.1.40]
    (sphi:TS85_06520 [1.2.4.1],     sphi:TS85_12485 [2.2.1.7])      => [1.1.1.40]
    (sphi:TS85_06520 [1.2.4.1],     sphi:TS85_15585 [2.3.1.12])     => [1.1.1.40]
    (sphj:BSL82_06255 [1.2.4.1],    sphj:BSL82_06245 [2.3.1.12])    => [1.1.1.40]
    (sphj:BSL82_06255 [1.2.4.1],    sphj:BSL82_17315 [2.3.1.12])    => [1.1.1.40]
    (sphk:SKP52_07200 [1.2.4.1],    sphk:SKP52_03350 [2.3.1.61])    => [1.1.1.40]
    (sphk:SKP52_07200 [1.2.4.1],    sphk:SKP52_08850 [2.3.1.12])    => [1.1.1.40]
    (sphl:LPB140_07965 [1.2.4.1],   sphl:LPB140_07605 [2.3.1.12])   => [1.1.1.40]
    (sphm:G432_13100 [1.2.4.1],     sphm:G432_08190 [2.3.1.12])     => [1.1.1.40]
    (sphp:LH20_07705 [1.2.4.1],     sphp:LH20_12785 [2.3.1.12])     => [1.1.1.40]
    (sphq:BWQ93_04105 [1.2.4.1],    sphq:BWQ93_07255 [2.3.1.12])    => [1.1.1.40]
    (sphr:BSY17_395 [1.2.4.1],      sphr:BSY17_2932 [2.3.1.12])     => [1.1.1.40]
    (spht:K426_11970 [1.2.4.1],     spht:K426_14090 [2.3.1.12])     => [1.1.1.40]
    (spht:K426_11970 [1.2.4.1],     spht:K426_14385 [2.2.1.7])      => [1.1.1.40]
    (spht:K426_11970 [1.2.4.1],     spht:K426_25354 [2.3.1.12])     => [1.1.1.40]
    (spht:K426_11970 [1.2.4.1],     spht:K426_28270 [2.3.1.12])     => [1.1.1.40]
    (sphy:CHN51_16395 [1.2.4.1],    sphy:CHN51_15230 [2.3.1.12])    => [1.1.1.40]
    (spkc:KC8_08660 [1.2.4.1],      spkc:KC8_15420 [2.3.1.12])      => [1.1.1.40]
    (splk:AV944_08790 [1.2.4.1],    splk:AV944_08370 [2.2.1.7])     => [1.1.1.40]
    (splk:AV944_08790 [1.2.4.1],    splk:AV944_14570 [2.3.1.12])    => [1.1.1.40]
    (splm:BXU08_05470 [1.2.4.1],    splm:BXU08_09200 [2.3.1.12])    => [1.1.1.40]
    (splm:BXU08_05470 [1.2.4.1],    splm:BXU08_09240 [2.2.1.7])     => [1.1.1.40]
    (spmi:K663_06930 [1.2.4.1],     spmi:K663_06115 [2.2.1.7])      => [1.1.1.40]
    (spmi:K663_06930 [1.2.4.1],     spmi:K663_09835 [2.3.1.12])     => [1.1.1.40]
    (spmi:K663_06930 [1.2.4.1],     spmi:K663_16085 [2.3.1.12])     => [1.1.1.40]
    (spse:SULPSESMR1_01103 [1.2.4.1],       spse:SULPSESMR1_01102 [2.3.1.12])       => [1.1.1.40]
    (ssan:NX02_15375 [1.2.4.1],     ssan:NX02_14100 [2.2.1.7])      => [1.1.1.40]
    (ssan:NX02_15375 [1.2.4.1],     ssan:NX02_20525 [2.3.1.12])     => [1.1.1.40]
    (ssy:SLG_18970 [1.2.4.1],       ssy:SLG_36230 [2.3.1.12])       => [1.1.1.40]
    (ssy:SLG_23990 [1.2.4.1],       ssy:SLG_36230 [2.3.1.12])       => [1.1.1.40]
    (stax:MC45_00715 [1.2.4.1],     stax:MC45_01905 [2.2.1.7])      => [1.1.1.40]
    (stax:MC45_00715 [1.2.4.1],     stax:MC45_09385 [2.3.1.12])     => [1.1.1.40]
    (ster:AOA14_13235 [1.2.4.1],    ster:AOA14_10505 [2.2.1.7])     => [1.1.1.40]
    (ster:AOA14_13235 [1.2.4.1],    ster:AOA14_14760 [2.3.1.12])    => [1.1.1.40]
    (suam:BOO69_10560 [1.2.4.1],    suam:BOO69_10570 [2.3.1.12])    => [1.1.1.40]
    (swi:Swit_1225 [1.2.4.1],       swi:Swit_1367 [2.3.1.12])       => [1.1.1.40]
    (swi:Swit_1225 [1.2.4.1],       swi:Swit_5152 [2.3.1.12])       => [1.1.1.40]
    (swi:Swit_5153 [1.2.4.1],       swi:Swit_1367 [2.3.1.12])       => [1.1.1.40]
    (swi:Swit_5153 [1.2.4.1],       swi:Swit_5152 [2.3.1.12])       => [1.1.1.40]
    (sya:A6768_03935 [1.2.4.1],     sya:A6768_06065 [2.2.1.7])      => [1.1.1.40]
    (sya:A6768_03935 [1.2.4.1],     sya:A6768_10825 [2.3.1.12])     => [1.1.1.40]
    (syb:TZ53_16805 [1.2.4.1],      syb:TZ53_00420 [2.3.1.12])      => [1.1.1.40]
    (syb:TZ53_16805 [1.2.4.1],      syb:TZ53_19895 [2.3.1.12])      => [1.1.1.40]
    (syb:TZ53_16805 [1.2.4.1],      syb:TZ53_20205 [2.2.1.7])       => [1.1.1.40]
    (thac:CSC3H3_10045 [1.2.4.1],   thac:CSC3H3_10040 [2.3.1.12])   => [1.1.1.40]
    (thd:BHV28_08270 [1.2.4.1],     thd:BHV28_08280 [2.3.1.12])     => [1.1.1.40]
    (thw:BMG03_12070 [1.2.4.1],     thw:BMG03_12075 [2.3.1.12])     => [1.1.1.40]
    (tom:BWR18_05285 [1.2.4.1],     tom:BWR18_05280 [2.3.1.12])     => [1.1.1.40]
    (tpro:Ga0080559_TMP606 [1.2.4.1],       tpro:Ga0080559_TMP608 [2.3.1.12])       => [1.1.1.40]
    (txi:TH3_10320 [1.2.4.1],       txi:TH3_10315 [2.3.1.12])       => [1.1.1.40]
    (vgo:GJW-30_1_02979 [1.2.4.1],  vgo:GJW-30_1_02982 [2.3.1.12])  => [1.1.1.40]
    (xau:Xaut_3890 [1.2.4.1],       xau:Xaut_1572 [2.3.1.12])       => [1.1.1.40]
    (xau:Xaut_3890 [1.2.4.1],       xau:Xaut_3891 [2.3.1.12])       => [1.1.1.40]
    (yan:AYJ57_13670 [1.2.4.1],     yan:AYJ57_13665 [2.3.1.12])     => [1.1.1.40]
    (zmo:ZMO1605 [1.2.4.1],         zmo:ZMO0510 [2.3.1.12])         => [1.1.1.40]
    (zmo:ZMO1605 [1.2.4.1],         zmo:ZMO1234 [2.2.1.7])          => [1.1.1.40]
    (zmo:ZMO1605 [1.2.4.1],         zmo:ZMO1598 [2.2.1.7])          => [1.1.1.40]
    (mop:Mesop_2825 [1.2.4.1],      mop:Mesop_5537 [2.2.1.1])       => [1.1.1.40, 5.1.3.1, 5.3.1.6]
    (paro:CUV01_02990 [1.2.4.1],    paro:CUV01_06065 [2.2.1.1])     => [1.1.1.40, 5.1.3.1, 5.3.1.6]
    (span:AWL63_13955 [1.2.4.1],    span:AWL63_00225 [2.2.1.1])     => [1.1.1.40, 5.1.3.1, 5.3.1.6]
    (aace:A0U92_09345 [2.1.3.2],    aace:A0U92_16215 [2.1.3.3])     => [2.1.3.2]
    (aak:AA2016_0641 [2.6.1.1],     aak:AA2016_4478 [4.4.1.8])      => [2.1.3.2]
    (aak:AA2016_3853 [2.1.3.2],     aak:AA2016_5307 [2.1.3.3])      => [2.1.3.2]
    (abg:Asbog_02489 [2.1.3.2],     abg:Asbog_02520 [2.1.3.3])      => [2.1.3.2]
    (abs:AZOBR_p1130184 [2.1.3.2],  abs:AZOBR_p1110081 [2.1.3.3])   => [2.1.3.2]
    (acr:Acry_0733 [2.1.3.2],       acr:Acry_2540 [2.1.3.3])        => [2.1.3.2]
    (agr:AGROH133_05748 [2.1.3.2],  agr:AGROH133_03710 [2.1.3.3])   => [2.1.3.2]
    (ahu:A6A40_05495 [2.1.3.2],     ahu:A6A40_01080 [2.1.3.3])      => [2.1.3.2]
    (amv:ACMV_11390 [2.1.3.2],      amv:ACMV_28640 [2.1.3.3])       => [2.1.3.2]
    (anh:A6F65_00628 [2.6.1.1],     anh:A6F65_00752 [2.6.1.9])      => [2.1.3.2]
    (aol:S58_32410 [2.1.3.2],       aol:S58_06810 [2.1.3.3])        => [2.1.3.2]
    (apb:SAR116_0613 [2.1.3.2],     apb:SAR116_1883 [2.1.3.3])      => [2.1.3.2]
    (apm:HIMB5_00001730 [2.6.1.1],  apm:HIMB5_00000410 [2.6.1.9])   => [2.1.3.2]
    (apm:HIMB5_00007360 [2.1.3.2],  apm:HIMB5_00011580 [2.1.3.3])   => [2.1.3.2]
    (apom:CPF11_03680 [2.1.3.2],    apom:CPF11_03820 [2.1.3.3])     => [2.1.3.2]
    (apt:APA01_07610 [2.1.3.2],     apt:APA01_07290 [2.1.3.3])      => [2.1.3.2]
    (aro:B0909_06865 [2.1.3.2],     aro:B0909_11305 [2.1.3.3])      => [2.1.3.2]
    (asv:WG31_04290 [2.1.3.2],      asv:WG31_04145 [2.1.3.3])       => [2.1.3.2]
    (asz:ASN_388 [2.1.3.2],         asz:ASN_423 [2.1.3.3])          => [2.1.3.2]
    (ato:CIW82_10605 [2.1.3.2],     ato:CIW82_10450 [2.1.3.3])      => [2.1.3.2]
    (atu:Atu1308 [2.1.3.2],         atu:Atu0429 [2.1.3.3])          => [2.1.3.2]
    (aua:M673_11640 [2.1.3.2],      aua:M673_15920 [2.1.3.3])       => [2.1.3.2]
    (azc:AZC_2851 [2.1.3.2],        azc:AZC_4027 [2.1.3.3])         => [2.1.3.2]
    (azl:AZL_015630 [2.1.3.2],      azl:AZL_004170 [2.1.3.3])       => [2.1.3.2]
    (bapi:BBC0122_012900 [2.1.3.2], bapi:BBC0122_002560 [2.1.3.3])  => [2.1.3.2]
    (bbk:BARBAKC583_0839 [2.1.3.2], bbk:BARBAKC583_1291 [2.1.3.3])  => [2.1.3.2]
    (bbt:BBta_4725 [2.1.3.2],       bbt:BBta_0760 [2.1.3.3])        => [2.1.3.2]
    (bcd:BARCL_0788 [2.1.3.2],      bcd:BARCL_0120 [2.1.3.3])       => [2.1.3.2]
    (bic:LMTR13_17950 [2.1.3.2],    bic:LMTR13_36225 [2.1.3.3])     => [2.1.3.2]
    (bid:Bind_3418 [2.1.3.2],       bid:Bind_0151 [2.1.3.3])        => [2.1.3.2]
    (bja:blr5099 [2.1.3.2],         bja:blr1099 [2.1.3.3])          => [2.1.3.2]
    (bju:BJ6T_46190 [2.1.3.2],      bju:BJ6T_11290 [2.1.3.3])       => [2.1.3.2]
    (blas:BSY18_1271 [2.1.3.2],     blas:BSY18_3543 [2.1.3.3])      => [2.1.3.2]
    (bop:AXW83_05525 [2.1.3.2],     bop:AXW83_20595 [2.1.3.3])      => [2.1.3.2]
    (bos:BSY19_803 [2.6.1.1],       bos:BSY19_3540 [4.4.1.8])       => [2.1.3.2]
    (bra:BRADO4502 [2.1.3.2],       bra:BRADO6778 [2.1.3.3])        => [2.1.3.2]
    (brc:BCCGELA001_21630 [2.1.3.2],brc:BCCGELA001_34135 [2.1.3.3]) => [2.1.3.2]
    (brk:CWS35_27085 [2.1.3.2],     brk:CWS35_10260 [2.1.3.3])      => [2.1.3.2]
    (bro:BRAD285_4271 [2.1.3.2],    bro:BRAD285_6924 [2.1.3.3])     => [2.1.3.2]
    (brs:S23_31190 [2.1.3.2],       brs:S23_67200 [2.1.3.3])        => [2.1.3.2]
    (bvr:BVIR_1655 [2.1.3.2],       bvr:BVIR_3201 [2.1.3.3])        => [2.1.3.2]
    (bvv:BHK69_17075 [2.6.1.1],     bvv:BHK69_11845 [4.4.1.8])      => [2.1.3.2]
    (bvv:BHK69_17405 [2.6.1.1],     bvv:BHK69_10215 [2.6.1.9])      => [2.1.3.2]
    (bvv:BHK69_17960 [2.1.3.2],     bvv:BHK69_05425 [2.1.3.3])      => [2.1.3.2]
    (bvv:BHK69_21550 [2.6.1.1],     bvv:BHK69_11845 [4.4.1.8])      => [2.1.3.2]
    (cdq:BOQ54_10620 [2.1.3.2],     cdq:BOQ54_02410 [2.1.3.3])      => [2.1.3.2]
    (cmag:CBW24_15855 [2.6.1.1],    cmag:CBW24_15140 [4.4.1.8])     => [2.1.3.2]
    (cmag:CBW24_15855 [2.6.1.1],    cmag:CBW24_17710 [2.6.1.9])     => [2.1.3.2]
    (cmb:CSW64_09750 [2.1.3.2],     cmb:CSW64_16805 [2.1.3.3])      => [2.1.3.2]
    (deq:XM25_09185 [2.1.3.2],      deq:XM25_22360 [2.1.3.3])       => [2.1.3.2]
    (egn:BMF35_a0322 [2.1.3.2],     egn:BMF35_a0814 [2.1.3.3])      => [2.1.3.2]
    (esj:SJ05684_c09700 [2.1.3.2],  esj:SJ05684_c01260 [2.1.3.3])   => [2.1.3.2]
    (fil:BN1229_v1_0353 [2.1.3.2],  fil:BN1229_v1_1325 [2.1.3.3])   => [2.1.3.2]
    (gal:A0U94_13890 [2.1.3.2],     gal:A0U94_13735 [2.1.3.3])      => [2.1.3.2]
    (gbe:GbCGDNIH1_0809 [2.1.3.2],  gbe:GbCGDNIH1_2273 [2.1.3.3])   => [2.1.3.2]
    (gdi:GDI0049 [2.1.3.2],         gdi:GDI1463 [2.1.3.3])          => [2.1.3.2]
    (gox:GOX1267 [2.1.3.2],         gox:GOX1236 [2.1.3.3])          => [2.1.3.2]
    (gxl:H845_2485 [2.1.3.2],       gxl:H845_2511 [2.1.3.3])        => [2.1.3.2]
    (gxy:GLX_12460 [2.1.3.2],       gxy:GLX_12730 [2.1.3.3])        => [2.1.3.2]
    (hat:RC74_07005 [2.6.1.1],      hat:RC74_08240 [4.4.1.8])       => [2.1.3.2]
    (hbc:AEM38_09630 [2.1.3.2],     hbc:AEM38_02735 [2.1.3.3])      => [2.1.3.2]
    (hdi:HDIA_2920 [2.1.3.2],       hdi:HDIA_0565 [2.1.3.3])        => [2.1.3.2]
    (hdi:HDIA_3464 [2.6.1.1],       hdi:HDIA_4357 [2.6.1.9])        => [2.1.3.2]
    (hdn:Hden_0636 [2.1.3.2],       hdn:Hden_0020 [2.1.3.3])        => [2.1.3.2]
    (hne:HNE_2302 [2.1.3.2],        hne:HNE_0592 [2.1.3.3])         => [2.1.3.2]
    (hne:HNE_2968 [2.6.1.1],        hne:HNE_1125 [2.6.1.9])         => [2.1.3.2]
    (hoe:IMCC20628_02307 [2.1.3.2], hoe:IMCC20628_03650 [2.1.3.3])  => [2.1.3.2]
    (kba:A0U89_11590 [2.1.3.2],     kba:A0U89_11740 [2.1.3.3])      => [2.1.3.2]
    (keu:S101446_01792 [2.1.3.2],   keu:S101446_01820 [2.1.3.3])    => [2.1.3.2]
    (kna:B0W47_06650 [2.1.3.2],     kna:B0W47_06785 [2.1.3.3])      => [2.1.3.2]
    (kro:BVG79_00956 [2.6.1.1],     kro:BVG79_00430 [4.4.1.8])      => [2.1.3.2]
    (kvu:EIO_1890 [2.6.1.1],        kvu:EIO_1794 [4.4.1.8])         => [2.1.3.2]
    (lar:lam_382 [2.1.3.2],         lar:lam_062 [2.1.3.3])          => [2.1.3.2]
    (lcc:B488_09550 [2.1.3.2],      lcc:B488_01490 [2.1.3.3])       => [2.1.3.2]
    (magn:WV31_17010 [2.1.3.2],     magn:WV31_14345 [2.1.3.3])      => [2.1.3.2]
    (magq:MGMAQ_0620 [2.1.3.2],     magq:MGMAQ_3518 [2.1.3.3])      => [2.1.3.2]
    (magq:MGMAQ_3208 [2.6.1.1],     magq:MGMAQ_2975 [2.6.1.9])      => [2.1.3.2]
    (magx:XM1_1851 [2.1.3.2],       magx:XM1_1245 [2.1.3.3])        => [2.1.3.2]
    (mam:Mesau_03989 [2.1.3.2],     mam:Mesau_06027 [2.1.3.3])      => [2.1.3.2]
    (mamo:A6B35_18600 [2.1.3.2],    mamo:A6B35_07965 [2.1.3.3])     => [2.1.3.2]
    (mcg:GL4_2216 [2.1.3.2],        mcg:GL4_0837 [2.1.3.3])         => [2.1.3.2]
    (mci:Mesci_4015 [2.1.3.2],      mci:Mesci_5986 [2.1.3.3])       => [2.1.3.2]
    (mes:Meso_2107 [2.6.1.1],       mes:Meso_3736 [4.4.1.8])        => [2.1.3.2]
    (mes:Meso_3626 [2.6.1.1],       mes:Meso_3736 [4.4.1.8])        => [2.1.3.2]
    (meso:BSQ44_13150 [2.1.3.2],    meso:BSQ44_20220 [2.1.3.3])     => [2.1.3.2]
    (mesw:A9K65_022370 [2.1.3.2],   mesw:A9K65_032115 [2.1.3.3])    => [2.1.3.2]
    (met:M446_4349 [2.1.3.2],       met:M446_6535 [2.1.3.3])        => [2.1.3.2]
    (meta:Y590_16200 [2.1.3.2],     meta:Y590_20310 [2.1.3.3])      => [2.1.3.2]
    (mex:Mext_3312 [2.1.3.2],       mex:Mext_4076 [2.1.3.3])        => [2.1.3.2]
    (mgy:MGMSRv2__0292 [2.1.3.2],   mgy:MGMSRv2__2971 [2.1.3.3])    => [2.1.3.2]
    (mln:A9174_22265 [2.1.3.2],     mln:A9174_33375 [2.1.3.3])      => [2.1.3.2]
    (mlo:mlr0686 [2.1.3.2],         mlo:mlr5647 [2.1.3.3])          => [2.1.3.2]
    (mno:Mnod_3310 [2.1.3.2],       mno:Mnod_7456 [2.1.3.3])        => [2.1.3.2]
    (mop:Mesop_4222 [2.1.3.2],      mop:Mesop_6633 [2.1.3.3])       => [2.1.3.2]
    (mor:MOC_1226 [2.1.3.2],        mor:MOC_2743 [2.1.3.3])         => [2.1.3.2]
    (mphy:MCBMB27_00603 [2.1.3.2],  mphy:MCBMB27_01933 [2.1.3.3])   => [2.1.3.2]
    (mpo:Mpop_3512 [2.1.3.2],       mpo:Mpop_4557 [2.1.3.3])        => [2.1.3.2]
    (mrd:Mrad2831_1010 [2.1.3.2],   mrd:Mrad2831_2317 [2.1.3.3])    => [2.1.3.2]
    (mtw:CQW49_10330 [2.1.3.2],     mtw:CQW49_13055 [2.1.3.3])      => [2.1.3.2]
    (mza:B2G69_24115 [2.1.3.2],     mza:B2G69_02290 [2.1.3.3])      => [2.1.3.2]
    (nao:Y958_18085 [2.1.3.2],      nao:Y958_12640 [2.1.3.3])       => [2.1.3.2]
    (nar:Saro_3061 [2.1.3.2],       nar:Saro_3140 [2.1.3.3])        => [2.1.3.2]
    (nch:A0U93_01120 [2.1.3.2],     nch:A0U93_08020 [2.1.3.3])      => [2.1.3.2]
    (ngl:RG1141_CH12190 [2.1.3.2],  ngl:RG1141_CH01240 [2.1.3.3])   => [2.1.3.2]
    (nha:Nham_2282 [2.1.3.2],       nha:Nham_0643 [2.1.3.3])        => [2.1.3.2]
    (nwi:Nwi_2007 [2.1.3.2],        nwi:Nwi_0514 [2.1.3.3])         => [2.1.3.2]
    (oca:OCAR_5788 [2.1.3.2],       oca:OCAR_4655 [2.1.3.3])        => [2.1.3.2]
    (paru:CYR75_02630 [2.6.1.1],    paru:CYR75_03070 [2.6.1.9])     => [2.1.3.2]
    (pgd:Gal_01277 [2.6.1.1],       pgd:Gal_00220 [4.4.1.8])        => [2.1.3.2]
    (pgv:SL003B_1850 [2.1.3.2],     pgv:SL003B_3272 [2.1.3.3])      => [2.1.3.2]
    (pla:Plav_2836 [2.1.3.2],       pla:Plav_0403 [2.1.3.3])        => [2.1.3.2]
    (ppic:PhaeoP14_01936 [2.6.1.1], ppic:PhaeoP14_02967 [4.4.1.8])  => [2.1.3.2]
    (psf:PSE_3779 [2.1.3.2],        psf:PSE_1697 [2.1.3.3])         => [2.1.3.2]
    (pub:SAR11_0080 [2.6.1.1],      pub:SAR11_0216 [2.6.1.9])       => [2.1.3.2]
    (pzh:CX676_01205 [2.6.1.1],     pzh:CX676_11515 [4.4.1.8])      => [2.1.3.2]
    (rdi:CMV14_11955 [2.1.3.2],     rdi:CMV14_07710 [2.1.3.3])      => [2.1.3.2]
    (red:roselon_00687 [2.1.3.2],   red:roselon_01922 [2.1.3.3])    => [2.1.3.2]
    (rga:RGR602_CH01510 [2.1.3.2],  rga:RGR602_CH00549 [2.1.3.3])   => [2.1.3.2]
    (rgi:RGI145_07825 [2.1.3.2],    rgi:RGI145_04760 [2.1.3.3])     => [2.1.3.2]
    (rgi:RGI145_22060 [2.6.1.1],    rgi:RGI145_01290 [2.6.1.9])     => [2.1.3.2]
    (rhl:LPU83_1698 [2.1.3.2],      rhl:LPU83_0649 [2.1.3.3])       => [2.1.3.2]
    (rht:NT26_1305 [2.1.3.2],       rht:NT26_0083 [2.1.3.3])        => [2.1.3.2]
    (rhz:RHPLAN_40050 [2.1.3.2],    rhz:RHPLAN_64680 [2.1.3.3])     => [2.1.3.2]
    (rir:BN877_I1288 [2.1.3.2],     rir:BN877_I0433 [2.1.3.3])      => [2.1.3.2]
    (ros:CTJ15_09505 [2.1.3.2],     ros:CTJ15_12635 [2.1.3.3])      => [2.1.3.2]
    (rpm:RSPPHO_02455 [2.1.3.2],    rpm:RSPPHO_03098 [2.1.3.3])     => [2.1.3.2]
    (rru:Rru_A3190 [2.1.3.2],       rru:Rru_A3276 [2.1.3.3])        => [2.1.3.2]
    (sagu:CDO87_07195 [2.6.1.1],    sagu:CDO87_06360 [4.4.1.8])     => [2.1.3.2]
    (sal:Sala_0924 [2.1.3.2],       sal:Sala_1358 [2.1.3.3])        => [2.1.3.2]
    (same:SAMCFNEI73_pC0840 [2.6.1.1],      same:SAMCFNEI73_Ch2931 [4.4.1.8])       => [2.1.3.2]
    (sch:Sphch_2981 [2.1.3.2],      sch:Sphch_2663 [2.1.3.3])       => [2.1.3.2]
    (sclo:SCLO_1029760 [2.1.3.2],   sclo:SCLO_1016020 [2.1.3.3])    => [2.1.3.2]
    (sgi:SGRAN_2628 [2.1.3.2],      sgi:SGRAN_2116 [2.1.3.3])       => [2.1.3.2]
    (shyd:CJD35_10725 [2.1.3.2],    shyd:CJD35_03045 [2.1.3.3])     => [2.1.3.2]
    (sil:SPO0584 [2.6.1.1],         sil:SPO1468 [2.6.1.9])          => [2.1.3.2]
    (sil:SPO0584 [2.6.1.1],         sil:SPO3177 [2.6.1.9])          => [2.1.3.2]
    (sil:SPO0584 [2.6.1.1],         sil:SPO3220 [4.4.1.8])          => [2.1.3.2]
    (sinb:SIDU_01275 [2.1.3.2],     sinb:SIDU_12520 [2.1.3.3])      => [2.1.3.2]
    (six:BSY16_1510 [2.1.3.2],      six:BSY16_2700 [2.1.3.3])       => [2.1.3.2]
    (sjp:SJA_C1-27100 [2.1.3.2],    sjp:SJA_C1-30650 [2.1.3.3])     => [2.1.3.2]
    (sme:SMc01360 [2.1.3.2],        sme:SMc02137 [2.1.3.3])         => [2.1.3.2]
    (sno:Snov_1518 [2.1.3.2],       sno:Snov_4491 [2.1.3.3])        => [2.1.3.2]
    (sphb:EP837_02230 [2.1.3.2],    sphb:EP837_02025 [2.1.3.3])     => [2.1.3.2]
    (sphd:HY78_23655 [2.1.3.2],     sphd:HY78_19530 [2.1.3.3])      => [2.1.3.2]
    (sphj:BSL82_03985 [2.1.3.2],    sphj:BSL82_03265 [2.1.3.3])     => [2.1.3.2]
    (sphk:SKP52_12045 [2.1.3.2],    sphk:SKP52_07715 [2.1.3.3])     => [2.1.3.2]
    (sphm:G432_00710 [2.1.3.2],     sphm:G432_02100 [2.1.3.3])      => [2.1.3.2]
    (sphr:BSY17_2353 [2.1.3.2],     sphr:BSY17_821 [2.1.3.3])       => [2.1.3.2]
    (spht:K426_16330 [2.1.3.2],     spht:K426_05450 [2.1.3.3])      => [2.1.3.2]
    (spkc:KC8_01860 [2.1.3.2],      spkc:KC8_07830 [2.1.3.3])       => [2.1.3.2]
    (splk:AV944_14140 [2.1.3.2],    splk:AV944_15640 [2.1.3.3])     => [2.1.3.2]
    (splm:BXU08_01330 [2.1.3.2],    splm:BXU08_09540 [2.1.3.3])     => [2.1.3.2]
    (ssan:NX02_05020 [2.1.3.2],     ssan:NX02_16150 [2.1.3.3])      => [2.1.3.2]
    (ssy:SLG_20620 [2.1.3.2],       ssy:SLG_34380 [2.1.3.3])        => [2.1.3.2]
    (stax:MC45_08595 [2.1.3.2],     stax:MC45_09110 [2.1.3.3])      => [2.1.3.2]
    (ster:AOA14_16510 [2.1.3.2],    ster:AOA14_17110 [2.1.3.3])     => [2.1.3.2]
    (suam:BOO69_18100 [2.6.1.1],    suam:BOO69_01585 [4.4.1.8])     => [2.1.3.2]
    (swi:Swit_0602 [2.1.3.2],       swi:Swit_1408 [2.1.3.3])        => [2.1.3.2]
    (sya:A6768_14705 [2.1.3.2],     sya:A6768_16035 [2.1.3.3])      => [2.1.3.2]
    (syb:TZ53_14000 [2.1.3.2],      syb:TZ53_02415 [2.1.3.3])       => [2.1.3.2]
    (thac:CSC3H3_08600 [2.1.3.2],   thac:CSC3H3_00195 [2.1.3.3])    => [2.1.3.2]
    (thal:A1OE_1459 [2.1.3.2],      thal:A1OE_555 [2.1.3.3])        => [2.1.3.2]
    (thd:BHV28_06860 [2.1.3.2],     thd:BHV28_11810 [2.1.3.3])      => [2.1.3.2]
    (txi:TH3_08955 [2.1.3.2],       txi:TH3_00210 [2.1.3.3])        => [2.1.3.2]
    (txi:TH3_16445 [2.6.1.1],       txi:TH3_17770 [2.6.1.9])        => [2.1.3.2]
    (zmo:ZMO0791 [2.1.3.2],         zmo:ZMO0409 [2.1.3.3])          => [2.1.3.2]
    (aace:A0U92_13605 [4.1.3.-],    aace:A0U92_13610 [5.3.1.16])    => [2.4.2.-]
    (aay:WYH_03064 [4.1.3.-],       aay:WYH_03062 [5.3.1.16])       => [2.4.2.-]
    (abg:Asbog_01382 [4.1.3.-],     abg:Asbog_01381 [5.3.1.16])     => [2.4.2.-]
    (abs:AZOBR_10373 [4.1.3.-],     abs:AZOBR_10372 [5.3.1.16])     => [2.4.2.-]
    (acr:Acry_1417 [4.1.3.-],       acr:Acry_1416 [5.3.1.16])       => [2.4.2.-]
    (aht:ANTHELSMS3_04067 [4.1.3.-],aht:ANTHELSMS3_04065 [5.3.1.16])=> [2.4.2.-]
    (ahu:A6A40_12250 [4.1.3.-],     ahu:A6A40_12245 [5.3.1.16])     => [2.4.2.-]
    (amv:ACMV_14640 [4.1.3.-],      amv:ACMV_14630 [5.3.1.16])      => [2.4.2.-]
    (apm:HIMB5_00013870 [4.1.3.-],  apm:HIMB5_00013860 [5.3.1.16])  => [2.4.2.-]
    (apom:CPF11_07530 [4.1.3.-],    apom:CPF11_07535 [5.3.1.16])    => [2.4.2.-]
    (apt:APA01_26550 [4.1.3.-],     apt:APA01_26540 [5.3.1.16])     => [2.4.2.-]
    (asv:WG31_13100 [4.1.3.-],      asv:WG31_13095 [5.3.1.16])      => [2.4.2.-]
    (asz:ASN_1651 [4.1.3.-],        asz:ASN_1652 [5.3.1.16])        => [2.4.2.-]
    (ati:AL072_04630 [4.1.3.-],     ati:AL072_04625 [5.3.1.16])     => [2.4.2.-]
    (ato:CIW82_03890 [4.1.3.-],     ato:CIW82_03885 [5.3.1.16])     => [2.4.2.-]
    (atu:Atu0039 [4.1.3.-],         atu:Atu0040 [5.3.1.16])         => [2.4.2.-]
    (aua:M673_01985 [4.1.3.-],      aua:M673_01975 [5.3.1.16])      => [2.4.2.-]
    (avi:Avi_0037 [4.1.3.-],        avi:Avi_0036 [5.3.1.16])        => [2.4.2.-]
    (azc:AZC_4498 [4.1.3.-],        azc:AZC_4499 [5.3.1.16])        => [2.4.2.-]
    (azl:AZL_028780 [4.1.3.-],      azl:AZL_028790 [5.3.1.16])      => [2.4.2.-]
    (bapi:BBC0122_000960 [4.1.3.-], bapi:BBC0122_000970 [5.3.1.16]) => [2.4.2.-]
    (bcet:V910_102056 [4.1.3.-],    bcet:V910_102057 [5.3.1.16])    => [2.4.2.-]
    (bcs:BCAN_A2131 [4.1.3.-],      bcs:BCAN_A2130 [5.3.1.16])      => [2.4.2.-]
    (bic:LMTR13_00085 [4.1.3.-],    bic:LMTR13_00080 [5.3.1.16])    => [2.4.2.-]
    (bid:Bind_0243 [4.1.3.-],       bid:Bind_0246 [5.3.1.16])       => [2.4.2.-]
    (bja:blr0654 [4.1.3.-],         bja:blr0653 [5.3.1.16])         => [2.4.2.-]
    (bme:BMEI2041 [4.1.3.-],        bme:BMEI2042 [5.3.1.16])        => [2.4.2.-]
    (bmf:BAB1_2086 [4.1.3.-],       bmf:BAB1_2085 [5.3.1.16])       => [2.4.2.-]
    (bmr:BMI_I2107 [4.1.3.-],       bmr:BMI_I2106 [5.3.1.16])       => [2.4.2.-]
    (bms:BR2085 [4.1.3.-],          bms:BR2084 [5.3.1.16])          => [2.4.2.-]
    (bov:BOV_2005 [4.1.3.-],        bov:BOV_2004 [5.3.1.16])        => [2.4.2.-]
    (bpp:BPI_I2143 [4.1.3.-],       bpp:BPI_I2142 [5.3.1.16])       => [2.4.2.-]
    (brad:BF49_0189 [4.1.3.-],      brad:BF49_0190 [5.3.1.16])      => [2.4.2.-]
    (bvl:BF3285c1_0776 [4.1.3.-],   bvl:BF3285c1_0775 [5.3.1.16])   => [2.4.2.-]
    (ccr:CC_3737 [4.1.3.-],         ccr:CC_3736 [5.3.1.16])         => [2.4.2.-]
    (chq:AQ619_17935 [4.1.3.-],     chq:AQ619_17940 [5.3.1.16])     => [2.4.2.-]
    (cid:P73_3233 [4.1.3.-],        cid:P73_3232 [5.3.1.16])        => [2.4.2.-]
    (cmag:CBW24_03755 [4.1.3.-],    cmag:CBW24_04905 [5.3.1.16])    => [2.4.2.-]
    (cmb:CSW64_20760 [4.1.3.-],     cmb:CSW64_20765 [5.3.1.16])     => [2.4.2.-]
    (con:TQ29_05850 [4.1.3.-],      con:TQ29_05855 [5.3.1.16])      => [2.4.2.-]
    (deq:XM25_17710 [4.1.3.-],      deq:XM25_17700 [5.3.1.16])      => [2.4.2.-]
    (don:BSK21_03860 [4.1.3.-],     don:BSK21_04160 [5.3.1.16])     => [2.4.2.-]
    (dsh:Dshi_2576 [4.1.3.-],       dsh:Dshi_2578 [5.3.1.16])       => [2.4.2.-]
    (efv:CHH26_03115 [4.1.3.-],     efv:CHH26_03110 [5.3.1.16])     => [2.4.2.-]
    (esj:SJ05684_c34190 [4.1.3.-],  esj:SJ05684_c34200 [5.3.1.16])  => [2.4.2.-]
    (gal:A0U94_09400 [4.1.3.-],     gal:A0U94_09395 [5.3.1.16])     => [2.4.2.-]
    (gbe:GbCGDNIH1_2230 [4.1.3.-],  gbe:GbCGDNIH1_2231 [5.3.1.16])  => [2.4.2.-]
    (gdi:GDI0069 [4.1.3.-],         gdi:GDI0070 [5.3.1.16])         => [2.4.2.-]
    (gox:GOX0483 [4.1.3.-],         gox:GOX0482 [5.3.1.16])         => [2.4.2.-]
    (gxl:H845_2478 [4.1.3.-],       gxl:H845_2477 [5.3.1.16])       => [2.4.2.-]
    (gxy:GLX_12390 [4.1.3.-],       gxy:GLX_12380 [5.3.1.16])       => [2.4.2.-]
    (hba:Hbal_3138 [4.1.3.-],       hba:Hbal_3135 [5.3.1.16])       => [2.4.2.-]
    (hbc:AEM38_15740 [4.1.3.-],     hbc:AEM38_15735 [5.3.1.16])     => [2.4.2.-]
    (hdn:Hden_3358 [4.1.3.-],       hdn:Hden_3354 [5.3.1.16])       => [2.4.2.-]
    (hne:HNE_0066 [4.1.3.-],        hne:HNE_0070 [5.3.1.16])        => [2.4.2.-]
    (hni:W911_00785 [4.1.3.-],      hni:W911_00790 [5.3.1.16])      => [2.4.2.-]
    (jan:Jann_2795 [4.1.3.-],       jan:Jann_2792 [5.3.1.16])       => [2.4.2.-]
    (kba:A0U89_05695 [4.1.3.-],     kba:A0U89_05700 [5.3.1.16])     => [2.4.2.-]
    (keu:S101446_01785 [4.1.3.-],   keu:S101446_01784 [5.3.1.16])   => [2.4.2.-]
    (kna:B0W47_06610 [4.1.3.-],     kna:B0W47_06605 [5.3.1.16])     => [2.4.2.-]
    (kro:BVG79_02005 [4.1.3.-],     kro:BVG79_02004 [5.3.1.16])     => [2.4.2.-]
    (kvu:EIO_2330 [4.1.3.-],        kvu:EIO_2329 [5.3.1.16])        => [2.4.2.-]
    (labr:CHH27_19765 [4.1.3.-],    labr:CHH27_19760 [5.3.1.16])    => [2.4.2.-]
    (lagg:B0E33_12120 [4.1.3.-],    lagg:B0E33_12125 [5.3.1.16])    => [2.4.2.-]
    (lap:ACP90_00620 [4.1.3.-],     lap:ACP90_00625 [5.3.1.16])     => [2.4.2.-]
    (lcc:B488_13520 [4.1.3.-],      lcc:B488_13510 [5.3.1.16])      => [2.4.2.-]
    (lvs:LOKVESSMR4R_00974 [4.1.3.-],       lvs:LOKVESSMR4R_00975 [5.3.1.16])       => [2.4.2.-]
    (mag:amb4531 [4.1.3.-],         mag:amb4532 [5.3.1.16])         => [2.4.2.-]
    (magn:WV31_12385 [4.1.3.-],     magn:WV31_12390 [5.3.1.16])     => [2.4.2.-]
    (magq:MGMAQ_3837 [4.1.3.-],     magq:MGMAQ_3836 [5.3.1.16])     => [2.4.2.-]
    (magx:XM1_0814 [4.1.3.-],       magx:XM1_0815 [5.3.1.16])       => [2.4.2.-]
    (malg:MALG_00137 [4.1.3.-],     malg:MALG_00138 [5.3.1.16])     => [2.4.2.-]
    (mam:Mesau_00627 [4.1.3.-],     mam:Mesau_00625 [5.3.1.16])     => [2.4.2.-]
    (maqu:Maq22A_1p33375 [4.1.3.-], maqu:Maq22A_1p33365 [5.3.1.16]) => [2.4.2.-]
    (mcg:GL4_0299 [4.1.3.-],        mcg:GL4_0301 [5.3.1.16])        => [2.4.2.-]
    (mci:Mesci_0476 [4.1.3.-],      mci:Mesci_0478 [5.3.1.16])      => [2.4.2.-]
    (meso:BSQ44_02025 [4.1.3.-],    meso:BSQ44_02015 [5.3.1.16])    => [2.4.2.-]
    (mesw:A9K65_002385 [4.1.3.-],   mesw:A9K65_002395 [5.3.1.16])   => [2.4.2.-]
    (met:M446_6790 [4.1.3.-],       met:M446_6791 [5.3.1.16])       => [2.4.2.-]
    (mgm:Mmc1_3156 [4.1.3.-],       mgm:Mmc1_3155 [5.3.1.16])       => [2.4.2.-]
    (mgy:MGMSRv2__3491 [4.1.3.-],   mgy:MGMSRv2__3492 [5.3.1.16])   => [2.4.2.-]
    (mln:A9174_02290 [4.1.3.-],     mln:A9174_02300 [5.3.1.16])     => [2.4.2.-]
    (mlo:mlr5016 [4.1.3.-],         mlo:mlr5014 [5.3.1.16])         => [2.4.2.-]
    (mno:Mnod_7529 [4.1.3.-],       mno:Mnod_7530 [5.3.1.16])       => [2.4.2.-]
    (mphy:MCBMB27_05651 [4.1.3.-],  mphy:MCBMB27_05650 [5.3.1.16])  => [2.4.2.-]
    (mpo:Mpop_2483 [4.1.3.-],       mpo:Mpop_2481 [5.3.1.16])       => [2.4.2.-]
    (msc:BN69_0826 [4.1.3.-],       msc:BN69_0827 [5.3.1.16])       => [2.4.2.-]
    (nao:Y958_00600 [4.1.3.-],      nao:Y958_00605 [5.3.1.16])      => [2.4.2.-]
    (nch:A0U93_01905 [4.1.3.-],     nch:A0U93_01910 [5.3.1.16])     => [2.4.2.-]
    (nha:Nham_0126 [4.1.3.-],       nha:Nham_0125 [5.3.1.16])       => [2.4.2.-]
    (nre:BES08_17140 [4.1.3.-],     nre:BES08_17130 [5.3.1.16])     => [2.4.2.-]
    (nwi:Nwi_0122 [4.1.3.-],        nwi:Nwi_0123 [5.3.1.16])        => [2.4.2.-]
    (oan:Oant_0834 [4.1.3.-],       oan:Oant_0835 [5.3.1.16])       => [2.4.2.-]
    (oca:OCAR_4399 [4.1.3.-],       oca:OCAR_4398 [5.3.1.16])       => [2.4.2.-]
    (och:CES85_2607 [4.1.3.-],      och:CES85_2606 [5.3.1.16])      => [2.4.2.-]
    (ops:A8A54_17550 [4.1.3.-],     ops:A8A54_17545 [5.3.1.16])     => [2.4.2.-]
    (paby:Ga0080574_TMP1305 [4.1.3.-],      paby:Ga0080574_TMP1334 [5.3.1.16])      => [2.4.2.-]
    (pami:JCM7686_0889 [4.1.3.-],   pami:JCM7686_0891 [5.3.1.16])   => [2.4.2.-]
    (paro:CUV01_15625 [4.1.3.-],    paro:CUV01_15640 [5.3.1.16])    => [2.4.2.-]
    (paru:CYR75_00985 [4.1.3.-],    paru:CYR75_00995 [5.3.1.16])    => [2.4.2.-]
    (pcon:B0A89_00105 [4.1.3.-],    pcon:B0A89_13745 [5.3.1.16])    => [2.4.2.-]
    (pde:Pden_1887 [4.1.3.-],       pde:Pden_1886 [5.3.1.16])       => [2.4.2.-]
    (pel:SAR11G3_00409 [4.1.3.-],   pel:SAR11G3_00408 [5.3.1.16])   => [2.4.2.-]
    (pga:PGA1_c09240 [4.1.3.-],     pga:PGA1_c09270 [5.3.1.16])     => [2.4.2.-]
    (pgd:Gal_02567 [4.1.3.-],       pgd:Gal_02564 [5.3.1.16])       => [2.4.2.-]
    (pgv:SL003B_0013 [4.1.3.-],     pgv:SL003B_0012 [5.3.1.16])     => [2.4.2.-]
    (php:PhaeoP97_00889 [4.1.3.-],  php:PhaeoP97_00893 [5.3.1.16])  => [2.4.2.-]
    (pht:BLM14_18785 [4.1.3.-],     pht:BLM14_18790 [5.3.1.16])     => [2.4.2.-]
    (pla:Plav_1233 [4.1.3.-],       pla:Plav_1234 [5.3.1.16])       => [2.4.2.-]
    (pphr:APZ00_04685 [4.1.3.-],    pphr:APZ00_04690 [5.3.1.16])    => [2.4.2.-]
    (ppic:PhaeoP14_00844 [4.1.3.-], ppic:PhaeoP14_00847 [5.3.1.16]) => [2.4.2.-]
    (psf:PSE_0556 [4.1.3.-],        psf:PSE_0557 [5.3.1.16])        => [2.4.2.-]
    (psin:CAK95_07965 [4.1.3.-],    psin:CAK95_07970 [5.3.1.16])    => [2.4.2.-]
    (pub:SAR11_0329 [4.1.3.-],      pub:SAR11_0330 [5.3.1.16])      => [2.4.2.-]
    (pye:A6J80_06335 [4.1.3.-],     pye:A6J80_06330 [5.3.1.16])     => [2.4.2.-]
    (pzh:CX676_03395 [4.1.3.-],     pzh:CX676_03405 [5.3.1.16])     => [2.4.2.-]
    (pzu:PHZ_c0043 [4.1.3.-],       pzu:PHZ_c0042 [5.3.1.16])       => [2.4.2.-]
    (rbg:BG454_15835 [4.1.3.-],     rbg:BG454_13580 [5.3.1.16])     => [2.4.2.-]
    (rbm:TEF_21450 [4.1.3.-],       rbm:TEF_21445 [5.3.1.16])       => [2.4.2.-]
    (rce:RC1_3299 [4.1.3.-],        rce:RC1_3298 [5.3.1.16])        => [2.4.2.-]
    (rcp:RCAP_rcc01153 [4.1.3.-],   rcp:RCAP_rcc01154 [5.3.1.16])   => [2.4.2.-]
    (rde:RD1_3561 [4.1.3.-],        rde:RD1_3560 [5.3.1.16])        => [2.4.2.-]
    (rdi:CMV14_01430 [4.1.3.-],     rdi:CMV14_01425 [5.3.1.16])     => [2.4.2.-]
    (rhc:RGUI_3765 [4.1.3.-],       rhc:RGUI_3766 [5.3.1.16])       => [2.4.2.-]
    (rhm:B5V46_12225 [4.1.3.-],     rhm:B5V46_12230 [5.3.1.16])     => [2.4.2.-]
    (rhn:AMJ98_CH00042 [4.1.3.-],   rhn:AMJ98_CH00043 [5.3.1.16])   => [2.4.2.-]
    (rhp:LPB142_13045 [4.1.3.-],    rhp:LPB142_13040 [5.3.1.16])    => [2.4.2.-]
    (rht:NT26_3871 [4.1.3.-],       rht:NT26_3872 [5.3.1.16])       => [2.4.2.-]
    (rhx:AMK02_CH00042 [4.1.3.-],   rhx:AMK02_CH00043 [5.3.1.16])   => [2.4.2.-]
    (rle:RL0042 [4.1.3.-],          rle:RL0043 [5.3.1.16])          => [2.4.2.-]
    (rli:RLO149_c026220 [4.1.3.-],  rli:RLO149_c026210 [5.3.1.16])  => [2.4.2.-]
    (rmb:K529_003635 [4.1.3.-],     rmb:K529_003650 [5.3.1.16])     => [2.4.2.-]
    (rmm:ROSMUCSMR3_00832 [4.1.3.-],rmm:ROSMUCSMR3_00834 [5.3.1.16])=> [2.4.2.-]
    (rpha:AMC79_CH00044 [4.1.3.-],  rpha:AMC79_CH00045 [5.3.1.16])  => [2.4.2.-]
    (rsp:RSP_2242 [4.1.3.-],        rsp:RSP_2243 [5.3.1.16])        => [2.4.2.-]
    (rsu:NHU_01297 [4.1.3.-],       rsu:NHU_01296 [5.3.1.16])       => [2.4.2.-]
    (rva:Rvan_2397 [4.1.3.-],       rva:Rvan_2017 [5.3.1.16])       => [2.4.2.-]
    (sagu:CDO87_01905 [4.1.3.-],    sagu:CDO87_01890 [5.3.1.16])    => [2.4.2.-]
    (same:SAMCFNEI73_Ch0051 [4.1.3.-],      same:SAMCFNEI73_Ch0052 [5.3.1.16])      => [2.4.2.-]
    (sil:SPO1156 [4.1.3.-],         sil:SPO1158 [5.3.1.16])         => [2.4.2.-]
    (sit:TM1040_2041 [4.1.3.-],     sit:TM1040_2039 [5.3.1.16])     => [2.4.2.-]
    (smd:Smed_3259 [4.1.3.-],       smd:Smed_3260 [5.3.1.16])       => [2.4.2.-]
    (sme:SMc02569 [4.1.3.-],        sme:SMc02570 [5.3.1.16])        => [2.4.2.-]
    (sno:Snov_3830 [4.1.3.-],       sno:Snov_3829 [5.3.1.16])       => [2.4.2.-]
    (sphd:HY78_11910 [4.1.3.-],     sphd:HY78_11915 [5.3.1.16])     => [2.4.2.-]
    (sphj:BSL82_06980 [4.1.3.-],    sphj:BSL82_06975 [5.3.1.16])    => [2.4.2.-]
    (sphm:G432_10435 [4.1.3.-],     sphm:G432_10430 [5.3.1.16])     => [2.4.2.-]
    (sphq:BWQ93_14380 [4.1.3.-],    sphq:BWQ93_14375 [5.3.1.16])    => [2.4.2.-]
    (sphy:CHN51_10005 [4.1.3.-],    sphy:CHN51_10000 [5.3.1.16])    => [2.4.2.-]
    (spkc:KC8_14260 [4.1.3.-],      spkc:KC8_14255 [5.3.1.16])      => [2.4.2.-]
    (splm:BXU08_11030 [4.1.3.-],    splm:BXU08_11025 [5.3.1.16])    => [2.4.2.-]
    (spse:SULPSESMR1_01976 [4.1.3.-],       spse:SULPSESMR1_01975 [5.3.1.16])       => [2.4.2.-]
    (suam:BOO69_12025 [4.1.3.-],    suam:BOO69_12020 [5.3.1.16])    => [2.4.2.-]
    (swi:Swit_2720 [4.1.3.-],       swi:Swit_2719 [5.3.1.16])       => [2.4.2.-]
    (thw:BMG03_06920 [4.1.3.-],     thw:BMG03_06985 [5.3.1.16])     => [2.4.2.-]
    (tom:BWR18_09370 [4.1.3.-],     tom:BWR18_09385 [5.3.1.16])     => [2.4.2.-]
    (tpro:Ga0080559_TMP2944 [4.1.3.-],      tpro:Ga0080559_TMP693 [5.3.1.16])       => [2.4.2.-]
    (txi:TH3_20220 [4.1.3.-],       txi:TH3_20225 [5.3.1.16])       => [2.4.2.-]
    (yan:AYJ57_10320 [4.1.3.-],     yan:AYJ57_10360 [5.3.1.16])     => [2.4.2.-]
    (zmo:ZMO1500 [4.1.3.-],         zmo:ZMO1501 [5.3.1.16])         => [2.4.2.-]
    (aak:AA2016_6521 [2.2.1.1],     aak:AA2016_4845 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (abs:AZOBR_p310084 [2.2.1.1],   abs:AZOBR_p1140022 [2.2.1.7])   => [5.1.3.1, 5.3.1.6]
    (abs:AZOBR_p310084 [2.2.1.1],   abs:AZOBR_p140100 [2.2.1.7])    => [5.1.3.1, 5.3.1.6]
    (acr:Acry_0718 [2.2.1.1],       acr:Acry_1833 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (agc:BSY240_2264 [2.2.1.1],     agc:BSY240_1694 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (agc:BSY240_2264 [2.2.1.1],     agc:BSY240_3636 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (agr:AGROH133_14223 [2.2.1.1],  agr:AGROH133_04351 [2.2.1.7])   => [5.1.3.1, 5.3.1.6]
    (agr:AGROH133_15069 [2.2.1.1],  agr:AGROH133_04351 [2.2.1.7])   => [5.1.3.1, 5.3.1.6]
    (aht:ANTHELSMS3_02354 [2.2.1.1],aht:ANTHELSMS3_02093 [2.2.1.7]) => [5.1.3.1, 5.3.1.6]
    (amv:ACMV_11540 [2.2.1.1],      amv:ACMV_20740 [2.2.1.7])       => [5.1.3.1, 5.3.1.6]
    (aol:S58_25160 [2.2.1.1],       aol:S58_53660 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (apc:HIMB59_00006560 [2.2.1.1], apc:HIMB59_00009760 [2.2.1.7])  => [5.1.3.1, 5.3.1.6]
    (ara:Arad_8184 [2.2.1.1],       ara:Arad_1198 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (aro:B0909_03510 [2.2.1.1],     aro:B0909_09755 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (ati:AL072_26050 [2.2.1.1],     ati:AL072_16870 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (atu:Atu1902 [2.2.1.1],         atu:Atu0745 [2.2.1.7])          => [5.1.3.1, 5.3.1.6]
    (azl:AZL_a04640 [2.2.1.1],      azl:AZL_c00990 [2.2.1.7])       => [5.1.3.1, 5.3.1.6]
    (bbt:BBta_3269 [2.2.1.1],       bbt:BBta_2479 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (bbt:BBta_5637 [2.2.1.1],       bbt:BBta_2479 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (bic:LMTR13_32315 [2.2.1.1],    bic:LMTR13_30360 [2.2.1.7])     => [5.1.3.1, 5.3.1.6]
    (bja:blr2169 [2.2.1.1],         bja:bll2651 [2.2.1.7])          => [5.1.3.1, 5.3.1.6]
    (bja:blr5427 [2.2.1.1],         bja:bll2651 [2.2.1.7])          => [5.1.3.1, 5.3.1.6]
    (bju:BJ6T_76830 [2.2.1.1],      bju:BJ6T_71490 [2.2.1.7])       => [5.1.3.1, 5.3.1.6]
    (bos:BSY19_638 [2.2.1.1],       bos:BSY19_1705 [2.2.1.7])       => [5.1.3.1, 5.3.1.6]
    (bos:BSY19_638 [2.2.1.1],       bos:BSY19_4068 [2.2.1.7])       => [5.1.3.1, 5.3.1.6]
    (bos:BSY19_984 [2.2.1.1],       bos:BSY19_1705 [2.2.1.7])       => [5.1.3.1, 5.3.1.6]
    (bos:BSY19_984 [2.2.1.1],       bos:BSY19_4068 [2.2.1.7])       => [5.1.3.1, 5.3.1.6]
    (bra:BRADO4763 [2.2.1.1],       bra:BRADO2161 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (bra:BRADO5170 [2.2.1.1],       bra:BRADO2161 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (brad:BF49_6202 [2.2.1.1],      brad:BF49_2076 [2.2.1.7])       => [5.1.3.1, 5.3.1.6]
    (brc:BCCGELA001_13895 [2.2.1.1],brc:BCCGELA001_11565 [2.2.1.7]) => [5.1.3.1, 5.3.1.6]
    (brc:BCCGELA001_22815 [2.2.1.1],brc:BCCGELA001_11565 [2.2.1.7]) => [5.1.3.1, 5.3.1.6]
    (bro:BRAD285_2061 [2.2.1.1],    bro:BRAD285_5093 [2.2.1.7])     => [5.1.3.1, 5.3.1.6]
    (brs:S23_22520 [2.2.1.1],       brs:S23_53210 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (bvr:BVIR_1972 [2.2.1.1],       bvr:BVIR_1955 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (bvv:BHK69_01915 [2.2.1.1],     bvv:BHK69_11885 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (bvv:BHK69_07175 [2.2.1.1],     bvv:BHK69_11885 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (bvv:BHK69_30485 [2.2.1.1],     bvv:BHK69_11885 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (cbot:ATE48_13255 [2.2.1.1],    cbot:ATE48_03035 [2.2.1.7])     => [5.1.3.1, 5.3.1.6]
    (cmar:IMCC12053_2208 [2.2.1.1], cmar:IMCC12053_1854 [2.2.1.7])  => [5.1.3.1, 5.3.1.6]
    (cmar:IMCC12053_755 [2.2.1.1],  cmar:IMCC12053_1854 [2.2.1.7])  => [5.1.3.1, 5.3.1.6]
    (cmb:CSW64_01295 [2.2.1.1],     cmb:CSW64_15595 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (don:BSK21_15615 [2.2.1.1],     don:BSK21_13645 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (ead:OV14_a1402 [2.2.1.1],      ead:OV14_1817 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (ead:OV14_b1225 [2.2.1.1],      ead:OV14_1817 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (esj:SJ05684_b54200 [2.2.1.1],  esj:SJ05684_c04820 [2.2.1.7])   => [5.1.3.1, 5.3.1.6]
    (gdi:GDI0241 [2.2.1.1],         gdi:GDI1860 [2.2.1.7])          => [5.1.3.1, 5.3.1.6]
    (gdi:GDI3010 [2.2.1.1],         gdi:GDI1860 [2.2.1.7])          => [5.1.3.1, 5.3.1.6]
    (hdi:HDIA_0855 [2.2.1.1],       hdi:HDIA_1210 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (hdi:HDIA_P0045 [2.2.1.1],      hdi:HDIA_1210 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (hoe:IMCC20628_02265 [2.2.1.1], hoe:IMCC20628_02813 [2.2.1.7])  => [5.1.3.1, 5.3.1.6]
    (maad:AZF01_17905 [2.2.1.1],    maad:AZF01_04975 [2.2.1.7])     => [5.1.3.1, 5.3.1.6]
    (mag:amb0067 [2.2.1.1],         mag:amb2904 [2.2.1.7])          => [5.1.3.1, 5.3.1.6]
    (magn:WV31_12985 [2.2.1.1],     magn:WV31_19785 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (magq:MGMAQ_0173 [2.2.1.1],     magq:MGMAQ_2260 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (magx:XM1_0928 [2.2.1.1],       magx:XM1_2756 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (malg:MALG_04575 [2.2.1.1],     malg:MALG_03335 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (maqu:Maq22A_c16690 [2.2.1.1],  maqu:Maq22A_c16825 [2.2.1.7])   => [5.1.3.1, 5.3.1.6]
    (maqu:Maq22A_c16690 [2.2.1.1],  maqu:Maq22A_c25230 [2.2.1.7])   => [5.1.3.1, 5.3.1.6]
    (mbry:B1812_21440 [2.2.1.1],    mbry:B1812_01145 [2.2.1.7])     => [5.1.3.1, 5.3.1.6]
    (mes:Meso_3618 [2.2.1.1],       mes:Meso_0735 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (met:M446_2744 [2.2.1.1],       met:M446_6352 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (met:M446_2744 [2.2.1.1],       met:M446_6391 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (meta:Y590_09995 [2.2.1.1],     meta:Y590_09015 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (meta:Y590_09995 [2.2.1.1],     meta:Y590_21535 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (mex:Mext_2092 [2.2.1.1],       mex:Mext_1939 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (mex:Mext_2092 [2.2.1.1],       mex:Mext_4309 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (mgm:Mmc1_1058 [2.2.1.1],       mgm:Mmc1_1048 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (mln:A9174_02530 [2.2.1.1],     mln:A9174_28510 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (mlo:mll5764 [2.2.1.1],         mlo:mlr7474 [2.2.1.7])          => [5.1.3.1, 5.3.1.6]
    (mmed:Mame_00457 [2.2.1.1],     mmed:Mame_03800 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (mmed:Mame_01571 [2.2.1.1],     mmed:Mame_03800 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (mno:Mnod_4383 [2.2.1.1],       mno:Mnod_6796 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (mno:Mnod_4383 [2.2.1.1],       mno:Mnod_7141 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (mno:Mnod_4387 [2.2.1.1],       mno:Mnod_6796 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (mno:Mnod_4387 [2.2.1.1],       mno:Mnod_7141 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (mno:Mnod_5659 [2.2.1.1],       mno:Mnod_6796 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (mno:Mnod_5659 [2.2.1.1],       mno:Mnod_7141 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (moc:BB934_30545 [2.2.1.1],     moc:BB934_05670 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (mop:Mesop_0510 [2.2.1.1],      mop:Mesop_5623 [2.2.1.7])       => [5.1.3.1, 5.3.1.6]
    (mor:MOC_3368 [2.2.1.1],        mor:MOC_4561 [2.2.1.7])         => [5.1.3.1, 5.3.1.6]
    (mphy:MCBMB27_02435 [2.2.1.1],  mphy:MCBMB27_02946 [2.2.1.7])   => [5.1.3.1, 5.3.1.6]
    (mphy:MCBMB27_02435 [2.2.1.1],  mphy:MCBMB27_03478 [2.2.1.7])   => [5.1.3.1, 5.3.1.6]
    (mpo:Mpop_0261 [2.2.1.1],       mpo:Mpop_1830 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (mpo:Mpop_0261 [2.2.1.1],       mpo:Mpop_4826 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (mrd:Mrad2831_3003 [2.2.1.1],   mrd:Mrad2831_3459 [2.2.1.7])    => [5.1.3.1, 5.3.1.6]
    (mrd:Mrad2831_3003 [2.2.1.1],   mrd:Mrad2831_3992 [2.2.1.7])    => [5.1.3.1, 5.3.1.6]
    (msc:BN69_2088 [2.2.1.1],       msc:BN69_2310 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (mza:B2G69_17915 [2.2.1.1],     mza:B2G69_03480 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (mza:B2G69_17915 [2.2.1.1],     mza:B2G69_17155 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (nre:BES08_14725 [2.2.1.1],     nre:BES08_12705 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (oan:Oant_4834 [2.2.1.1],       oan:Oant_0547 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (oat:OAN307_c00600 [2.2.1.1],   oat:OAN307_c45760 [2.2.1.7])    => [5.1.3.1, 5.3.1.6]
    (paby:Ga0080574_TMP4465 [2.2.1.1],      paby:Ga0080574_TMP3111 [2.2.1.7])       => [5.1.3.1, 5.3.1.6]
    (paro:CUV01_01450 [2.2.1.1],    paro:CUV01_10455 [2.2.1.7])     => [5.1.3.1, 5.3.1.6]
    (paro:CUV01_06065 [2.2.1.1],    paro:CUV01_10455 [2.2.1.7])     => [5.1.3.1, 5.3.1.6]
    (paro:CUV01_13155 [2.2.1.1],    paro:CUV01_10455 [2.2.1.7])     => [5.1.3.1, 5.3.1.6]
    (pgv:SL003B_2451 [2.2.1.1],     pgv:SL003B_3299 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (php:PhaeoP97_03855 [2.2.1.1],  php:PhaeoP97_03318 [2.2.1.7])   => [5.1.3.1, 5.3.1.6]
    (pht:BLM14_25240 [2.2.1.1],     pht:BLM14_13200 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (ptp:RCA23_c02710 [2.2.1.1],    ptp:RCA23_c04430 [2.2.1.7])     => [5.1.3.1, 5.3.1.6]
    (ptp:RCA23_c02710 [2.2.1.1],    ptp:RCA23_c29710 [2.2.1.7])     => [5.1.3.1, 5.3.1.6]
    (pub:SAR11_0536 [2.2.1.1],      pub:SAR11_0611 [2.2.1.7])       => [5.1.3.1, 5.3.1.6]
    (pzh:CX676_18995 [2.2.1.1],     pzh:CX676_10325 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (rce:RC1_3769 [2.2.1.1],        rce:RC1_0565 [2.2.1.7])         => [5.1.3.1, 5.3.1.6]
    (rcp:RCAP_rcc01832 [2.2.1.1],   rcp:RCAP_rcc00696 [2.2.1.7])    => [5.1.3.1, 5.3.1.6]
    (rcp:RCAP_rcc02654 [2.2.1.1],   rcp:RCAP_rcc00696 [2.2.1.7])    => [5.1.3.1, 5.3.1.6]
    (rcp:RCAP_rcc02654 [2.2.1.1],   rcp:RCAP_rcc03462 [2.2.1.7])    => [5.1.3.1, 5.3.1.6]
    (ret:RHE_CH02397 [2.2.1.1],     ret:RHE_CH00913 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (rga:RGR602_PC00231 [2.2.1.1],  rga:RGR602_CH00973 [2.2.1.7])   => [5.1.3.1, 5.3.1.6]
    (rga:RGR602_PC01824 [2.2.1.1],  rga:RGR602_CH00973 [2.2.1.7])   => [5.1.3.1, 5.3.1.6]
    (rgi:RGI145_22310 [2.2.1.1],    rgi:RGI145_07290 [2.2.1.7])     => [5.1.3.1, 5.3.1.6]
    (rhc:RGUI_3957 [2.2.1.1],       rhc:RGUI_1953 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (rhc:RGUI_3957 [2.2.1.1],       rhc:RGUI_2678 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (rhi:NGR_a02450 [2.2.1.1],      rhi:NGR_c04950 [2.2.1.7])       => [5.1.3.1, 5.3.1.6]
    (rhl:LPU83_pLPU83c0740 [2.2.1.1],       rhl:LPU83_1026 [2.2.1.7])       => [5.1.3.1, 5.3.1.6]
    (rhn:AMJ98_CH02452 [2.2.1.1],   rhn:AMJ98_CH00931 [2.2.1.7])    => [5.1.3.1, 5.3.1.6]
    (rhx:AMK02_CH02467 [2.2.1.1],   rhx:AMK02_CH00955 [2.2.1.7])    => [5.1.3.1, 5.3.1.6]
    (rir:BN877_p0594 [2.2.1.1],     rir:BN877_I0720 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (rle:RL2718 [2.2.1.1],          rle:RL0973 [2.2.1.7])           => [5.1.3.1, 5.3.1.6]
    (rmb:K529_016635 [2.2.1.1],     rmb:K529_014870 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (rpha:AMC79_CH02524 [2.2.1.1],  rpha:AMC79_CH00941 [2.2.1.7])   => [5.1.3.1, 5.3.1.6]
    (rpha:AMC79_PD00768 [2.2.1.1],  rpha:AMC79_CH00941 [2.2.1.7])   => [5.1.3.1, 5.3.1.6]
    (rsp:RSP_3268 [2.2.1.1],        rsp:RSP_0254 [2.2.1.7])         => [5.1.3.1, 5.3.1.6]
    (rsp:RSP_3268 [2.2.1.1],        rsp:RSP_1134 [2.2.1.7])         => [5.1.3.1, 5.3.1.6]
    (rtr:RTCIAT899_PC06425 [2.2.1.1],       rtr:RTCIAT899_CH04415 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (sagu:CDO87_02170 [2.2.1.1],    sagu:CDO87_04610 [2.2.1.7])     => [5.1.3.1, 5.3.1.6]
    (same:SAMCFNEI73_pA0163 [2.2.1.1],      same:SAMCFNEI73_Ch0928 [2.2.1.7])       => [5.1.3.1, 5.3.1.6]
    (same:SAMCFNEI73_pC1939 [2.2.1.1],      same:SAMCFNEI73_Ch0928 [2.2.1.7])       => [5.1.3.1, 5.3.1.6]
    (sgi:SGRAN_1185 [2.2.1.1],      sgi:SGRAN_3913 [2.2.1.7])       => [5.1.3.1, 5.3.1.6]
    (shz:shn_03050 [2.2.1.1],       shz:shn_04070 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (shz:shn_26175 [2.2.1.1],       shz:shn_04070 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (shz:shn_27070 [2.2.1.1],       shz:shn_04070 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (sino:SS05631_a42480 [2.2.1.1], sino:SS05631_c05900 [2.2.1.7])  => [5.1.3.1, 5.3.1.6]
    (sino:SS05631_a48150 [2.2.1.1], sino:SS05631_c05900 [2.2.1.7])  => [5.1.3.1, 5.3.1.6]
    (sino:SS05631_b52020 [2.2.1.1], sino:SS05631_c05900 [2.2.1.7])  => [5.1.3.1, 5.3.1.6]
    (six:BSY16_4811 [2.2.1.1],      six:BSY16_2102 [2.2.1.7])       => [5.1.3.1, 5.3.1.6]
    (skr:BRX40_01570 [2.2.1.1],     skr:BRX40_07400 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (smd:Smed_3129 [2.2.1.1],       smd:Smed_0492 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (sme:SMc00269 [2.2.1.1],        sme:SMc00972 [2.2.1.7])         => [5.1.3.1, 5.3.1.6]
    (span:AWL63_00225 [2.2.1.1],    span:AWL63_08815 [2.2.1.7])     => [5.1.3.1, 5.3.1.6]
    (sphc:CVN68_12600 [2.2.1.1],    sphc:CVN68_09985 [2.2.1.7])     => [5.1.3.1, 5.3.1.6]
    (sphi:TS85_09655 [2.2.1.1],     sphi:TS85_12485 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (spse:SULPSESMR1_00542 [2.2.1.1],       spse:SULPSESMR1_03031 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (ssan:NX02_20250 [2.2.1.1],     ssan:NX02_14100 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (sya:A6768_20295 [2.2.1.1],     sya:A6768_06065 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (thw:BMG03_00060 [2.2.1.1],     thw:BMG03_00810 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (thw:BMG03_00155 [2.2.1.1],     thw:BMG03_00810 [2.2.1.7])      => [5.1.3.1, 5.3.1.6]
    (tpro:Ga0080559_TMP322 [2.2.1.1],       tpro:Ga0080559_TMP1172 [2.2.1.7])       => [5.1.3.1, 5.3.1.6]
    (xau:Xaut_1539 [2.2.1.1],       xau:Xaut_4733 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (xau:Xaut_1713 [2.2.1.1],       xau:Xaut_4733 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    (xau:Xaut_2041 [2.2.1.1],       xau:Xaut_4733 [2.2.1.7])        => [5.1.3.1, 5.3.1.6]
    
    
    
    
    Betaproteobacteria:

    core metabolism ECs: 298
    
    "neofunctionalised" ECs: 70 (23%)
    1.1.1.100
    1.1.1.35
    1.1.1.36
    1.1.1.42
    1.1.1.85
    1.2.4.1
    1.2.4.2
    1.8.1.4
    2.1.2.2
    2.1.3.2
    2.1.3.3
    2.2.1.1
    2.2.1.7
    2.3.1.-
    2.3.1.1
    2.3.1.12
    2.3.1.129
    2.3.1.16
    2.3.1.179
    2.3.1.180
    2.3.1.191
    2.3.1.61
    2.3.1.9
    2.4.2.-
    2.4.2.14
    2.5.1.49
    2.5.1.54
    2.5.1.55
    2.6.1.16
    2.6.1.17
    2.6.1.62
    2.7.2.8
    2.7.7.24
    2.7.7.38
    2.7.7.6
    2.7.7.7
    2.7.7.9
    3.1.3.105
    3.1.3.18
    3.1.3.45
    3.5.1.10
    4.1.3.-
    4.1.3.27
    4.1.99.17
    4.2.1.46
    4.4.1.8
    5.1.1.7
    5.1.3.2
    5.3.1.16
    5.4.3.8
    6.1.1.1
    6.1.1.10
    6.1.1.12
    6.1.1.14
    6.1.1.15
    6.1.1.17
    6.1.1.18
    6.1.1.20
    6.1.1.3
    6.1.1.4
    6.1.1.5
    6.1.1.6
    6.1.1.9
    6.2.1.1
    6.2.1.3
    6.3.2.10
    6.3.2.13
    6.3.2.8
    6.3.2.9
    6.3.4.18
    
    "neofunctionalised" ECs contributing to redundancy: 7 ( 2%)
    2.1.3.3 => [2.1.3.2]
    2.2.1.1 => [2.2.1.2, 5.1.3.1, 5.3.1.6]
    2.2.1.7 => [1.2.1.12, 2.7.9.2]
    2.4.2.- => [4.1.3.-]
    2.7.7.6 => [6.3.4.2]
    4.1.3.- => [2.4.2.-]
    6.2.1.3 => [3.1.2.-]
    
    Neofunctionalisations contributing to redundancy: 1760 (21%)
    (achr:C2U31_27345 [2.2.1.1],    achr:C2U31_14670 [2.2.1.7])     => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (adn:Alide_2368 [2.2.1.1],      adn:Alide_1116 [2.2.1.7])       => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (adt:APT56_19615 [2.2.1.1],     adt:APT56_08065 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (ais:BUW96_13275 [2.2.1.1],     ais:BUW96_17225 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (asw:CVS48_14175 [2.2.1.1],     asw:CVS48_27015 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (axy:AXYL_04857 [2.2.1.1],      axy:AXYL_01834 [2.2.1.7])       => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (aza:AZKH_p0609 [2.2.1.1],      aza:AZKH_1187 [2.2.1.7])        => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bam:Bamb_4411 [2.2.1.1],       bam:Bamb_3250 [2.2.1.7])        => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bav:BAV1248 [2.2.1.1],         bav:BAV2177 [2.2.1.7])          => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bbro:BAU06_15455 [2.2.1.1],    bbro:BAU06_17255 [2.2.1.7])     => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bbro:BAU06_24825 [2.2.1.1],    bbro:BAU06_17255 [2.2.1.7])     => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bcai:K788_0002125 [2.2.1.1],   bcai:K788_0000378 [2.2.1.7])    => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bcai:K788_0002125 [2.2.1.1],   bcai:K788_0006001 [2.2.1.7])    => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bcn:Bcen_6422 [2.2.1.1],       bcn:Bcen_4486 [2.2.1.7])        => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bdl:AK34_4869 [2.2.1.1],       bdl:AK34_4540 [2.2.1.7])        => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (beb:AEM42_00205 [2.2.1.1],     beb:AEM42_15395 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bfn:OI25_5833 [2.2.1.1],       bfn:OI25_5238 [2.2.1.7])        => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bfn:OI25_6025 [2.2.1.1],       bfn:OI25_5238 [2.2.1.7])        => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bfz:BAU07_10955 [2.2.1.1],     bfz:BAU07_08915 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bge:BC1002_6125 [2.2.1.1],     bge:BC1002_5272 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bgf:BC1003_3395 [2.2.1.1],     bgf:BC1003_4540 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bgf:BC1003_4378 [2.2.1.1],     bgf:BC1003_4540 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bhz:ACR54_02536 [2.2.1.1],     bhz:ACR54_02932 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (blat:WK25_27220 [2.2.1.1],     blat:WK25_22030 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bmec:WJ16_20295 [2.2.1.1],     bmec:WJ16_23515 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bmu:Bmul_4991 [2.2.1.1],       bmu:Bmul_4820 [2.2.1.7])        => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bph:Bphy_5878 [2.2.1.1],       bph:Bphy_3948 [2.2.1.7])        => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bpsl:WS57_17195 [2.2.1.1],     bpsl:WS57_09505 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bpsl:WS57_18925 [2.2.1.1],     bpsl:WS57_09505 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bpx:BUPH_05969 [2.2.1.1],      bpx:BUPH_01519 [2.2.1.7])       => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bpx:BUPH_08115 [2.2.1.1],      bpx:BUPH_01519 [2.2.1.7])       => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bpy:Bphyt_6139 [2.2.1.1],      bpy:Bphyt_6781 [2.2.1.7])       => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bpy:Bphyt_6143 [2.2.1.1],      bpy:Bphyt_6781 [2.2.1.7])       => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bpyr:ABD05_24875 [2.2.1.1],    bpyr:ABD05_17250 [2.2.1.7])     => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bue:BRPE67_CCDS04770 [2.2.1.1],bue:BRPE67_BCDS14920 [2.2.1.7]) => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bue:BRPE67_DCDS09370 [2.2.1.1],bue:BRPE67_BCDS14920 [2.2.1.7]) => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bug:BC1001_3437 [2.2.1.1],     bug:BC1001_4954 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bug:BC1001_5109 [2.2.1.1],     bug:BC1001_4954 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (buo:BRPE64_CCDS04460 [2.2.1.1],buo:BRPE64_BCDS12130 [2.2.1.7]) => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (buo:BRPE64_DCDS04540 [2.2.1.1],buo:BRPE64_BCDS12130 [2.2.1.7]) => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (buq:AC233_24585 [2.2.1.1],     buq:AC233_25165 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (buq:AC233_25595 [2.2.1.1],     buq:AC233_25165 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (buz:AYM40_04760 [2.2.1.1],     buz:AYM40_22455 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (buz:AYM40_34265 [2.2.1.1],     buz:AYM40_22455 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (bxe:Bxe_B2699 [2.2.1.1],       bxe:Bxe_B2827 [2.2.1.7])        => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (byi:BYI23_C006650 [2.2.1.1],   byi:BYI23_B011150 [2.2.1.7])    => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (byi:BYI23_D007460 [2.2.1.1],   byi:BYI23_B011150 [2.2.1.7])    => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (cbw:RR42_s2709 [2.2.1.1],      cbw:RR42_m3051 [2.2.1.7])       => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (dac:Daci_0727 [2.2.1.1],       dac:Daci_2242 [2.2.1.7])        => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (del:DelCs14_5810 [2.2.1.1],    del:DelCs14_4446 [2.2.1.7])     => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (dhk:BO996_03675 [2.2.1.1],     dhk:BO996_10460 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (dts:BI380_21095 [2.2.1.1],     dts:BI380_13020 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (gca:Galf_1087 [2.2.1.1],       gca:Galf_2269 [2.2.1.7])        => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (hee:hmeg3_21570 [2.2.1.1],     hee:hmeg3_04815 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (hht:F506_00970 [2.2.1.1],      hht:F506_02305 [2.2.1.7])       => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (hrb:Hrubri_4314 [2.2.1.1],     hrb:Hrubri_3794 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (hse:Hsero_1105 [2.2.1.1],      hse:Hsero_3831 [2.2.1.7])       => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (hyr:BSY239_3381 [2.2.1.1],     hyr:BSY239_895 [2.2.1.7])       => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (jab:VN23_20255 [2.2.1.1],      jab:VN23_00950 [2.2.1.7])       => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (kki:KKKWG1_1933 [2.2.1.1],     kki:KKKWG1_2212 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (lch:Lcho_4275 [2.2.1.1],       lch:Lcho_3373 [2.2.1.7])        => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (lim:L103DPR2_00946 [2.2.1.1],  lim:L103DPR2_01015 [2.2.1.7])   => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (lim:L103DPR2_00946 [2.2.1.1],  lim:L103DPR2_01240 [2.2.1.7])   => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (masw:AM586_20940 [2.2.1.1],    masw:AM586_05270 [2.2.1.7])     => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (nla:NLA_8710 [2.2.1.1],        nla:NLA_18120 [2.2.1.7])        => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (odi:ODI_R2986 [2.2.1.1],       odi:ODI_R1586 [2.2.1.7])        => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (parb:CJU94_30940 [2.2.1.1],    parb:CJU94_29535 [2.2.1.7])     => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (parb:CJU94_31845 [2.2.1.1],    parb:CJU94_29535 [2.2.1.7])     => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (phs:C2L64_13915 [2.2.1.1],     phs:C2L64_31595 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (phs:C2L64_13915 [2.2.1.1],     phs:C2L64_34025 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (phs:C2L64_42960 [2.2.1.1],     phs:C2L64_31595 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (phs:C2L64_42960 [2.2.1.1],     phs:C2L64_34025 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (pol:Bpro_1462 [2.2.1.1],       pol:Bpro_1747 [2.2.1.7])        => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (pse:NH8B_2710 [2.2.1.1],       pse:NH8B_2773 [2.2.1.7])        => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (pspw:BJG93_28290 [2.2.1.1],    pspw:BJG93_20705 [2.2.1.7])     => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (pter:C2L65_33870 [2.2.1.1],    pter:C2L65_28330 [2.2.1.7])     => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (pter:C2L65_33870 [2.2.1.1],    pter:C2L65_30475 [2.2.1.7])     => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (pter:C2L65_40145 [2.2.1.1],    pter:C2L65_28330 [2.2.1.7])     => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (pter:C2L65_40145 [2.2.1.1],    pter:C2L65_30475 [2.2.1.7])     => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (ptx:ABW99_11865 [2.2.1.1],     ptx:ABW99_10555 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (put:PT7_3273 [2.2.1.1],        put:PT7_0463 [2.2.1.7])         => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (rbu:PG1C_08950 [2.2.1.1],      rbu:PG1C_03825 [2.2.1.7])       => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (reu:Reut_B4778 [2.2.1.1],      reu:Reut_A0882 [2.2.1.7])       => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (rsb:RS694_02935 [2.2.1.1],     rsb:RS694_06610 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (rta:Rta_31430 [2.2.1.1],       rta:Rta_13100 [2.2.1.7])        => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (vap:Vapar_3312 [2.2.1.1],      vap:Vapar_1571 [2.2.1.7])       => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (vbo:CKY39_03890 [2.2.1.1],     vbo:CKY39_09810 [2.2.1.7])      => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (vei:Veis_0901 [2.2.1.1],       vei:Veis_3283 [2.2.1.7])        => [1.2.1.12, 2.2.1.2, 2.7.9.2, 5.1.3.1, 5.3.1.6]
    (lhk:LHK_02270 [1.2.4.1],       lhk:LHK_02324 [2.2.1.7])        => [1.2.1.12, 2.7.9.2]
    (aaa:Acav_1329 [2.1.3.2],       aaa:Acav_1176 [2.1.3.3])        => [2.1.3.2]
    (aaa:Acav_3861 [2.1.3.2],       aaa:Acav_1176 [2.1.3.3])        => [2.1.3.2]
    (achr:C2U31_14810 [2.1.3.2],    achr:C2U31_15535 [2.1.3.3])     => [2.1.3.2]
    (afa:UZ73_01350 [2.1.3.2],      afa:UZ73_16545 [2.1.3.3])       => [2.1.3.2]
    (aql:BXU06_15315 [2.1.3.2],     aql:BXU06_05320 [2.1.3.3])      => [2.1.3.2]
    (bbro:BAU06_09015 [2.1.3.2],    bbro:BAU06_16455 [2.1.3.3])     => [2.1.3.2]
    (boh:AKI39_08835 [2.1.3.2],     boh:AKI39_15735 [2.1.3.3])      => [2.1.3.2]
    (bpdz:BBN53_13075 [2.1.3.2],    bpdz:BBN53_07765 [2.1.3.3])     => [2.1.3.2]
    (bpe:BP0321 [2.1.3.2],          bpe:BP3538 [2.1.3.3])           => [2.1.3.2]
    (bprc:D521_0249 [2.1.3.2],      bprc:D521_1736 [2.1.3.3])       => [2.1.3.2]
    (chro:CXB49_21590 [2.1.3.2],    chro:CXB49_12380 [2.1.3.3])     => [2.1.3.2]
    (cuh:BJN34_15590 [2.1.3.2],     cuh:BJN34_16365 [2.1.3.3])      => [2.1.3.2]
    (cvc:BKX93_13600 [2.1.3.2],     cvc:BKX93_00195 [2.1.3.3])      => [2.1.3.2]
    (cvi:CV_0369 [2.1.3.2],         cvi:CV_1993 [2.1.3.3])          => [2.1.3.2]
    (jab:VN23_11375 [2.1.3.2],      jab:VN23_09715 [2.1.3.3])       => [2.1.3.2]
    (kci:CKCE_0422 [2.1.3.2],       kci:CKCE_0268 [2.1.3.3])        => [2.1.3.2]
    (kde:CDSE_0440 [2.1.3.2],       kde:CDSE_0612 [2.1.3.3])        => [2.1.3.2]
    (kki:KKKWG1_1109 [2.1.3.2],     kki:KKKWG1_0605 [2.1.3.3])      => [2.1.3.2]
    (lim:L103DPR2_02555 [2.1.3.2],  lim:L103DPR2_02391 [2.1.3.3])   => [2.1.3.2]
    (pne:Pnec_0267 [2.1.3.2],       pne:Pnec_1469 [2.1.3.3])        => [2.1.3.2]
    (pse:NH8B_4063 [2.1.3.2],       pse:NH8B_2585 [2.1.3.3])        => [2.1.3.2]
    (salv:SALWKB2_2106 [2.1.3.2],   salv:SALWKB2_1795 [2.1.3.3])    => [2.1.3.2]
    (tbd:Tbd_2582 [2.1.3.2],        tbd:Tbd_1850 [2.1.3.3])         => [2.1.3.2]
    (aav:Aave_1047 [4.1.3.-],       aav:Aave_1034 [5.3.1.16])       => [2.4.2.-]
    (achr:C2U31_05885 [4.1.3.-],    achr:C2U31_05890 [5.3.1.16])    => [2.4.2.-]
    (acid:CBP33_15190 [4.1.3.-],    acid:CBP33_15225 [5.3.1.16])    => [2.4.2.-]
    (acin:CBP34_15995 [4.1.3.-],    acin:CBP34_16035 [5.3.1.16])    => [2.4.2.-]
    (adn:Alide_0890 [4.1.3.-],      adn:Alide_0880 [5.3.1.16])      => [2.4.2.-]
    (adt:APT56_01200 [4.1.3.-],     adt:APT56_01205 [5.3.1.16])     => [2.4.2.-]
    (afa:UZ73_12110 [4.1.3.-],      afa:UZ73_12115 [5.3.1.16])      => [2.4.2.-]
    (ais:BUW96_26685 [4.1.3.-],     ais:BUW96_26690 [5.3.1.16])     => [2.4.2.-]
    (amim:MIM_c04890 [4.1.3.-],     amim:MIM_c04880 [5.3.1.16])     => [2.4.2.-]
    (aoa:dqs_3481 [4.1.3.-],        aoa:dqs_3482 [5.3.1.16])        => [2.4.2.-]
    (app:CAP2UW1_4038 [4.1.3.-],    app:CAP2UW1_4037 [5.3.1.16])    => [2.4.2.-]
    (aql:BXU06_13320 [4.1.3.-],     aql:BXU06_13325 [5.3.1.16])     => [2.4.2.-]
    (asw:CVS48_05125 [4.1.3.-],     asw:CVS48_05120 [5.3.1.16])     => [2.4.2.-]
    (atw:C0099_06035 [4.1.3.-],     atw:C0099_06030 [5.3.1.16])     => [2.4.2.-]
    (axy:AXYL_00185 [4.1.3.-],      axy:AXYL_00186 [5.3.1.16])      => [2.4.2.-]
    (aza:AZKH_0760 [4.1.3.-],       aza:AZKH_0759 [5.3.1.16])       => [2.4.2.-]
    (azi:AzCIB_0661 [4.1.3.-],      azi:AzCIB_0660 [5.3.1.16])      => [2.4.2.-]
    (azo:azo3344 [4.1.3.-],         azo:azo3345 [5.3.1.16])         => [2.4.2.-]
    (bam:Bamb_0349 [4.1.3.-],       bam:Bamb_0348 [5.3.1.16])       => [2.4.2.-]
    (bav:BAV3319 [4.1.3.-],         bav:BAV3318 [5.3.1.16])         => [2.4.2.-]
    (bbag:E1O_23320 [4.1.3.-],      bbag:E1O_23330 [5.3.1.16])      => [2.4.2.-]
    (bbay:A4V04_12520 [4.1.3.-],    bbay:A4V04_12525 [5.3.1.16])    => [2.4.2.-]
    (bbr:BB4859 [4.1.3.-],          bbr:BB4858 [5.3.1.16])          => [2.4.2.-]
    (bbro:BAU06_00830 [4.1.3.-],    bbro:BAU06_00835 [5.3.1.16])    => [2.4.2.-]
    (bcai:K788_00013550 [4.1.3.-],  bcai:K788_0002608 [5.3.1.16])   => [2.4.2.-]
    (bcn:Bcen_2676 [4.1.3.-],       bcn:Bcen_2677 [5.3.1.16])       => [2.4.2.-]
    (bcon:NL30_19965 [4.1.3.-],     bcon:NL30_19960 [5.3.1.16])     => [2.4.2.-]
    (bct:GEM_3091 [4.1.3.-],        bct:GEM_3092 [5.3.1.16])        => [2.4.2.-]
    (bdf:WI26_01760 [4.1.3.-],      bdf:WI26_01755 [5.3.1.16])      => [2.4.2.-]
    (bdl:AK34_2715 [4.1.3.-],       bdl:AK34_2716 [5.3.1.16])       => [2.4.2.-]
    (beba:BWI17_08645 [4.1.3.-],    beba:BWI17_08640 [5.3.1.16])    => [2.4.2.-]
    (bfn:OI25_1854 [4.1.3.-],       bfn:OI25_1853 [5.3.1.16])       => [2.4.2.-]
    (bfz:BAU07_00675 [4.1.3.-],     bfz:BAU07_00680 [5.3.1.16])     => [2.4.2.-]
    (bgd:bgla_1g03820 [4.1.3.-],    bgd:bgla_1g03810 [5.3.1.16])    => [2.4.2.-]
    (bge:BC1002_2813 [4.1.3.-],     bge:BC1002_2814 [5.3.1.16])     => [2.4.2.-]
    (bgf:BC1003_3154 [4.1.3.-],     bgf:BC1003_3155 [5.3.1.16])     => [2.4.2.-]
    (bgl:bglu_1g03370 [4.1.3.-],    bgl:bglu_1g03360 [5.3.1.16])    => [2.4.2.-]
    (bho:D560_1570 [4.1.3.-],       bho:D560_1571 [5.3.1.16])       => [2.4.2.-]
    (bhz:ACR54_04497 [4.1.3.-],     bhz:ACR54_04496 [5.3.1.16])     => [2.4.2.-]
    (blat:WK25_00550 [4.1.3.-],     blat:WK25_00555 [5.3.1.16])     => [2.4.2.-]
    (bma:BMA2708 [4.1.3.-],         bma:BMA2709 [5.3.1.16])         => [2.4.2.-]
    (bmec:WJ16_01790 [4.1.3.-],     bmec:WJ16_01785 [5.3.1.16])     => [2.4.2.-]
    (bmu:Bmul_0334 [4.1.3.-],       bmu:Bmul_0333 [5.3.1.16])       => [2.4.2.-]
    (boh:AKI39_00595 [4.1.3.-],     boh:AKI39_00590 [5.3.1.16])     => [2.4.2.-]
    (bok:DM82_2832 [4.1.3.-],       bok:DM82_2833 [5.3.1.16])       => [2.4.2.-]
    (bpa:BPP4272 [4.1.3.-],         bpa:BPP4271 [5.3.1.16])         => [2.4.2.-]
    (bpdz:BBN53_00655 [4.1.3.-],    bpdz:BBN53_00660 [5.3.1.16])    => [2.4.2.-]
    (bpe:BP3773 [4.1.3.-],          bpe:BP3772 [5.3.1.16])          => [2.4.2.-]
    (bpla:bpln_1g03260 [4.1.3.-],   bpla:bpln_1g03250 [5.3.1.16])   => [2.4.2.-]
    (bprc:D521_0111 [4.1.3.-],      bprc:D521_0110 [5.3.1.16])      => [2.4.2.-]
    (bps:BPSL3133 [4.1.3.-],        bps:BPSL3134 [5.3.1.16])        => [2.4.2.-]
    (bpsi:IX83_08400 [4.1.3.-],     bpsi:IX83_08405 [5.3.1.16])     => [2.4.2.-]
    (bpsl:WS57_19655 [4.1.3.-],     bpsl:WS57_19650 [5.3.1.16])     => [2.4.2.-]
    (bpx:BUPH_06283 [4.1.3.-],      bpx:BUPH_06284 [5.3.1.16])      => [2.4.2.-]
    (bpy:Bphyt_3554 [4.1.3.-],      bpy:Bphyt_3555 [5.3.1.16])      => [2.4.2.-]
    (bpyr:ABD05_07815 [4.1.3.-],    bpyr:ABD05_07810 [5.3.1.16])    => [2.4.2.-]
    (brh:RBRH_02287 [4.1.3.-],      brh:RBRH_02288 [5.3.1.16])      => [2.4.2.-]
    (bsem:WJ12_01840 [4.1.3.-],     bsem:WJ12_01835 [5.3.1.16])     => [2.4.2.-]
    (bstg:WT74_02130 [4.1.3.-],     bstg:WT74_02125 [5.3.1.16])     => [2.4.2.-]
    (bstl:BBJ41_11885 [4.1.3.-],    bstl:BBJ41_11880 [5.3.1.16])    => [2.4.2.-]
    (bte:BTH_I2987 [4.1.3.-],       bte:BTH_I2988 [5.3.1.16])       => [2.4.2.-]
    (btei:WS51_12580 [4.1.3.-],     btei:WS51_12575 [5.3.1.16])     => [2.4.2.-]
    (btrm:SAMEA390648701079 [4.1.3.-],      btrm:SAMEA390648701078 [5.3.1.16])      => [2.4.2.-]
    (bub:BW23_1321 [4.1.3.-],       bub:BW23_1322 [5.3.1.16])       => [2.4.2.-]
    (bud:AQ610_01970 [4.1.3.-],     bud:AQ610_01965 [5.3.1.16])     => [2.4.2.-]
    (bue:BRPE67_ACDS24470 [4.1.3.-],bue:BRPE67_ACDS24480 [5.3.1.16])=> [2.4.2.-]
    (bug:BC1001_3193 [4.1.3.-],     bug:BC1001_3194 [5.3.1.16])     => [2.4.2.-]
    (bul:BW21_514 [4.1.3.-],        bul:BW21_513 [5.3.1.16])        => [2.4.2.-]
    (buo:BRPE64_ACDS25010 [4.1.3.-],buo:BRPE64_ACDS25020 [5.3.1.16])=> [2.4.2.-]
    (buq:AC233_16230 [4.1.3.-],     buq:AC233_16235 [5.3.1.16])     => [2.4.2.-]
    (bur:Bcep18194_A3529 [4.1.3.-], bur:Bcep18194_A3528 [5.3.1.16]) => [2.4.2.-]
    (buz:AYM40_18560 [4.1.3.-],     buz:AYM40_18565 [5.3.1.16])     => [2.4.2.-]
    (bvi:Bcep1808_0410 [4.1.3.-],   bvi:Bcep1808_0409 [5.3.1.16])   => [2.4.2.-]
    (bxe:Bxe_A0404 [4.1.3.-],       bxe:Bxe_A0403 [5.3.1.16])       => [2.4.2.-]
    (byi:BYI23_A023660 [4.1.3.-],   byi:BYI23_A023670 [5.3.1.16])   => [2.4.2.-]
    (care:LT85_0577 [4.1.3.-],      care:LT85_0576 [5.3.1.16])      => [2.4.2.-]
    (cbw:RR42_m3835 [4.1.3.-],      cbw:RR42_m3836 [5.3.1.16])      => [2.4.2.-]
    (cbx:Cenrod_0738 [4.1.3.-],     cbx:Cenrod_0737 [5.3.1.16])     => [2.4.2.-]
    (ccup:BKK81_00100 [4.1.3.-],    ccup:BKK81_00105 [5.3.1.16])    => [2.4.2.-]
    (cdn:BN940_00391 [4.1.3.-],     cdn:BN940_00386 [5.3.1.16])     => [2.4.2.-]
    (cfu:CFU_0520 [4.1.3.-],        cfu:CFU_0519 [5.3.1.16])        => [2.4.2.-]
    (cgd:CR3_2520 [4.1.3.-],        cgd:CR3_2521 [5.3.1.16])        => [2.4.2.-]
    (chro:CXB49_22815 [4.1.3.-],    chro:CXB49_22810 [5.3.1.16])    => [2.4.2.-]
    (cke:B5M06_07895 [4.1.3.-],     cke:B5M06_07885 [5.3.1.16])     => [2.4.2.-]
    (cpra:CPter91_0601 [4.1.3.-],   cpra:CPter91_0600 [5.3.1.16])   => [2.4.2.-]
    (cser:CCO03_05155 [4.1.3.-],    cser:CCO03_14580 [5.3.1.16])    => [2.4.2.-]
    (cti:RALTA_A2869 [4.1.3.-],     cti:RALTA_A2870 [5.3.1.16])     => [2.4.2.-]
    (cuh:BJN34_18275 [4.1.3.-],     cuh:BJN34_18280 [5.3.1.16])     => [2.4.2.-]
    (cup:BKK80_19355 [4.1.3.-],     cup:BKK80_19360 [5.3.1.16])     => [2.4.2.-]
    (cuu:BKK79_12720 [4.1.3.-],     cuu:BKK79_12715 [5.3.1.16])     => [2.4.2.-]
    (cvc:BKX93_12265 [4.1.3.-],     cvc:BKX93_12270 [5.3.1.16])     => [2.4.2.-]
    (cvi:CV_0618 [4.1.3.-],         cvi:CV_0617 [5.3.1.16])         => [2.4.2.-]
    (dac:Daci_5548 [4.1.3.-],       dac:Daci_5518 [5.3.1.16])       => [2.4.2.-]
    (del:DelCs14_1066 [4.1.3.-],    del:DelCs14_1096 [5.3.1.16])    => [2.4.2.-]
    (dhk:BO996_25830 [4.1.3.-],     dhk:BO996_25680 [5.3.1.16])     => [2.4.2.-]
    (dia:Dtpsy_0738 [4.1.3.-],      dia:Dtpsy_0732 [5.3.1.16])      => [2.4.2.-]
    (dpy:BA022_11040 [4.1.3.-],     dpy:BA022_11070 [5.3.1.16])     => [2.4.2.-]
    (dsu:Dsui_1418 [4.1.3.-],       dsu:Dsui_1417 [5.3.1.16])       => [2.4.2.-]
    (dts:BI380_27375 [4.1.3.-],     dts:BI380_27520 [5.3.1.16])     => [2.4.2.-]
    (eba:ebA1291 [4.1.3.-],         eba:ebA1293 [5.3.1.16])         => [2.4.2.-]
    (har:HEAR3064 [4.1.3.-],        har:HEAR3065 [5.3.1.16])        => [2.4.2.-]
    (hee:hmeg3_03510 [4.1.3.-],     hee:hmeg3_03505 [5.3.1.16])     => [2.4.2.-]
    (hht:F506_03585 [4.1.3.-],      hht:F506_03580 [5.3.1.16])      => [2.4.2.-]
    (hrb:Hrubri_4021 [4.1.3.-],     hrb:Hrubri_4022 [5.3.1.16])     => [2.4.2.-]
    (hse:Hsero_4063 [4.1.3.-],      hse:Hsero_4064 [5.3.1.16])      => [2.4.2.-]
    (hyb:Q5W_02305 [4.1.3.-],       hyb:Q5W_02300 [5.3.1.16])       => [2.4.2.-]
    (hyl:LPB072_04835 [4.1.3.-],    hyl:LPB072_04830 [5.3.1.16])    => [2.4.2.-]
    (hyr:BSY239_3079 [4.1.3.-],     hyr:BSY239_3080 [5.3.1.16])     => [2.4.2.-]
    (jab:VN23_18290 [4.1.3.-],      jab:VN23_18300 [5.3.1.16])      => [2.4.2.-]
    (jag:GJA_76 [4.1.3.-],          jag:GJA_75 [5.3.1.16])          => [2.4.2.-]
    (jal:BZG29_00540 [4.1.3.-],     jal:BZG29_00545 [5.3.1.16])     => [2.4.2.-]
    (jaz:YQ44_27465 [4.1.3.-],      jaz:YQ44_27460 [5.3.1.16])      => [2.4.2.-]
    (jsv:CNX70_00570 [4.1.3.-],     jsv:CNX70_00575 [5.3.1.16])     => [2.4.2.-]
    (kbl:CKBE_00184 [4.1.3.-],      kbl:CKBE_00185 [5.3.1.16])      => [2.4.2.-]
    (kci:CKCE_0628 [4.1.3.-],       kci:CKCE_0629 [5.3.1.16])       => [2.4.2.-]
    (kde:CDSE_0225 [4.1.3.-],       kde:CDSE_0226 [5.3.1.16])       => [2.4.2.-]
    (kga:ST1E_0246 [4.1.3.-],       kga:ST1E_0248 [5.3.1.16])       => [2.4.2.-]
    (kon:CONE_0222 [4.1.3.-],       kon:CONE_0223 [5.3.1.16])       => [2.4.2.-]
    (lch:Lcho_1592 [4.1.3.-],       lch:Lcho_1591 [5.3.1.16])       => [2.4.2.-]
    (lhk:LHK_00190 [4.1.3.-],       lhk:LHK_00188 [5.3.1.16])       => [2.4.2.-]
    (lih:L63ED372_02586 [4.1.3.-],  lih:L63ED372_02588 [5.3.1.16])  => [2.4.2.-]
    (lim:L103DPR2_00741 [4.1.3.-],  lim:L103DPR2_00739 [5.3.1.16])  => [2.4.2.-]
    (mbac:BN1209_0206 [4.1.3.-],    mbac:BN1209_0205 [5.3.1.16])    => [2.4.2.-]
    (mbat:BN1208_0185 [4.1.3.-],    mbat:BN1208_0184 [5.3.1.16])    => [2.4.2.-]
    (meh:M301_0308 [4.1.3.-],       meh:M301_0307 [5.3.1.16])       => [2.4.2.-]
    (mei:Msip34_0272 [4.1.3.-],     mei:Msip34_0271 [5.3.1.16])     => [2.4.2.-]
    (mep:MPQ_0285 [4.1.3.-],        mep:MPQ_0284 [5.3.1.16])        => [2.4.2.-]
    (metr:BSY238_2540 [4.1.3.-],    metr:BSY238_2539 [5.3.1.16])    => [2.4.2.-]
    (meu:ACJ67_02440 [4.1.3.-],     meu:ACJ67_02435 [5.3.1.16])     => [2.4.2.-]
    (mfa:Mfla_0254 [4.1.3.-],       mfa:Mfla_0253 [5.3.1.16])       => [2.4.2.-]
    (mmb:Mmol_0317 [4.1.3.-],       mmb:Mmol_0316 [5.3.1.16])       => [2.4.2.-]
    (mms:mma_3283 [4.1.3.-],        mms:mma_3284 [5.3.1.16])        => [2.4.2.-]
    (mnr:ACZ75_19875 [4.1.3.-],     mnr:ACZ75_19870 [5.3.1.16])     => [2.4.2.-]
    (mpt:Mpe_A0836 [4.1.3.-],       mpt:Mpe_A0835 [5.3.1.16])       => [2.4.2.-]
    (nco:AAW31_17410 [4.1.3.-],     nco:AAW31_17415 [5.3.1.16])     => [2.4.2.-]
    (nel:NELON_04670 [4.1.3.-],     nel:NELON_04660 [5.3.1.16])     => [2.4.2.-]
    (net:Neut_1909 [4.1.3.-],       net:Neut_1908 [5.3.1.16])       => [2.4.2.-]
    (neu:NE0643 [4.1.3.-],          neu:NE0644 [5.3.1.16])          => [2.4.2.-]
    (ngo:NGO0211 [4.1.3.-],         ngo:NGO0212 [5.3.1.16])         => [2.4.2.-]
    (nii:Nit79A3_1044 [4.1.3.-],    nii:Nit79A3_1045 [5.3.1.16])    => [2.4.2.-]
    (nla:NLA_16030 [4.1.3.-],       nla:NLA_16020 [5.3.1.16])       => [2.4.2.-]
    (nlc:EBAPG3_006305 [4.1.3.-],   nlc:EBAPG3_006310 [5.3.1.16])   => [2.4.2.-]
    (nma:NMA0838 [4.1.3.-],         nma:NMA0839 [5.3.1.16])         => [2.4.2.-]
    (nmu:Nmul_A0814 [4.1.3.-],      nmu:Nmul_A0815 [5.3.1.16])      => [2.4.2.-]
    (nsi:A6J88_13230 [4.1.3.-],     nsi:A6J88_13240 [5.3.1.16])     => [2.4.2.-]
    (nwe:SAMEA3174300_0041 [4.1.3.-],       nwe:SAMEA3174300_0039 [5.3.1.16])       => [2.4.2.-]
    (odi:ODI_R0270 [4.1.3.-],       odi:ODI_R0271 [5.3.1.16])       => [2.4.2.-]
    (ofo:BRW83_0194 [4.1.3.-],      ofo:BRW83_0193 [5.3.1.16])      => [2.4.2.-]
    (oto:ADJ79_05965 [4.1.3.-],     oto:ADJ79_02380 [5.3.1.16])     => [2.4.2.-]
    (papi:SG18_06885 [4.1.3.-],     papi:SG18_06890 [5.3.1.16])     => [2.4.2.-]
    (para:BTO02_18755 [4.1.3.-],    para:BTO02_18760 [5.3.1.16])    => [2.4.2.-]
    (parb:CJU94_07155 [4.1.3.-],    parb:CJU94_07150 [5.3.1.16])    => [2.4.2.-]
    (pbh:AAW51_4651 [4.1.3.-],      pbh:AAW51_4652 [5.3.1.16])      => [2.4.2.-]
    (pdq:CL55_00001100 [4.1.3.-],   pdq:CL55_00001090 [5.3.1.16])   => [2.4.2.-]
    (pfg:AB870_09440 [4.1.3.-],     pfg:AB870_09445 [5.3.1.16])     => [2.4.2.-]
    (phn:PAEH1_08825 [4.1.3.-],     phn:PAEH1_08830 [5.3.1.16])     => [2.4.2.-]
    (phs:C2L64_16400 [4.1.3.-],     phs:C2L64_16405 [5.3.1.16])     => [2.4.2.-]
    (pkt:AT984_01545 [4.1.3.-],     pkt:AT984_01540 [5.3.1.16])     => [2.4.2.-]
    (pne:Pnec_0111 [4.1.3.-],       pne:Pnec_0110 [5.3.1.16])       => [2.4.2.-]
    (pnr:AT302_06085 [4.1.3.-],     pnr:AT302_06090 [5.3.1.16])     => [2.4.2.-]
    (pnu:Pnuc_0112 [4.1.3.-],       pnu:Pnuc_0111 [5.3.1.16])       => [2.4.2.-]
    (pox:MB84_02490 [4.1.3.-],      pox:MB84_02495 [5.3.1.16])      => [2.4.2.-]
    (ppk:U875_00645 [4.1.3.-],      ppk:U875_00640 [5.3.1.16])      => [2.4.2.-]
    (ppul:RO07_06495 [4.1.3.-],     ppul:RO07_06500 [5.3.1.16])     => [2.4.2.-]
    (pse:NH8B_3828 [4.1.3.-],       pse:NH8B_3829 [5.3.1.16])       => [2.4.2.-]
    (pspu:NA29_02365 [4.1.3.-],     pspu:NA29_02370 [5.3.1.16])     => [2.4.2.-]
    (pspw:BJG93_14435 [4.1.3.-],    pspw:BJG93_14430 [5.3.1.16])    => [2.4.2.-]
    (pter:C2L65_14240 [4.1.3.-],    pter:C2L65_14245 [5.3.1.16])    => [2.4.2.-]
    (ptx:ABW99_18420 [4.1.3.-],     ptx:ABW99_18415 [5.3.1.16])     => [2.4.2.-]
    (put:PT7_3117 [4.1.3.-],        put:PT7_3118 [5.3.1.16])        => [2.4.2.-]
    (pve:UC34_22565 [4.1.3.-],      pve:UC34_22570 [5.3.1.16])      => [2.4.2.-]
    (rbn:RBXJA2T_15493 [4.1.3.-],   rbn:RBXJA2T_15488 [5.3.1.16])   => [2.4.2.-]
    (rbu:PG1C_10135 [4.1.3.-],      rbu:PG1C_10140 [5.3.1.16])      => [2.4.2.-]
    (rdp:RD2015_4184 [4.1.3.-],     rdp:RD2015_4185 [5.3.1.16])     => [2.4.2.-]
    (reh:H16_A3410 [4.1.3.-],       reh:H16_A3411 [5.3.1.16])       => [2.4.2.-]
    (reu:Reut_A3105 [4.1.3.-],      reu:Reut_A3106 [5.3.1.16])      => [2.4.2.-]
    (rge:RGE_08640 [4.1.3.-],       rge:RGE_08630 [5.3.1.16])       => [2.4.2.-]
    (rgu:A4W93_04900 [4.1.3.-],     rgu:A4W93_04895 [5.3.1.16])     => [2.4.2.-]
    (rin:ACS15_3305 [4.1.3.-],      rin:ACS15_3306 [5.3.1.16])      => [2.4.2.-]
    (rme:Rmet_3242 [4.1.3.-],       rme:Rmet_3243 [5.3.1.16])       => [2.4.2.-]
    (rmn:TK49_00365 [4.1.3.-],      rmn:TK49_00370 [5.3.1.16])      => [2.4.2.-]
    (rpi:Rpic_3223 [4.1.3.-],       rpi:Rpic_3224 [5.3.1.16])       => [2.4.2.-]
    (rsb:RS694_16185 [4.1.3.-],     rsb:RS694_16190 [5.3.1.16])     => [2.4.2.-]
    (rso:RSc2946 [4.1.3.-],         rso:RSc2947 [5.3.1.16])         => [2.4.2.-]
    (salv:SALWKB2_1725 [4.1.3.-],   salv:SALWKB2_1727 [5.3.1.16])   => [2.4.2.-]
    (sdr:SCD_n00591 [4.1.3.-],      sdr:SCD_n00590 [5.3.1.16])      => [2.4.2.-]
    (shd:SUTH_02839 [4.1.3.-],      shd:SUTH_02840 [5.3.1.16])      => [2.4.2.-]
    (sulf:CAP31_05295 [4.1.3.-],    sulf:CAP31_05300 [5.3.1.16])    => [2.4.2.-]
    (tbd:Tbd_1708 [4.1.3.-],        tbd:Tbd_1709 [5.3.1.16])        => [2.4.2.-]
    (tcl:Tchl_0637 [4.1.3.-],       tcl:Tchl_0636 [5.3.1.16])       => [2.4.2.-]
    (thi:THI_1118 [4.1.3.-],        thi:THI_1117 [5.3.1.16])        => [2.4.2.-]
    (thk:CCZ27_00850 [4.1.3.-],     thk:CCZ27_00845 [5.3.1.16])     => [2.4.2.-]
    (thu:AC731_018095 [4.1.3.-],    thu:AC731_018090 [5.3.1.16])    => [2.4.2.-]
    (tin:Tint_0867 [4.1.3.-],       tin:Tint_0866 [5.3.1.16])       => [2.4.2.-]
    (vbo:CKY39_05960 [4.1.3.-],     vbo:CKY39_05935 [5.3.1.16])     => [2.4.2.-]
    (vff:VITFI_CDS2687 [4.1.3.-],   vff:VITFI_CDS2688 [5.3.1.16])   => [2.4.2.-]
    (zin:ZICARI_180 [4.1.3.-],      zin:ZICARI_181 [5.3.1.16])      => [2.4.2.-]
    (aaa:Acav_1539 [6.2.1.1],       aaa:Acav_2415 [6.2.1.3])        => [3.1.2.-]
    (aaa:Acav_1539 [6.2.1.1],       aaa:Acav_4494 [6.2.1.3])        => [3.1.2.-]
    (aaa:Acav_2427 [6.2.1.1],       aaa:Acav_2415 [6.2.1.3])        => [3.1.2.-]
    (aaa:Acav_2427 [6.2.1.1],       aaa:Acav_4494 [6.2.1.3])        => [3.1.2.-]
    (aav:Aave_1499 [6.2.1.1],       aav:Aave_4574 [6.2.1.3])        => [3.1.2.-]
    (achr:C2U31_13190 [6.2.1.1],    achr:C2U31_08890 [6.2.1.3])     => [3.1.2.-]
    (achr:C2U31_13190 [6.2.1.1],    achr:C2U31_22425 [6.2.1.3])     => [3.1.2.-]
    (achr:C2U31_13190 [6.2.1.1],    achr:C2U31_26190 [6.2.1.3])     => [3.1.2.-]
    (achr:C2U31_13350 [6.2.1.1],    achr:C2U31_03265 [6.2.1.3])     => [3.1.2.-]
    (achr:C2U31_13350 [6.2.1.1],    achr:C2U31_08890 [6.2.1.3])     => [3.1.2.-]
    (achr:C2U31_13350 [6.2.1.1],    achr:C2U31_22425 [6.2.1.3])     => [3.1.2.-]
    (achr:C2U31_13350 [6.2.1.1],    achr:C2U31_26190 [6.2.1.3])     => [3.1.2.-]
    (achr:C2U31_21745 [6.2.1.1],    achr:C2U31_08890 [6.2.1.3])     => [3.1.2.-]
    (achr:C2U31_21745 [6.2.1.1],    achr:C2U31_22425 [6.2.1.3])     => [3.1.2.-]
    (achr:C2U31_21745 [6.2.1.1],    achr:C2U31_26190 [6.2.1.3])     => [3.1.2.-]
    (acid:CBP33_07535 [6.2.1.1],    acid:CBP33_17730 [6.2.1.3])     => [3.1.2.-]
    (acid:CBP33_08165 [6.2.1.1],    acid:CBP33_17730 [6.2.1.3])     => [3.1.2.-]
    (acin:CBP34_07435 [6.2.1.1],    acin:CBP34_18350 [6.2.1.3])     => [3.1.2.-]
    (acip:CBP36_08105 [6.2.1.1],    acip:CBP36_18010 [6.2.1.3])     => [3.1.2.-]
    (ack:C380_15660 [6.2.1.1],      ack:C380_00030 [6.2.1.3])       => [3.1.2.-]
    (ack:C380_15660 [6.2.1.1],      ack:C380_02255 [6.2.1.3])       => [3.1.2.-]
    (ack:C380_15660 [6.2.1.1],      ack:C380_22580 [6.2.1.3])       => [3.1.2.-]
    (acra:BSY15_48 [6.2.1.1],       acra:BSY15_1176 [6.2.1.3])      => [3.1.2.-]
    (acra:BSY15_48 [6.2.1.1],       acra:BSY15_1452 [6.2.1.3])      => [3.1.2.-]
    (acra:BSY15_48 [6.2.1.1],       acra:BSY15_5 [6.2.1.3])         => [3.1.2.-]
    (adn:Alide_1147 [6.2.1.1],      adn:Alide_4154 [6.2.1.3])       => [3.1.2.-]
    (adn:Alide_2935 [6.2.1.1],      adn:Alide_4154 [6.2.1.3])       => [3.1.2.-]
    (adn:Alide_4206 [6.2.1.1],      adn:Alide_4154 [6.2.1.3])       => [3.1.2.-]
    (adn:Alide_4322 [6.2.1.1],      adn:Alide_4154 [6.2.1.3])       => [3.1.2.-]
    (adt:APT56_06955 [6.2.1.1],     adt:APT56_04460 [6.2.1.3])      => [3.1.2.-]
    (adt:APT56_06955 [6.2.1.1],     adt:APT56_20045 [6.2.1.3])      => [3.1.2.-]
    (adt:APT56_07095 [6.2.1.1],     adt:APT56_04460 [6.2.1.3])      => [3.1.2.-]
    (adt:APT56_07095 [6.2.1.1],     adt:APT56_20045 [6.2.1.3])      => [3.1.2.-]
    (adt:APT56_07095 [6.2.1.1],     adt:APT56_26880 [6.2.1.3])      => [3.1.2.-]
    (adt:APT56_10850 [6.2.1.1],     adt:APT56_04460 [6.2.1.3])      => [3.1.2.-]
    (adt:APT56_10850 [6.2.1.1],     adt:APT56_17615 [6.2.1.3])      => [3.1.2.-]
    (adt:APT56_10850 [6.2.1.1],     adt:APT56_20045 [6.2.1.3])      => [3.1.2.-]
    (adt:APT56_10850 [6.2.1.1],     adt:APT56_26880 [6.2.1.3])      => [3.1.2.-]
    (afa:UZ73_03200 [6.2.1.1],      afa:UZ73_06630 [6.2.1.3])       => [3.1.2.-]
    (afa:UZ73_03200 [6.2.1.1],      afa:UZ73_11085 [6.2.1.3])       => [3.1.2.-]
    (afa:UZ73_06130 [6.2.1.1],      afa:UZ73_06630 [6.2.1.3])       => [3.1.2.-]
    (afa:UZ73_06130 [6.2.1.1],      afa:UZ73_09570 [6.2.1.3])       => [3.1.2.-]
    (afa:UZ73_06130 [6.2.1.1],      afa:UZ73_11085 [6.2.1.3])       => [3.1.2.-]
    (ais:BUW96_02335 [6.2.1.1],     ais:BUW96_03095 [6.2.1.3])      => [3.1.2.-]
    (ais:BUW96_02335 [6.2.1.1],     ais:BUW96_11380 [6.2.1.3])      => [3.1.2.-]
    (ais:BUW96_02335 [6.2.1.1],     ais:BUW96_11745 [6.2.1.3])      => [3.1.2.-]
    (ais:BUW96_02335 [6.2.1.1],     ais:BUW96_21525 [6.2.1.3])      => [3.1.2.-]
    (ais:BUW96_02335 [6.2.1.1],     ais:BUW96_24205 [6.2.1.3])      => [3.1.2.-]
    (ais:BUW96_18325 [6.2.1.1],     ais:BUW96_03095 [6.2.1.3])      => [3.1.2.-]
    (ais:BUW96_18325 [6.2.1.1],     ais:BUW96_11380 [6.2.1.3])      => [3.1.2.-]
    (ais:BUW96_18325 [6.2.1.1],     ais:BUW96_11745 [6.2.1.3])      => [3.1.2.-]
    (ais:BUW96_18325 [6.2.1.1],     ais:BUW96_21525 [6.2.1.3])      => [3.1.2.-]
    (ais:BUW96_18325 [6.2.1.1],     ais:BUW96_24205 [6.2.1.3])      => [3.1.2.-]
    (ais:BUW96_18505 [6.2.1.1],     ais:BUW96_03095 [6.2.1.3])      => [3.1.2.-]
    (ais:BUW96_18505 [6.2.1.1],     ais:BUW96_11380 [6.2.1.3])      => [3.1.2.-]
    (ais:BUW96_18505 [6.2.1.1],     ais:BUW96_11745 [6.2.1.3])      => [3.1.2.-]
    (ais:BUW96_18505 [6.2.1.1],     ais:BUW96_21525 [6.2.1.3])      => [3.1.2.-]
    (ajs:Ajs_1067 [6.2.1.1],        ajs:Ajs_3950 [6.2.1.3])         => [3.1.2.-]
    (aka:TKWG_10060 [6.2.1.1],      aka:TKWG_23800 [6.2.1.3])       => [3.1.2.-]
    (amim:MIM_c23610 [6.2.1.1],     amim:MIM_c01110 [6.2.1.3])      => [3.1.2.-]
    (amim:MIM_c23610 [6.2.1.1],     amim:MIM_c23700 [6.2.1.3])      => [3.1.2.-]
    (amim:MIM_c38630 [6.2.1.1],     amim:MIM_c01110 [6.2.1.3])      => [3.1.2.-]
    (amim:MIM_c38630 [6.2.1.1],     amim:MIM_c07010 [6.2.1.3])      => [3.1.2.-]
    (amim:MIM_c38630 [6.2.1.1],     amim:MIM_c23700 [6.2.1.3])      => [3.1.2.-]
    (aoa:dqs_2558 [6.2.1.1],        aoa:dqs_1141 [6.2.1.3])         => [3.1.2.-]
    (app:CAP2UW1_2247 [6.2.1.1],    app:CAP2UW1_1889 [6.2.1.3])     => [3.1.2.-]
    (app:CAP2UW1_2247 [6.2.1.1],    app:CAP2UW1_3331 [6.2.1.3])     => [3.1.2.-]
    (app:CAP2UW1_3755 [6.2.1.1],    app:CAP2UW1_1889 [6.2.1.3])     => [3.1.2.-]
    (app:CAP2UW1_3755 [6.2.1.1],    app:CAP2UW1_3331 [6.2.1.3])     => [3.1.2.-]
    (aql:BXU06_06255 [6.2.1.1],     aql:BXU06_05445 [6.2.1.3])      => [3.1.2.-]
    (asw:CVS48_10110 [6.2.1.1],     asw:CVS48_02350 [6.2.1.3])      => [3.1.2.-]
    (asw:CVS48_10110 [6.2.1.1],     asw:CVS48_23515 [6.2.1.3])      => [3.1.2.-]
    (asw:CVS48_10110 [6.2.1.1],     asw:CVS48_23880 [6.2.1.3])      => [3.1.2.-]
    (asw:CVS48_13690 [6.2.1.1],     asw:CVS48_02350 [6.2.1.3])      => [3.1.2.-]
    (asw:CVS48_13690 [6.2.1.1],     asw:CVS48_23515 [6.2.1.3])      => [3.1.2.-]
    (asw:CVS48_13690 [6.2.1.1],     asw:CVS48_23880 [6.2.1.3])      => [3.1.2.-]
    (asw:CVS48_15660 [6.2.1.1],     asw:CVS48_02350 [6.2.1.3])      => [3.1.2.-]
    (asw:CVS48_15660 [6.2.1.1],     asw:CVS48_07560 [6.2.1.3])      => [3.1.2.-]
    (asw:CVS48_15660 [6.2.1.1],     asw:CVS48_23515 [6.2.1.3])      => [3.1.2.-]
    (asw:CVS48_15660 [6.2.1.1],     asw:CVS48_23880 [6.2.1.3])      => [3.1.2.-]
    (asw:CVS48_28150 [6.2.1.1],     asw:CVS48_02350 [6.2.1.3])      => [3.1.2.-]
    (asw:CVS48_28150 [6.2.1.1],     asw:CVS48_23515 [6.2.1.3])      => [3.1.2.-]
    (asw:CVS48_28150 [6.2.1.1],     asw:CVS48_23880 [6.2.1.3])      => [3.1.2.-]
    (axy:AXYL_01580 [6.2.1.1],      axy:AXYL_00813 [6.2.1.3])       => [3.1.2.-]
    (axy:AXYL_01580 [6.2.1.1],      axy:AXYL_02583 [6.2.1.3])       => [3.1.2.-]
    (axy:AXYL_01580 [6.2.1.1],      axy:AXYL_04432 [6.2.1.3])       => [3.1.2.-]
    (axy:AXYL_01580 [6.2.1.1],      axy:AXYL_04504 [6.2.1.3])       => [3.1.2.-]
    (axy:AXYL_01616 [6.2.1.1],      axy:AXYL_00813 [6.2.1.3])       => [3.1.2.-]
    (axy:AXYL_01616 [6.2.1.1],      axy:AXYL_02583 [6.2.1.3])       => [3.1.2.-]
    (axy:AXYL_01616 [6.2.1.1],      axy:AXYL_04432 [6.2.1.3])       => [3.1.2.-]
    (axy:AXYL_01616 [6.2.1.1],      axy:AXYL_04504 [6.2.1.3])       => [3.1.2.-]
    (axy:AXYL_01616 [6.2.1.1],      axy:AXYL_06189 [6.2.1.3])       => [3.1.2.-]
    (axy:AXYL_02409 [6.2.1.1],      axy:AXYL_00813 [6.2.1.3])       => [3.1.2.-]
    (axy:AXYL_02409 [6.2.1.1],      axy:AXYL_02583 [6.2.1.3])       => [3.1.2.-]
    (axy:AXYL_02409 [6.2.1.1],      axy:AXYL_04432 [6.2.1.3])       => [3.1.2.-]
    (axy:AXYL_02409 [6.2.1.1],      axy:AXYL_04504 [6.2.1.3])       => [3.1.2.-]
    (axy:AXYL_02409 [6.2.1.1],      axy:AXYL_06189 [6.2.1.3])       => [3.1.2.-]
    (aza:AZKH_0568 [6.2.1.1],       aza:AZKH_2502 [6.2.1.3])        => [3.1.2.-]
    (aza:AZKH_0568 [6.2.1.1],       aza:AZKH_3122 [6.2.1.3])        => [3.1.2.-]
    (aza:AZKH_0851 [6.2.1.1],       aza:AZKH_2502 [6.2.1.3])        => [3.1.2.-]
    (aza:AZKH_0851 [6.2.1.1],       aza:AZKH_3122 [6.2.1.3])        => [3.1.2.-]
    (aza:AZKH_1504 [6.2.1.1],       aza:AZKH_2502 [6.2.1.3])        => [3.1.2.-]
    (aza:AZKH_1504 [6.2.1.1],       aza:AZKH_3122 [6.2.1.3])        => [3.1.2.-]
    (aza:AZKH_1719 [6.2.1.1],       aza:AZKH_2502 [6.2.1.3])        => [3.1.2.-]
    (aza:AZKH_1719 [6.2.1.1],       aza:AZKH_3122 [6.2.1.3])        => [3.1.2.-]
    (azi:AzCIB_0750 [6.2.1.1],      azi:AzCIB_3050 [6.2.1.3])       => [3.1.2.-]
    (azi:AzCIB_1014 [6.2.1.1],      azi:AzCIB_3050 [6.2.1.3])       => [3.1.2.-]
    (azi:AzCIB_1325 [6.2.1.1],      azi:AzCIB_3050 [6.2.1.3])       => [3.1.2.-]
    (azi:AzCIB_3999 [6.2.1.1],      azi:AzCIB_3050 [6.2.1.3])       => [3.1.2.-]
    (azo:azo2414 [6.2.1.1],         azo:azo1033 [6.2.1.3])          => [3.1.2.-]
    (bam:Bamb_1201 [6.2.1.1],       bam:Bamb_0451 [6.2.1.3])        => [3.1.2.-]
    (bam:Bamb_1201 [6.2.1.1],       bam:Bamb_1416 [6.2.1.3])        => [3.1.2.-]
    (bam:Bamb_1201 [6.2.1.1],       bam:Bamb_5782 [6.2.1.3])        => [3.1.2.-]
    (bam:Bamb_2230 [6.2.1.1],       bam:Bamb_0451 [6.2.1.3])        => [3.1.2.-]
    (bam:Bamb_2230 [6.2.1.1],       bam:Bamb_1416 [6.2.1.3])        => [3.1.2.-]
    (bam:Bamb_2230 [6.2.1.1],       bam:Bamb_5782 [6.2.1.3])        => [3.1.2.-]
    (bam:Bamb_4384 [6.2.1.1],       bam:Bamb_0451 [6.2.1.3])        => [3.1.2.-]
    (bam:Bamb_4384 [6.2.1.1],       bam:Bamb_1416 [6.2.1.3])        => [3.1.2.-]
    (bam:Bamb_4384 [6.2.1.1],       bam:Bamb_5782 [6.2.1.3])        => [3.1.2.-]
    (bam:Bamb_5971 [6.2.1.1],       bam:Bamb_0451 [6.2.1.3])        => [3.1.2.-]
    (bam:Bamb_5971 [6.2.1.1],       bam:Bamb_1416 [6.2.1.3])        => [3.1.2.-]
    (bam:Bamb_5971 [6.2.1.1],       bam:Bamb_5782 [6.2.1.3])        => [3.1.2.-]
    (bam:Bamb_6158 [6.2.1.1],       bam:Bamb_0451 [6.2.1.3])        => [3.1.2.-]
    (bam:Bamb_6158 [6.2.1.1],       bam:Bamb_1416 [6.2.1.3])        => [3.1.2.-]
    (bam:Bamb_6158 [6.2.1.1],       bam:Bamb_5782 [6.2.1.3])        => [3.1.2.-]
    (bav:BAV1149 [6.2.1.1],         bav:BAV2858 [6.2.1.3])          => [3.1.2.-]
    (bav:BAV1171 [6.2.1.1],         bav:BAV0187 [6.2.1.3])          => [3.1.2.-]
    (bav:BAV1171 [6.2.1.1],         bav:BAV2858 [6.2.1.3])          => [3.1.2.-]
    (bbag:E1O_05800 [6.2.1.1],      bbag:E1O_03600 [6.2.1.3])       => [3.1.2.-]
    (bbr:BB0615 [6.2.1.1],          bbr:BB1125 [6.2.1.3])           => [3.1.2.-]
    (bbr:BB0615 [6.2.1.1],          bbr:BB1789 [6.2.1.3])           => [3.1.2.-]
    (bbr:BB0615 [6.2.1.1],          bbr:BB4175 [6.2.1.3])           => [3.1.2.-]
    (bbr:BB1153 [6.2.1.1],          bbr:BB1125 [6.2.1.3])           => [3.1.2.-]
    (bbr:BB1153 [6.2.1.1],          bbr:BB1789 [6.2.1.3])           => [3.1.2.-]
    (bbr:BB1153 [6.2.1.1],          bbr:BB4175 [6.2.1.3])           => [3.1.2.-]
    (bbr:BB3695 [6.2.1.1],          bbr:BB0233 [6.2.1.3])           => [3.1.2.-]
    (bbr:BB3695 [6.2.1.1],          bbr:BB1125 [6.2.1.3])           => [3.1.2.-]
    (bbr:BB3695 [6.2.1.1],          bbr:BB1789 [6.2.1.3])           => [3.1.2.-]
    (bbr:BB3695 [6.2.1.1],          bbr:BB4175 [6.2.1.3])           => [3.1.2.-]
    (bbr:BB3725 [6.2.1.1],          bbr:BB1125 [6.2.1.3])           => [3.1.2.-]
    (bbr:BB3725 [6.2.1.1],          bbr:BB1789 [6.2.1.3])           => [3.1.2.-]
    (bbr:BB3725 [6.2.1.1],          bbr:BB4175 [6.2.1.3])           => [3.1.2.-]
    (bbro:BAU06_08060 [6.2.1.1],    bbro:BAU06_20275 [6.2.1.3])     => [3.1.2.-]
    (bbro:BAU06_08195 [6.2.1.1],    bbro:BAU06_20275 [6.2.1.3])     => [3.1.2.-]
    (bbro:BAU06_08195 [6.2.1.1],    bbro:BAU06_24265 [6.2.1.3])     => [3.1.2.-]
    (bcai:K788_0002231 [6.2.1.1],   bcai:K788_0001161 [6.2.1.3])    => [3.1.2.-]
    (bcai:K788_0002231 [6.2.1.1],   bcai:K788_0002435 [6.2.1.3])    => [3.1.2.-]
    (bcai:K788_0002231 [6.2.1.1],   bcai:K788_0006803 [6.2.1.3])    => [3.1.2.-]
    (bcai:K788_0002254 [6.2.1.1],   bcai:K788_0001161 [6.2.1.3])    => [3.1.2.-]
    (bcai:K788_0002254 [6.2.1.1],   bcai:K788_0002435 [6.2.1.3])    => [3.1.2.-]
    (bcai:K788_0002254 [6.2.1.1],   bcai:K788_0006803 [6.2.1.3])    => [3.1.2.-]
    (bcai:K788_0002254 [6.2.1.1],   bcai:K788_0008577 [6.2.1.3])    => [3.1.2.-]
    (bcai:K788_0008225 [6.2.1.1],   bcai:K788_0001161 [6.2.1.3])    => [3.1.2.-]
    (bcai:K788_0008225 [6.2.1.1],   bcai:K788_0002435 [6.2.1.3])    => [3.1.2.-]
    (bcai:K788_0008225 [6.2.1.1],   bcai:K788_0006803 [6.2.1.3])    => [3.1.2.-]
    (bcai:K788_0008225 [6.2.1.1],   bcai:K788_0008577 [6.2.1.3])    => [3.1.2.-]
    (bcn:Bcen_0835 [6.2.1.1],       bcn:Bcen_0064 [6.2.1.3])        => [3.1.2.-]
    (bcn:Bcen_0835 [6.2.1.1],       bcn:Bcen_1054 [6.2.1.3])        => [3.1.2.-]
    (bcn:Bcen_0835 [6.2.1.1],       bcn:Bcen_1557 [6.2.1.3])        => [3.1.2.-]
    (bcn:Bcen_1428 [6.2.1.1],       bcn:Bcen_0064 [6.2.1.3])        => [3.1.2.-]
    (bcn:Bcen_1428 [6.2.1.1],       bcn:Bcen_1054 [6.2.1.3])        => [3.1.2.-]
    (bcn:Bcen_1428 [6.2.1.1],       bcn:Bcen_1557 [6.2.1.3])        => [3.1.2.-]
    (bcn:Bcen_1601 [6.2.1.1],       bcn:Bcen_0064 [6.2.1.3])        => [3.1.2.-]
    (bcn:Bcen_1601 [6.2.1.1],       bcn:Bcen_1054 [6.2.1.3])        => [3.1.2.-]
    (bcn:Bcen_1601 [6.2.1.1],       bcn:Bcen_1557 [6.2.1.3])        => [3.1.2.-]
    (bcn:Bcen_3238 [6.2.1.1],       bcn:Bcen_0064 [6.2.1.3])        => [3.1.2.-]
    (bcn:Bcen_3238 [6.2.1.1],       bcn:Bcen_1054 [6.2.1.3])        => [3.1.2.-]
    (bcn:Bcen_3238 [6.2.1.1],       bcn:Bcen_1557 [6.2.1.3])        => [3.1.2.-]
    (bcn:Bcen_3405 [6.2.1.1],       bcn:Bcen_0064 [6.2.1.3])        => [3.1.2.-]
    (bcn:Bcen_3405 [6.2.1.1],       bcn:Bcen_1054 [6.2.1.3])        => [3.1.2.-]
    (bcn:Bcen_3405 [6.2.1.1],       bcn:Bcen_1557 [6.2.1.3])        => [3.1.2.-]
    (bcn:Bcen_5886 [6.2.1.1],       bcn:Bcen_0064 [6.2.1.3])        => [3.1.2.-]
    (bcn:Bcen_5886 [6.2.1.1],       bcn:Bcen_1054 [6.2.1.3])        => [3.1.2.-]
    (bcn:Bcen_5886 [6.2.1.1],       bcn:Bcen_1557 [6.2.1.3])        => [3.1.2.-]
    (bcon:NL30_00605 [6.2.1.1],     bcon:NL30_15565 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_00605 [6.2.1.1],     bcon:NL30_21345 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_00605 [6.2.1.1],     bcon:NL30_31680 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_00605 [6.2.1.1],     bcon:NL30_31795 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_01435 [6.2.1.1],     bcon:NL30_15565 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_01435 [6.2.1.1],     bcon:NL30_21345 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_01435 [6.2.1.1],     bcon:NL30_31680 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_01435 [6.2.1.1],     bcon:NL30_31795 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_09090 [6.2.1.1],     bcon:NL30_15565 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_09090 [6.2.1.1],     bcon:NL30_21345 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_09090 [6.2.1.1],     bcon:NL30_31680 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_09090 [6.2.1.1],     bcon:NL30_31795 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_25515 [6.2.1.1],     bcon:NL30_15565 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_25515 [6.2.1.1],     bcon:NL30_21345 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_25515 [6.2.1.1],     bcon:NL30_31680 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_25515 [6.2.1.1],     bcon:NL30_31795 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_33335 [6.2.1.1],     bcon:NL30_15565 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_33335 [6.2.1.1],     bcon:NL30_21345 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_33335 [6.2.1.1],     bcon:NL30_31680 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_33335 [6.2.1.1],     bcon:NL30_31795 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_33430 [6.2.1.1],     bcon:NL30_15565 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_33430 [6.2.1.1],     bcon:NL30_21345 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_33430 [6.2.1.1],     bcon:NL30_31680 [6.2.1.3])      => [3.1.2.-]
    (bcon:NL30_33430 [6.2.1.1],     bcon:NL30_31795 [6.2.1.3])      => [3.1.2.-]
    (bct:GEM_1224 [6.2.1.1],        bct:GEM_1899 [6.2.1.3])         => [3.1.2.-]
    (bct:GEM_1224 [6.2.1.1],        bct:GEM_2236 [6.2.1.3])         => [3.1.2.-]
    (bct:GEM_1224 [6.2.1.1],        bct:GEM_2971 [6.2.1.3])         => [3.1.2.-]
    (bct:GEM_2137 [6.2.1.1],        bct:GEM_1899 [6.2.1.3])         => [3.1.2.-]
    (bct:GEM_2137 [6.2.1.1],        bct:GEM_2236 [6.2.1.3])         => [3.1.2.-]
    (bct:GEM_2137 [6.2.1.1],        bct:GEM_2971 [6.2.1.3])         => [3.1.2.-]
    (bct:GEM_3469 [6.2.1.1],        bct:GEM_1899 [6.2.1.3])         => [3.1.2.-]
    (bct:GEM_3469 [6.2.1.1],        bct:GEM_2236 [6.2.1.3])         => [3.1.2.-]
    (bct:GEM_3469 [6.2.1.1],        bct:GEM_2971 [6.2.1.3])         => [3.1.2.-]
    (bdf:WI26_06045 [6.2.1.1],      bdf:WI26_02280 [6.2.1.3])       => [3.1.2.-]
    (bdf:WI26_06045 [6.2.1.1],      bdf:WI26_06990 [6.2.1.3])       => [3.1.2.-]
    (bdf:WI26_06045 [6.2.1.1],      bdf:WI26_26935 [6.2.1.3])       => [3.1.2.-]
    (bdf:WI26_10580 [6.2.1.1],      bdf:WI26_02280 [6.2.1.3])       => [3.1.2.-]
    (bdf:WI26_10580 [6.2.1.1],      bdf:WI26_06990 [6.2.1.3])       => [3.1.2.-]
    (bdf:WI26_10580 [6.2.1.1],      bdf:WI26_26935 [6.2.1.3])       => [3.1.2.-]
    (bdf:WI26_23850 [6.2.1.1],      bdf:WI26_02280 [6.2.1.3])       => [3.1.2.-]
    (bdf:WI26_23850 [6.2.1.1],      bdf:WI26_06990 [6.2.1.3])       => [3.1.2.-]
    (bdf:WI26_23850 [6.2.1.1],      bdf:WI26_26935 [6.2.1.3])       => [3.1.2.-]
    (bdf:WI26_28390 [6.2.1.1],      bdf:WI26_02280 [6.2.1.3])       => [3.1.2.-]
    (bdf:WI26_28390 [6.2.1.1],      bdf:WI26_06990 [6.2.1.3])       => [3.1.2.-]
    (bdf:WI26_28390 [6.2.1.1],      bdf:WI26_26935 [6.2.1.3])       => [3.1.2.-]
    (bdf:WI26_29530 [6.2.1.1],      bdf:WI26_02280 [6.2.1.3])       => [3.1.2.-]
    (bdf:WI26_29530 [6.2.1.1],      bdf:WI26_06990 [6.2.1.3])       => [3.1.2.-]
    (bdf:WI26_29530 [6.2.1.1],      bdf:WI26_26935 [6.2.1.3])       => [3.1.2.-]
    (bdf:WI26_30110 [6.2.1.1],      bdf:WI26_02280 [6.2.1.3])       => [3.1.2.-]
    (bdf:WI26_30110 [6.2.1.1],      bdf:WI26_06990 [6.2.1.3])       => [3.1.2.-]
    (bdf:WI26_30110 [6.2.1.1],      bdf:WI26_26935 [6.2.1.3])       => [3.1.2.-]
    (bdl:AK34_1850 [6.2.1.1],       bdl:AK34_1636 [6.2.1.3])        => [3.1.2.-]
    (bdl:AK34_1850 [6.2.1.1],       bdl:AK34_2595 [6.2.1.3])        => [3.1.2.-]
    (bdl:AK34_3563 [6.2.1.1],       bdl:AK34_1636 [6.2.1.3])        => [3.1.2.-]
    (bdl:AK34_3563 [6.2.1.1],       bdl:AK34_2595 [6.2.1.3])        => [3.1.2.-]
    (bdl:AK34_5313 [6.2.1.1],       bdl:AK34_1636 [6.2.1.3])        => [3.1.2.-]
    (bdl:AK34_5313 [6.2.1.1],       bdl:AK34_2595 [6.2.1.3])        => [3.1.2.-]
    (bdl:AK34_5434 [6.2.1.1],       bdl:AK34_1636 [6.2.1.3])        => [3.1.2.-]
    (bdl:AK34_5434 [6.2.1.1],       bdl:AK34_2595 [6.2.1.3])        => [3.1.2.-]
    (bdl:AK34_925 [6.2.1.1],        bdl:AK34_1636 [6.2.1.3])        => [3.1.2.-]
    (bdl:AK34_925 [6.2.1.1],        bdl:AK34_2595 [6.2.1.3])        => [3.1.2.-]
    (beb:AEM42_13155 [6.2.1.1],     beb:AEM42_09160 [6.2.1.3])      => [3.1.2.-]
    (beba:BWI17_05810 [6.2.1.1],    beba:BWI17_00995 [6.2.1.3])     => [3.1.2.-]
    (beba:BWI17_05810 [6.2.1.1],    beba:BWI17_16015 [6.2.1.3])     => [3.1.2.-]
    (beba:BWI17_20430 [6.2.1.1],    beba:BWI17_16015 [6.2.1.3])     => [3.1.2.-]
    (bfn:OI25_335 [6.2.1.1],        bfn:OI25_1023 [6.2.1.3])        => [3.1.2.-]
    (bfn:OI25_335 [6.2.1.1],        bfn:OI25_1934 [6.2.1.3])        => [3.1.2.-]
    (bfn:OI25_335 [6.2.1.1],        bfn:OI25_3957 [6.2.1.3])        => [3.1.2.-]
    (bfn:OI25_3495 [6.2.1.1],       bfn:OI25_1023 [6.2.1.3])        => [3.1.2.-]
    (bfn:OI25_3495 [6.2.1.1],       bfn:OI25_1934 [6.2.1.3])        => [3.1.2.-]
    (bfn:OI25_3495 [6.2.1.1],       bfn:OI25_3957 [6.2.1.3])        => [3.1.2.-]
    (bfn:OI25_6882 [6.2.1.1],       bfn:OI25_1023 [6.2.1.3])        => [3.1.2.-]
    (bfn:OI25_6882 [6.2.1.1],       bfn:OI25_1934 [6.2.1.3])        => [3.1.2.-]
    (bfn:OI25_6882 [6.2.1.1],       bfn:OI25_3957 [6.2.1.3])        => [3.1.2.-]
    (bfz:BAU07_17935 [6.2.1.1],     bfz:BAU07_06095 [6.2.1.3])      => [3.1.2.-]
    (bfz:BAU07_17935 [6.2.1.1],     bfz:BAU07_12970 [6.2.1.3])      => [3.1.2.-]
    (bfz:BAU07_17935 [6.2.1.1],     bfz:BAU07_19820 [6.2.1.3])      => [3.1.2.-]
    (bfz:BAU07_17935 [6.2.1.1],     bfz:BAU07_24375 [6.2.1.3])      => [3.1.2.-]
    (bfz:BAU07_18090 [6.2.1.1],     bfz:BAU07_06095 [6.2.1.3])      => [3.1.2.-]
    (bfz:BAU07_18090 [6.2.1.1],     bfz:BAU07_12970 [6.2.1.3])      => [3.1.2.-]
    (bfz:BAU07_18090 [6.2.1.1],     bfz:BAU07_19820 [6.2.1.3])      => [3.1.2.-]
    (bgd:bgla_1g14050 [6.2.1.1],    bgd:bgla_1g04870 [6.2.1.3])     => [3.1.2.-]
    (bgd:bgla_1g14050 [6.2.1.1],    bgd:bgla_1g18310 [6.2.1.3])     => [3.1.2.-]
    (bgd:bgla_1g28680 [6.2.1.1],    bgd:bgla_1g04870 [6.2.1.3])     => [3.1.2.-]
    (bgd:bgla_1g28680 [6.2.1.1],    bgd:bgla_1g18310 [6.2.1.3])     => [3.1.2.-]
    (bgd:bgla_2g08940 [6.2.1.1],    bgd:bgla_1g04870 [6.2.1.3])     => [3.1.2.-]
    (bgd:bgla_2g08940 [6.2.1.1],    bgd:bgla_1g18310 [6.2.1.3])     => [3.1.2.-]
    (bge:BC1002_1033 [6.2.1.1],     bge:BC1002_1213 [6.2.1.3])      => [3.1.2.-]
    (bge:BC1002_1033 [6.2.1.1],     bge:BC1002_2741 [6.2.1.3])      => [3.1.2.-]
    (bge:BC1002_1985 [6.2.1.1],     bge:BC1002_1213 [6.2.1.3])      => [3.1.2.-]
    (bge:BC1002_1985 [6.2.1.1],     bge:BC1002_2741 [6.2.1.3])      => [3.1.2.-]
    (bge:BC1002_4209 [6.2.1.1],     bge:BC1002_1213 [6.2.1.3])      => [3.1.2.-]
    (bge:BC1002_4209 [6.2.1.1],     bge:BC1002_2741 [6.2.1.3])      => [3.1.2.-]
    (bgf:BC1003_2250 [6.2.1.1],     bgf:BC1003_1957 [6.2.1.3])      => [3.1.2.-]
    (bgf:BC1003_2250 [6.2.1.1],     bgf:BC1003_3068 [6.2.1.3])      => [3.1.2.-]
    (bgf:BC1003_5574 [6.2.1.1],     bgf:BC1003_1957 [6.2.1.3])      => [3.1.2.-]
    (bgf:BC1003_5574 [6.2.1.1],     bgf:BC1003_3068 [6.2.1.3])      => [3.1.2.-]
    (bgl:bglu_1g11900 [6.2.1.1],    bgl:bglu_1g04510 [6.2.1.3])     => [3.1.2.-]
    (bgl:bglu_1g11900 [6.2.1.1],    bgl:bglu_1g19680 [6.2.1.3])     => [3.1.2.-]
    (bgl:bglu_1g25360 [6.2.1.1],    bgl:bglu_1g04510 [6.2.1.3])     => [3.1.2.-]
    (bgl:bglu_1g25360 [6.2.1.1],    bgl:bglu_1g19680 [6.2.1.3])     => [3.1.2.-]
    (bgl:bglu_2g06270 [6.2.1.1],    bgl:bglu_1g04510 [6.2.1.3])     => [3.1.2.-]
    (bgl:bglu_2g06270 [6.2.1.1],    bgl:bglu_1g19680 [6.2.1.3])     => [3.1.2.-]
    (bho:D560_2346 [6.2.1.1],       bho:D560_0669 [6.2.1.3])        => [3.1.2.-]
    (bho:D560_2346 [6.2.1.1],       bho:D560_2804 [6.2.1.3])        => [3.1.2.-]
    (bho:D560_2371 [6.2.1.1],       bho:D560_0669 [6.2.1.3])        => [3.1.2.-]
    (bho:D560_2371 [6.2.1.1],       bho:D560_2804 [6.2.1.3])        => [3.1.2.-]
    (bhz:ACR54_02516 [6.2.1.1],     bhz:ACR54_01248 [6.2.1.3])      => [3.1.2.-]
    (bhz:ACR54_02516 [6.2.1.1],     bhz:ACR54_03918 [6.2.1.3])      => [3.1.2.-]
    (bhz:ACR54_03249 [6.2.1.1],     bhz:ACR54_00227 [6.2.1.3])      => [3.1.2.-]
    (bhz:ACR54_03249 [6.2.1.1],     bhz:ACR54_01248 [6.2.1.3])      => [3.1.2.-]
    (bhz:ACR54_03249 [6.2.1.1],     bhz:ACR54_03918 [6.2.1.3])      => [3.1.2.-]
    (bhz:ACR54_03273 [6.2.1.1],     bhz:ACR54_01248 [6.2.1.3])      => [3.1.2.-]
    (bhz:ACR54_03273 [6.2.1.1],     bhz:ACR54_03918 [6.2.1.3])      => [3.1.2.-]
    (blat:WK25_06590 [6.2.1.1],     blat:WK25_02625 [6.2.1.3])      => [3.1.2.-]
    (blat:WK25_06590 [6.2.1.1],     blat:WK25_07575 [6.2.1.3])      => [3.1.2.-]
    (blat:WK25_10660 [6.2.1.1],     blat:WK25_02625 [6.2.1.3])      => [3.1.2.-]
    (blat:WK25_10660 [6.2.1.1],     blat:WK25_07575 [6.2.1.3])      => [3.1.2.-]
    (blat:WK25_17835 [6.2.1.1],     blat:WK25_02625 [6.2.1.3])      => [3.1.2.-]
    (blat:WK25_17835 [6.2.1.1],     blat:WK25_07575 [6.2.1.3])      => [3.1.2.-]
    (blat:WK25_18560 [6.2.1.1],     blat:WK25_02625 [6.2.1.3])      => [3.1.2.-]
    (blat:WK25_18560 [6.2.1.1],     blat:WK25_07575 [6.2.1.3])      => [3.1.2.-]
    (blat:WK25_27095 [6.2.1.1],     blat:WK25_02625 [6.2.1.3])      => [3.1.2.-]
    (blat:WK25_27095 [6.2.1.1],     blat:WK25_07575 [6.2.1.3])      => [3.1.2.-]
    (bma:BMA0802 [6.2.1.1],         bma:BMA1134 [6.2.1.3])          => [3.1.2.-]
    (bma:BMA0802 [6.2.1.1],         bma:BMA1276 [6.2.1.3])          => [3.1.2.-]
    (bma:BMAA1794 [6.2.1.1],        bma:BMA1134 [6.2.1.3])          => [3.1.2.-]
    (bma:BMAA1794 [6.2.1.1],        bma:BMA1276 [6.2.1.3])          => [3.1.2.-]
    (bmec:WJ16_06275 [6.2.1.1],     bmec:WJ16_02355 [6.2.1.3])      => [3.1.2.-]
    (bmec:WJ16_06275 [6.2.1.1],     bmec:WJ16_07420 [6.2.1.3])      => [3.1.2.-]
    (bmec:WJ16_06275 [6.2.1.1],     bmec:WJ16_17220 [6.2.1.3])      => [3.1.2.-]
    (bmec:WJ16_11385 [6.2.1.1],     bmec:WJ16_02355 [6.2.1.3])      => [3.1.2.-]
    (bmec:WJ16_11385 [6.2.1.1],     bmec:WJ16_07420 [6.2.1.3])      => [3.1.2.-]
    (bmec:WJ16_11385 [6.2.1.1],     bmec:WJ16_17220 [6.2.1.3])      => [3.1.2.-]
    (bmec:WJ16_16590 [6.2.1.1],     bmec:WJ16_02355 [6.2.1.3])      => [3.1.2.-]
    (bmec:WJ16_16590 [6.2.1.1],     bmec:WJ16_07420 [6.2.1.3])      => [3.1.2.-]
    (bmec:WJ16_16590 [6.2.1.1],     bmec:WJ16_17220 [6.2.1.3])      => [3.1.2.-]
    (bmec:WJ16_29435 [6.2.1.1],     bmec:WJ16_02355 [6.2.1.3])      => [3.1.2.-]
    (bmec:WJ16_29435 [6.2.1.1],     bmec:WJ16_07420 [6.2.1.3])      => [3.1.2.-]
    (bmec:WJ16_29435 [6.2.1.1],     bmec:WJ16_17220 [6.2.1.3])      => [3.1.2.-]
    (bmec:WJ16_30235 [6.2.1.1],     bmec:WJ16_02355 [6.2.1.3])      => [3.1.2.-]
    (bmec:WJ16_30235 [6.2.1.1],     bmec:WJ16_07420 [6.2.1.3])      => [3.1.2.-]
    (bmec:WJ16_30235 [6.2.1.1],     bmec:WJ16_17220 [6.2.1.3])      => [3.1.2.-]
    (bmu:Bmul_1085 [6.2.1.1],       bmu:Bmul_1720 [6.2.1.3])        => [3.1.2.-]
    (bmu:Bmul_1085 [6.2.1.1],       bmu:Bmul_2848 [6.2.1.3])        => [3.1.2.-]
    (bmu:Bmul_1085 [6.2.1.1],       bmu:Bmul_5361 [6.2.1.3])        => [3.1.2.-]
    (bmu:Bmul_1992 [6.2.1.1],       bmu:Bmul_1720 [6.2.1.3])        => [3.1.2.-]
    (bmu:Bmul_1992 [6.2.1.1],       bmu:Bmul_2848 [6.2.1.3])        => [3.1.2.-]
    (bmu:Bmul_1992 [6.2.1.1],       bmu:Bmul_5361 [6.2.1.3])        => [3.1.2.-]
    (bmu:Bmul_3657 [6.2.1.1],       bmu:Bmul_1720 [6.2.1.3])        => [3.1.2.-]
    (bmu:Bmul_3657 [6.2.1.1],       bmu:Bmul_2848 [6.2.1.3])        => [3.1.2.-]
    (bmu:Bmul_3657 [6.2.1.1],       bmu:Bmul_5361 [6.2.1.3])        => [3.1.2.-]
    (bmu:Bmul_5345 [6.2.1.1],       bmu:Bmul_1720 [6.2.1.3])        => [3.1.2.-]
    (bmu:Bmul_5345 [6.2.1.1],       bmu:Bmul_2848 [6.2.1.3])        => [3.1.2.-]
    (bmu:Bmul_5345 [6.2.1.1],       bmu:Bmul_5361 [6.2.1.3])        => [3.1.2.-]
    (bmu:Bmul_5976 [6.2.1.1],       bmu:Bmul_1720 [6.2.1.3])        => [3.1.2.-]
    (bmu:Bmul_5976 [6.2.1.1],       bmu:Bmul_2848 [6.2.1.3])        => [3.1.2.-]
    (bmu:Bmul_5976 [6.2.1.1],       bmu:Bmul_5361 [6.2.1.3])        => [3.1.2.-]
    (boh:AKI39_07875 [6.2.1.1],     boh:AKI39_19520 [6.2.1.3])      => [3.1.2.-]
    (boh:AKI39_08010 [6.2.1.1],     boh:AKI39_19520 [6.2.1.3])      => [3.1.2.-]
    (boh:AKI39_08010 [6.2.1.1],     boh:AKI39_23190 [6.2.1.3])      => [3.1.2.-]
    (boh:AKI39_21535 [6.2.1.1],     boh:AKI39_19520 [6.2.1.3])      => [3.1.2.-]
    (bok:DM82_4474 [6.2.1.1],       bok:DM82_1061 [6.2.1.3])        => [3.1.2.-]
    (bok:DM82_4474 [6.2.1.1],       bok:DM82_2705 [6.2.1.3])        => [3.1.2.-]
    (bok:DM82_4713 [6.2.1.1],       bok:DM82_1061 [6.2.1.3])        => [3.1.2.-]
    (bok:DM82_4713 [6.2.1.1],       bok:DM82_2705 [6.2.1.3])        => [3.1.2.-]
    (bok:DM82_820 [6.2.1.1],        bok:DM82_1061 [6.2.1.3])        => [3.1.2.-]
    (bok:DM82_820 [6.2.1.1],        bok:DM82_2705 [6.2.1.3])        => [3.1.2.-]
    (bpa:BPP0609 [6.2.1.1],         bpa:BPP2338 [6.2.1.3])          => [3.1.2.-]
    (bpa:BPP0609 [6.2.1.1],         bpa:BPP3729 [6.2.1.3])          => [3.1.2.-]
    (bpa:BPP0944 [6.2.1.1],         bpa:BPP0915 [6.2.1.3])          => [3.1.2.-]
    (bpa:BPP0944 [6.2.1.1],         bpa:BPP2338 [6.2.1.3])          => [3.1.2.-]
    (bpa:BPP0944 [6.2.1.1],         bpa:BPP3729 [6.2.1.3])          => [3.1.2.-]
    (bpa:BPP3243 [6.2.1.1],         bpa:BPP0229 [6.2.1.3])          => [3.1.2.-]
    (bpa:BPP3243 [6.2.1.1],         bpa:BPP0915 [6.2.1.3])          => [3.1.2.-]
    (bpa:BPP3243 [6.2.1.1],         bpa:BPP2338 [6.2.1.3])          => [3.1.2.-]
    (bpa:BPP3243 [6.2.1.1],         bpa:BPP3729 [6.2.1.3])          => [3.1.2.-]
    (bpa:BPP3274 [6.2.1.1],         bpa:BPP0915 [6.2.1.3])          => [3.1.2.-]
    (bpa:BPP3274 [6.2.1.1],         bpa:BPP2338 [6.2.1.3])          => [3.1.2.-]
    (bpa:BPP3274 [6.2.1.1],         bpa:BPP3729 [6.2.1.3])          => [3.1.2.-]
    (bpdz:BBN53_06085 [6.2.1.1],    bpdz:BBN53_03455 [6.2.1.3])     => [3.1.2.-]
    (bpdz:BBN53_06085 [6.2.1.1],    bpdz:BBN53_13595 [6.2.1.3])     => [3.1.2.-]
    (bpdz:BBN53_06085 [6.2.1.1],    bpdz:BBN53_15510 [6.2.1.3])     => [3.1.2.-]
    (bpdz:BBN53_06210 [6.2.1.1],    bpdz:BBN53_03455 [6.2.1.3])     => [3.1.2.-]
    (bpdz:BBN53_06210 [6.2.1.1],    bpdz:BBN53_13595 [6.2.1.3])     => [3.1.2.-]
    (bpdz:BBN53_06210 [6.2.1.1],    bpdz:BBN53_15510 [6.2.1.3])     => [3.1.2.-]
    (bpdz:BBN53_06210 [6.2.1.1],    bpdz:BBN53_19600 [6.2.1.3])     => [3.1.2.-]
    (bpdz:BBN53_09585 [6.2.1.1],    bpdz:BBN53_03455 [6.2.1.3])     => [3.1.2.-]
    (bpdz:BBN53_09585 [6.2.1.1],    bpdz:BBN53_13595 [6.2.1.3])     => [3.1.2.-]
    (bpdz:BBN53_09585 [6.2.1.1],    bpdz:BBN53_15510 [6.2.1.3])     => [3.1.2.-]
    (bpe:BP2377 [6.2.1.1],          bpe:BP0532 [6.2.1.3])           => [3.1.2.-]
    (bpe:BP2377 [6.2.1.1],          bpe:BP2811 [6.2.1.3])           => [3.1.2.-]
    (bpe:BP2409 [6.2.1.1],          bpe:BP0532 [6.2.1.3])           => [3.1.2.-]
    (bpe:BP2409 [6.2.1.1],          bpe:BP2811 [6.2.1.3])           => [3.1.2.-]
    (bph:Bphy_1850 [6.2.1.1],       bph:Bphy_1704 [6.2.1.3])        => [3.1.2.-]
    (bph:Bphy_1850 [6.2.1.1],       bph:Bphy_2685 [6.2.1.3])        => [3.1.2.-]
    (bph:Bphy_1850 [6.2.1.1],       bph:Bphy_4871 [6.2.1.3])        => [3.1.2.-]
    (bph:Bphy_1850 [6.2.1.1],       bph:Bphy_5806 [6.2.1.3])        => [3.1.2.-]
    (bph:Bphy_1938 [6.2.1.1],       bph:Bphy_1704 [6.2.1.3])        => [3.1.2.-]
    (bph:Bphy_1938 [6.2.1.1],       bph:Bphy_2685 [6.2.1.3])        => [3.1.2.-]
    (bph:Bphy_1938 [6.2.1.1],       bph:Bphy_4871 [6.2.1.3])        => [3.1.2.-]
    (bph:Bphy_1938 [6.2.1.1],       bph:Bphy_5806 [6.2.1.3])        => [3.1.2.-]
    (bph:Bphy_4939 [6.2.1.1],       bph:Bphy_1704 [6.2.1.3])        => [3.1.2.-]
    (bph:Bphy_4939 [6.2.1.1],       bph:Bphy_2685 [6.2.1.3])        => [3.1.2.-]
    (bph:Bphy_4939 [6.2.1.1],       bph:Bphy_4871 [6.2.1.3])        => [3.1.2.-]
    (bph:Bphy_4939 [6.2.1.1],       bph:Bphy_5806 [6.2.1.3])        => [3.1.2.-]
    (bph:Bphy_5127 [6.2.1.1],       bph:Bphy_1704 [6.2.1.3])        => [3.1.2.-]
    (bph:Bphy_5127 [6.2.1.1],       bph:Bphy_2685 [6.2.1.3])        => [3.1.2.-]
    (bph:Bphy_5127 [6.2.1.1],       bph:Bphy_4871 [6.2.1.3])        => [3.1.2.-]
    (bph:Bphy_5127 [6.2.1.1],       bph:Bphy_5806 [6.2.1.3])        => [3.1.2.-]
    (bph:Bphy_7028 [6.2.1.1],       bph:Bphy_1704 [6.2.1.3])        => [3.1.2.-]
    (bph:Bphy_7028 [6.2.1.1],       bph:Bphy_2685 [6.2.1.3])        => [3.1.2.-]
    (bph:Bphy_7028 [6.2.1.1],       bph:Bphy_4871 [6.2.1.3])        => [3.1.2.-]
    (bph:Bphy_7028 [6.2.1.1],       bph:Bphy_5806 [6.2.1.3])        => [3.1.2.-]
    (bpla:bpln_1g12960 [6.2.1.1],   bpla:bpln_1g04230 [6.2.1.3])    => [3.1.2.-]
    (bpla:bpln_1g12960 [6.2.1.1],   bpla:bpln_1g16140 [6.2.1.3])    => [3.1.2.-]
    (bpla:bpln_1g26450 [6.2.1.1],   bpla:bpln_1g04230 [6.2.1.3])    => [3.1.2.-]
    (bpla:bpln_1g26450 [6.2.1.1],   bpla:bpln_1g16140 [6.2.1.3])    => [3.1.2.-]
    (bpla:bpln_2g08890 [6.2.1.1],   bpla:bpln_1g04230 [6.2.1.3])    => [3.1.2.-]
    (bpla:bpln_2g08890 [6.2.1.1],   bpla:bpln_1g16140 [6.2.1.3])    => [3.1.2.-]
    (bprc:D521_0689 [6.2.1.1],      bprc:D521_0877 [6.2.1.3])       => [3.1.2.-]
    (bps:BPSL1380 [6.2.1.1],        bps:BPSL1734 [6.2.1.3])         => [3.1.2.-]
    (bps:BPSL1380 [6.2.1.1],        bps:BPSL1883 [6.2.1.3])         => [3.1.2.-]
    (bps:BPSL1380 [6.2.1.1],        bps:BPSL3037 [6.2.1.3])         => [3.1.2.-]
    (bps:BPSS0375 [6.2.1.1],        bps:BPSL1734 [6.2.1.3])         => [3.1.2.-]
    (bps:BPSS0375 [6.2.1.1],        bps:BPSL1883 [6.2.1.3])         => [3.1.2.-]
    (bps:BPSS0375 [6.2.1.1],        bps:BPSL3037 [6.2.1.3])         => [3.1.2.-]
    (bps:BPSS0618 [6.2.1.1],        bps:BPSL1734 [6.2.1.3])         => [3.1.2.-]
    (bps:BPSS0618 [6.2.1.1],        bps:BPSL1883 [6.2.1.3])         => [3.1.2.-]
    (bps:BPSS0618 [6.2.1.1],        bps:BPSL3037 [6.2.1.3])         => [3.1.2.-]
    (bpsl:WS57_03130 [6.2.1.1],     bpsl:WS57_03575 [6.2.1.3])      => [3.1.2.-]
    (bpsl:WS57_03130 [6.2.1.1],     bpsl:WS57_14925 [6.2.1.3])      => [3.1.2.-]
    (bpsl:WS57_03130 [6.2.1.1],     bpsl:WS57_20190 [6.2.1.3])      => [3.1.2.-]
    (bpsl:WS57_03130 [6.2.1.1],     bpsl:WS57_26140 [6.2.1.3])      => [3.1.2.-]
    (bpsl:WS57_14235 [6.2.1.1],     bpsl:WS57_03575 [6.2.1.3])      => [3.1.2.-]
    (bpsl:WS57_14235 [6.2.1.1],     bpsl:WS57_14925 [6.2.1.3])      => [3.1.2.-]
    (bpsl:WS57_14235 [6.2.1.1],     bpsl:WS57_20190 [6.2.1.3])      => [3.1.2.-]
    (bpsl:WS57_14235 [6.2.1.1],     bpsl:WS57_26140 [6.2.1.3])      => [3.1.2.-]
    (bpsl:WS57_17070 [6.2.1.1],     bpsl:WS57_03575 [6.2.1.3])      => [3.1.2.-]
    (bpsl:WS57_17070 [6.2.1.1],     bpsl:WS57_14925 [6.2.1.3])      => [3.1.2.-]
    (bpsl:WS57_17070 [6.2.1.1],     bpsl:WS57_20190 [6.2.1.3])      => [3.1.2.-]
    (bpsl:WS57_17070 [6.2.1.1],     bpsl:WS57_26140 [6.2.1.3])      => [3.1.2.-]
    (bpsl:WS57_24300 [6.2.1.1],     bpsl:WS57_03575 [6.2.1.3])      => [3.1.2.-]
    (bpsl:WS57_24300 [6.2.1.1],     bpsl:WS57_14925 [6.2.1.3])      => [3.1.2.-]
    (bpsl:WS57_24300 [6.2.1.1],     bpsl:WS57_20190 [6.2.1.3])      => [3.1.2.-]
    (bpsl:WS57_24300 [6.2.1.1],     bpsl:WS57_26140 [6.2.1.3])      => [3.1.2.-]
    (bpsl:WS57_29735 [6.2.1.1],     bpsl:WS57_03575 [6.2.1.3])      => [3.1.2.-]
    (bpsl:WS57_29735 [6.2.1.1],     bpsl:WS57_14925 [6.2.1.3])      => [3.1.2.-]
    (bpsl:WS57_29735 [6.2.1.1],     bpsl:WS57_20190 [6.2.1.3])      => [3.1.2.-]
    (bpsl:WS57_29735 [6.2.1.1],     bpsl:WS57_26140 [6.2.1.3])      => [3.1.2.-]
    (bpt:Bpet1782 [6.2.1.1],        bpt:Bpet0716 [6.2.1.3])         => [3.1.2.-]
    (bpt:Bpet1782 [6.2.1.1],        bpt:Bpet3416 [6.2.1.3])         => [3.1.2.-]
    (bpt:Bpet1807 [6.2.1.1],        bpt:Bpet0716 [6.2.1.3])         => [3.1.2.-]
    (bpt:Bpet1807 [6.2.1.1],        bpt:Bpet3416 [6.2.1.3])         => [3.1.2.-]
    (bpt:Bpet1807 [6.2.1.1],        bpt:Bpet4743 [6.2.1.3])         => [3.1.2.-]
    (bpx:BUPH_00398 [6.2.1.1],      bpx:BUPH_01937 [6.2.1.3])       => [3.1.2.-]
    (bpx:BUPH_00398 [6.2.1.1],      bpx:BUPH_03649 [6.2.1.3])       => [3.1.2.-]
    (bpx:BUPH_01685 [6.2.1.1],      bpx:BUPH_01937 [6.2.1.3])       => [3.1.2.-]
    (bpx:BUPH_01685 [6.2.1.1],      bpx:BUPH_03649 [6.2.1.3])       => [3.1.2.-]
    (bpy:Bphyt_1416 [6.2.1.1],      bpy:Bphyt_1672 [6.2.1.3])       => [3.1.2.-]
    (bpy:Bphyt_1416 [6.2.1.1],      bpy:Bphyt_3482 [6.2.1.3])       => [3.1.2.-]
    (bpy:Bphyt_2727 [6.2.1.1],      bpy:Bphyt_1672 [6.2.1.3])       => [3.1.2.-]
    (bpy:Bphyt_2727 [6.2.1.1],      bpy:Bphyt_3482 [6.2.1.3])       => [3.1.2.-]
    (bpy:Bphyt_5594 [6.2.1.1],      bpy:Bphyt_1672 [6.2.1.3])       => [3.1.2.-]
    (bpy:Bphyt_5594 [6.2.1.1],      bpy:Bphyt_3482 [6.2.1.3])       => [3.1.2.-]
    (bpy:Bphyt_5649 [6.2.1.1],      bpy:Bphyt_1672 [6.2.1.3])       => [3.1.2.-]
    (bpy:Bphyt_5649 [6.2.1.1],      bpy:Bphyt_3482 [6.2.1.3])       => [3.1.2.-]
    (bpy:Bphyt_6450 [6.2.1.1],      bpy:Bphyt_1672 [6.2.1.3])       => [3.1.2.-]
    (bpy:Bphyt_6450 [6.2.1.1],      bpy:Bphyt_3482 [6.2.1.3])       => [3.1.2.-]
    (bpyr:ABD05_00965 [6.2.1.1],    bpyr:ABD05_08330 [6.2.1.3])     => [3.1.2.-]
    (bpyr:ABD05_00965 [6.2.1.1],    bpyr:ABD05_13465 [6.2.1.3])     => [3.1.2.-]
    (bpyr:ABD05_00965 [6.2.1.1],    bpyr:ABD05_31075 [6.2.1.3])     => [3.1.2.-]
    (bpyr:ABD05_12335 [6.2.1.1],    bpyr:ABD05_08330 [6.2.1.3])     => [3.1.2.-]
    (bpyr:ABD05_12335 [6.2.1.1],    bpyr:ABD05_13465 [6.2.1.3])     => [3.1.2.-]
    (bpyr:ABD05_12335 [6.2.1.1],    bpyr:ABD05_31075 [6.2.1.3])     => [3.1.2.-]
    (bpyr:ABD05_24480 [6.2.1.1],    bpyr:ABD05_08330 [6.2.1.3])     => [3.1.2.-]
    (bpyr:ABD05_24480 [6.2.1.1],    bpyr:ABD05_13465 [6.2.1.3])     => [3.1.2.-]
    (bpyr:ABD05_24480 [6.2.1.1],    bpyr:ABD05_31075 [6.2.1.3])     => [3.1.2.-]
    (bpyr:ABD05_34705 [6.2.1.1],    bpyr:ABD05_08330 [6.2.1.3])     => [3.1.2.-]
    (bpyr:ABD05_34705 [6.2.1.1],    bpyr:ABD05_13465 [6.2.1.3])     => [3.1.2.-]
    (bpyr:ABD05_34705 [6.2.1.1],    bpyr:ABD05_31075 [6.2.1.3])     => [3.1.2.-]
    (brh:RBRH_03924 [6.2.1.1],      brh:RBRH_03271 [6.2.1.3])       => [3.1.2.-]
    (bsem:WJ12_06460 [6.2.1.1],     bsem:WJ12_02375 [6.2.1.3])      => [3.1.2.-]
    (bsem:WJ12_06460 [6.2.1.1],     bsem:WJ12_07565 [6.2.1.3])      => [3.1.2.-]
    (bsem:WJ12_06460 [6.2.1.1],     bsem:WJ12_18115 [6.2.1.3])      => [3.1.2.-]
    (bsem:WJ12_11085 [6.2.1.1],     bsem:WJ12_02375 [6.2.1.3])      => [3.1.2.-]
    (bsem:WJ12_11085 [6.2.1.1],     bsem:WJ12_07565 [6.2.1.3])      => [3.1.2.-]
    (bsem:WJ12_11085 [6.2.1.1],     bsem:WJ12_18115 [6.2.1.3])      => [3.1.2.-]
    (bsem:WJ12_18680 [6.2.1.1],     bsem:WJ12_02375 [6.2.1.3])      => [3.1.2.-]
    (bsem:WJ12_18680 [6.2.1.1],     bsem:WJ12_07565 [6.2.1.3])      => [3.1.2.-]
    (bsem:WJ12_18680 [6.2.1.1],     bsem:WJ12_18115 [6.2.1.3])      => [3.1.2.-]
    (bsem:WJ12_30880 [6.2.1.1],     bsem:WJ12_02375 [6.2.1.3])      => [3.1.2.-]
    (bsem:WJ12_30880 [6.2.1.1],     bsem:WJ12_07565 [6.2.1.3])      => [3.1.2.-]
    (bsem:WJ12_30880 [6.2.1.1],     bsem:WJ12_18115 [6.2.1.3])      => [3.1.2.-]
    (bstg:WT74_06860 [6.2.1.1],     bstg:WT74_02680 [6.2.1.3])      => [3.1.2.-]
    (bstg:WT74_06860 [6.2.1.1],     bstg:WT74_07750 [6.2.1.3])      => [3.1.2.-]
    (bstg:WT74_06860 [6.2.1.1],     bstg:WT74_08015 [6.2.1.3])      => [3.1.2.-]
    (bstg:WT74_06860 [6.2.1.1],     bstg:WT74_17055 [6.2.1.3])      => [3.1.2.-]
    (bstg:WT74_11580 [6.2.1.1],     bstg:WT74_02680 [6.2.1.3])      => [3.1.2.-]
    (bstg:WT74_11580 [6.2.1.1],     bstg:WT74_07750 [6.2.1.3])      => [3.1.2.-]
    (bstg:WT74_11580 [6.2.1.1],     bstg:WT74_08015 [6.2.1.3])      => [3.1.2.-]
    (bstg:WT74_11580 [6.2.1.1],     bstg:WT74_17055 [6.2.1.3])      => [3.1.2.-]
    (bstg:WT74_16810 [6.2.1.1],     bstg:WT74_02680 [6.2.1.3])      => [3.1.2.-]
    (bstg:WT74_16810 [6.2.1.1],     bstg:WT74_07750 [6.2.1.3])      => [3.1.2.-]
    (bstg:WT74_16810 [6.2.1.1],     bstg:WT74_08015 [6.2.1.3])      => [3.1.2.-]
    (bstg:WT74_16810 [6.2.1.1],     bstg:WT74_17055 [6.2.1.3])      => [3.1.2.-]
    (bstg:WT74_29950 [6.2.1.1],     bstg:WT74_02680 [6.2.1.3])      => [3.1.2.-]
    (bstg:WT74_29950 [6.2.1.1],     bstg:WT74_07750 [6.2.1.3])      => [3.1.2.-]
    (bstg:WT74_29950 [6.2.1.1],     bstg:WT74_08015 [6.2.1.3])      => [3.1.2.-]
    (bstg:WT74_29950 [6.2.1.1],     bstg:WT74_17055 [6.2.1.3])      => [3.1.2.-]
    (bstl:BBJ41_05525 [6.2.1.1],    bstl:BBJ41_04440 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_05525 [6.2.1.1],    bstl:BBJ41_09605 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_05525 [6.2.1.1],    bstl:BBJ41_22510 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_05525 [6.2.1.1],    bstl:BBJ41_34650 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_05525 [6.2.1.1],    bstl:BBJ41_35480 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_18025 [6.2.1.1],    bstl:BBJ41_04440 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_18025 [6.2.1.1],    bstl:BBJ41_09605 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_18025 [6.2.1.1],    bstl:BBJ41_22510 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_18025 [6.2.1.1],    bstl:BBJ41_34650 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_18025 [6.2.1.1],    bstl:BBJ41_35480 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_24625 [6.2.1.1],    bstl:BBJ41_04440 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_24625 [6.2.1.1],    bstl:BBJ41_09605 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_24625 [6.2.1.1],    bstl:BBJ41_22510 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_24625 [6.2.1.1],    bstl:BBJ41_34650 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_24625 [6.2.1.1],    bstl:BBJ41_35480 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_34800 [6.2.1.1],    bstl:BBJ41_04440 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_34800 [6.2.1.1],    bstl:BBJ41_09605 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_34800 [6.2.1.1],    bstl:BBJ41_22510 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_34800 [6.2.1.1],    bstl:BBJ41_34650 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_34800 [6.2.1.1],    bstl:BBJ41_35480 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_38135 [6.2.1.1],    bstl:BBJ41_04440 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_38135 [6.2.1.1],    bstl:BBJ41_09605 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_38135 [6.2.1.1],    bstl:BBJ41_22510 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_38135 [6.2.1.1],    bstl:BBJ41_34650 [6.2.1.3])     => [3.1.2.-]
    (bstl:BBJ41_38135 [6.2.1.1],    bstl:BBJ41_35480 [6.2.1.3])     => [3.1.2.-]
    (bte:BTH_I2753 [6.2.1.1],       bte:BTH_I1106 [6.2.1.3])        => [3.1.2.-]
    (bte:BTH_I2753 [6.2.1.1],       bte:BTH_I2529 [6.2.1.3])        => [3.1.2.-]
    (bte:BTH_II0927 [6.2.1.1],      bte:BTH_I1106 [6.2.1.3])        => [3.1.2.-]
    (bte:BTH_II0927 [6.2.1.1],      bte:BTH_I2529 [6.2.1.3])        => [3.1.2.-]
    (bte:BTH_II1802 [6.2.1.1],      bte:BTH_I1106 [6.2.1.3])        => [3.1.2.-]
    (bte:BTH_II1802 [6.2.1.1],      bte:BTH_I2529 [6.2.1.3])        => [3.1.2.-]
    (bte:BTH_II2017 [6.2.1.1],      bte:BTH_I1106 [6.2.1.3])        => [3.1.2.-]
    (bte:BTH_II2017 [6.2.1.1],      bte:BTH_I2529 [6.2.1.3])        => [3.1.2.-]
    (btei:WS51_08135 [6.2.1.1],     btei:WS51_13100 [6.2.1.3])      => [3.1.2.-]
    (btei:WS51_08135 [6.2.1.1],     btei:WS51_17935 [6.2.1.3])      => [3.1.2.-]
    (btei:WS51_08135 [6.2.1.1],     btei:WS51_26430 [6.2.1.3])      => [3.1.2.-]
    (btei:WS51_16915 [6.2.1.1],     btei:WS51_13100 [6.2.1.3])      => [3.1.2.-]
    (btei:WS51_16915 [6.2.1.1],     btei:WS51_17935 [6.2.1.3])      => [3.1.2.-]
    (btei:WS51_16915 [6.2.1.1],     btei:WS51_26430 [6.2.1.3])      => [3.1.2.-]
    (btei:WS51_21320 [6.2.1.1],     btei:WS51_13100 [6.2.1.3])      => [3.1.2.-]
    (btei:WS51_21320 [6.2.1.1],     btei:WS51_17935 [6.2.1.3])      => [3.1.2.-]
    (btei:WS51_21320 [6.2.1.1],     btei:WS51_26430 [6.2.1.3])      => [3.1.2.-]
    (btei:WS51_27940 [6.2.1.1],     btei:WS51_13100 [6.2.1.3])      => [3.1.2.-]
    (btei:WS51_27940 [6.2.1.1],     btei:WS51_17935 [6.2.1.3])      => [3.1.2.-]
    (btei:WS51_27940 [6.2.1.1],     btei:WS51_26430 [6.2.1.3])      => [3.1.2.-]
    (btei:WS51_29345 [6.2.1.1],     btei:WS51_13100 [6.2.1.3])      => [3.1.2.-]
    (btei:WS51_29345 [6.2.1.1],     btei:WS51_17935 [6.2.1.3])      => [3.1.2.-]
    (btei:WS51_29345 [6.2.1.1],     btei:WS51_26430 [6.2.1.3])      => [3.1.2.-]
    (btei:WS51_29895 [6.2.1.1],     btei:WS51_13100 [6.2.1.3])      => [3.1.2.-]
    (btei:WS51_29895 [6.2.1.1],     btei:WS51_17935 [6.2.1.3])      => [3.1.2.-]
    (btei:WS51_29895 [6.2.1.1],     btei:WS51_26430 [6.2.1.3])      => [3.1.2.-]
    (btrm:SAMEA390648702598 [6.2.1.1],      btrm:SAMEA390648700527 [6.2.1.3])       => [3.1.2.-]
    (btrm:SAMEA390648702598 [6.2.1.1],      btrm:SAMEA390648704147 [6.2.1.3])       => [3.1.2.-]
    (btrm:SAMEA390648702622 [6.2.1.1],      btrm:SAMEA390648700527 [6.2.1.3])       => [3.1.2.-]
    (btrm:SAMEA390648702622 [6.2.1.1],      btrm:SAMEA390648701436 [6.2.1.3])       => [3.1.2.-]
    (btrm:SAMEA390648702622 [6.2.1.1],      btrm:SAMEA390648704147 [6.2.1.3])       => [3.1.2.-]
    (bub:BW23_2675 [6.2.1.1],       bub:BW23_1198 [6.2.1.3])        => [3.1.2.-]
    (bub:BW23_2675 [6.2.1.1],       bub:BW23_181 [6.2.1.3])         => [3.1.2.-]
    (bub:BW23_2675 [6.2.1.1],       bub:BW23_214 [6.2.1.3])         => [3.1.2.-]
    (bub:BW23_2675 [6.2.1.1],       bub:BW23_6260 [6.2.1.3])        => [3.1.2.-]
    (bub:BW23_3395 [6.2.1.1],       bub:BW23_1198 [6.2.1.3])        => [3.1.2.-]
    (bub:BW23_3395 [6.2.1.1],       bub:BW23_181 [6.2.1.3])         => [3.1.2.-]
    (bub:BW23_3395 [6.2.1.1],       bub:BW23_214 [6.2.1.3])         => [3.1.2.-]
    (bub:BW23_3395 [6.2.1.1],       bub:BW23_6260 [6.2.1.3])        => [3.1.2.-]
    (bub:BW23_403 [6.2.1.1],        bub:BW23_1198 [6.2.1.3])        => [3.1.2.-]
    (bub:BW23_403 [6.2.1.1],        bub:BW23_181 [6.2.1.3])         => [3.1.2.-]
    (bub:BW23_403 [6.2.1.1],        bub:BW23_214 [6.2.1.3])         => [3.1.2.-]
    (bub:BW23_403 [6.2.1.1],        bub:BW23_6260 [6.2.1.3])        => [3.1.2.-]
    (bub:BW23_5613 [6.2.1.1],       bub:BW23_1198 [6.2.1.3])        => [3.1.2.-]
    (bub:BW23_5613 [6.2.1.1],       bub:BW23_214 [6.2.1.3])         => [3.1.2.-]
    (bub:BW23_5613 [6.2.1.1],       bub:BW23_6260 [6.2.1.3])        => [3.1.2.-]
    (bub:BW23_6237 [6.2.1.1],       bub:BW23_1198 [6.2.1.3])        => [3.1.2.-]
    (bub:BW23_6237 [6.2.1.1],       bub:BW23_181 [6.2.1.3])         => [3.1.2.-]
    (bub:BW23_6237 [6.2.1.1],       bub:BW23_214 [6.2.1.3])         => [3.1.2.-]
    (bub:BW23_6237 [6.2.1.1],       bub:BW23_6260 [6.2.1.3])        => [3.1.2.-]
    (bud:AQ610_11680 [6.2.1.1],     bud:AQ610_02580 [6.2.1.3])      => [3.1.2.-]
    (bud:AQ610_11680 [6.2.1.1],     bud:AQ610_10595 [6.2.1.3])      => [3.1.2.-]
    (bud:AQ610_11680 [6.2.1.1],     bud:AQ610_12700 [6.2.1.3])      => [3.1.2.-]
    (bud:AQ610_21505 [6.2.1.1],     bud:AQ610_02580 [6.2.1.3])      => [3.1.2.-]
    (bud:AQ610_21505 [6.2.1.1],     bud:AQ610_10595 [6.2.1.3])      => [3.1.2.-]
    (bud:AQ610_21505 [6.2.1.1],     bud:AQ610_12700 [6.2.1.3])      => [3.1.2.-]
    (bud:AQ610_27650 [6.2.1.1],     bud:AQ610_02580 [6.2.1.3])      => [3.1.2.-]
    (bud:AQ610_27650 [6.2.1.1],     bud:AQ610_10595 [6.2.1.3])      => [3.1.2.-]
    (bud:AQ610_27650 [6.2.1.1],     bud:AQ610_12700 [6.2.1.3])      => [3.1.2.-]
    (bue:BRPE67_ACDS09430 [6.2.1.1],bue:BRPE67_ACDS16560 [6.2.1.3]) => [3.1.2.-]
    (bue:BRPE67_ACDS09430 [6.2.1.1],bue:BRPE67_ACDS23770 [6.2.1.3]) => [3.1.2.-]
    (bue:BRPE67_BCDS14320 [6.2.1.1],bue:BRPE67_ACDS16560 [6.2.1.3]) => [3.1.2.-]
    (bue:BRPE67_BCDS14320 [6.2.1.1],bue:BRPE67_ACDS23770 [6.2.1.3]) => [3.1.2.-]
    (bue:BRPE67_DCDS01770 [6.2.1.1],bue:BRPE67_ACDS16560 [6.2.1.3]) => [3.1.2.-]
    (bue:BRPE67_DCDS01770 [6.2.1.1],bue:BRPE67_ACDS23770 [6.2.1.3]) => [3.1.2.-]
    (bue:BRPE67_DCDS07580 [6.2.1.1],bue:BRPE67_ACDS16560 [6.2.1.3]) => [3.1.2.-]
    (bue:BRPE67_DCDS07580 [6.2.1.1],bue:BRPE67_ACDS23770 [6.2.1.3]) => [3.1.2.-]
    (bug:BC1001_1157 [6.2.1.1],     bug:BC1001_1422 [6.2.1.3])      => [3.1.2.-]
    (bug:BC1001_1157 [6.2.1.1],     bug:BC1001_3121 [6.2.1.3])      => [3.1.2.-]
    (bug:BC1001_3824 [6.2.1.1],     bug:BC1001_1422 [6.2.1.3])      => [3.1.2.-]
    (bug:BC1001_3824 [6.2.1.1],     bug:BC1001_3121 [6.2.1.3])      => [3.1.2.-]
    (buk:MYA_1983 [6.2.1.1],        buk:MYA_0459 [6.2.1.3])         => [3.1.2.-]
    (buk:MYA_1983 [6.2.1.1],        buk:MYA_1375 [6.2.1.3])         => [3.1.2.-]
    (buk:MYA_1983 [6.2.1.1],        buk:MYA_5190 [6.2.1.3])         => [3.1.2.-]
    (buk:MYA_2950 [6.2.1.1],        buk:MYA_0459 [6.2.1.3])         => [3.1.2.-]
    (buk:MYA_2950 [6.2.1.1],        buk:MYA_1375 [6.2.1.3])         => [3.1.2.-]
    (buk:MYA_2950 [6.2.1.1],        buk:MYA_5190 [6.2.1.3])         => [3.1.2.-]
    (buk:MYA_5107 [6.2.1.1],        buk:MYA_0459 [6.2.1.3])         => [3.1.2.-]
    (buk:MYA_5107 [6.2.1.1],        buk:MYA_1375 [6.2.1.3])         => [3.1.2.-]
    (buk:MYA_5107 [6.2.1.1],        buk:MYA_5190 [6.2.1.3])         => [3.1.2.-]
    (buk:MYA_5963 [6.2.1.1],        buk:MYA_0459 [6.2.1.3])         => [3.1.2.-]
    (buk:MYA_5963 [6.2.1.1],        buk:MYA_1375 [6.2.1.3])         => [3.1.2.-]
    (buk:MYA_5963 [6.2.1.1],        buk:MYA_5190 [6.2.1.3])         => [3.1.2.-]
    (bul:BW21_2470 [6.2.1.1],       bul:BW21_2247 [6.2.1.3])        => [3.1.2.-]
    (bul:BW21_2470 [6.2.1.1],       bul:BW21_2684 [6.2.1.3])        => [3.1.2.-]
    (bul:BW21_2470 [6.2.1.1],       bul:BW21_637 [6.2.1.3])         => [3.1.2.-]
    (bul:BW21_3880 [6.2.1.1],       bul:BW21_2247 [6.2.1.3])        => [3.1.2.-]
    (bul:BW21_3880 [6.2.1.1],       bul:BW21_2684 [6.2.1.3])        => [3.1.2.-]
    (bul:BW21_3880 [6.2.1.1],       bul:BW21_637 [6.2.1.3])         => [3.1.2.-]
    (bul:BW21_5112 [6.2.1.1],       bul:BW21_2247 [6.2.1.3])        => [3.1.2.-]
    (bul:BW21_5112 [6.2.1.1],       bul:BW21_2684 [6.2.1.3])        => [3.1.2.-]
    (bul:BW21_5112 [6.2.1.1],       bul:BW21_637 [6.2.1.3])         => [3.1.2.-]
    (buo:BRPE64_ACDS10530 [6.2.1.1],buo:BRPE64_ACDS16570 [6.2.1.3]) => [3.1.2.-]
    (buo:BRPE64_ACDS10530 [6.2.1.1],buo:BRPE64_ACDS24290 [6.2.1.3]) => [3.1.2.-]
    (buo:BRPE64_BCDS02730 [6.2.1.1],buo:BRPE64_ACDS16570 [6.2.1.3]) => [3.1.2.-]
    (buo:BRPE64_BCDS02730 [6.2.1.1],buo:BRPE64_ACDS24290 [6.2.1.3]) => [3.1.2.-]
    (buo:BRPE64_DCDS01300 [6.2.1.1],buo:BRPE64_ACDS16570 [6.2.1.3]) => [3.1.2.-]
    (buo:BRPE64_DCDS01300 [6.2.1.1],buo:BRPE64_ACDS24290 [6.2.1.3]) => [3.1.2.-]
    (buq:AC233_05760 [6.2.1.1],     buq:AC233_09270 [6.2.1.3])      => [3.1.2.-]
    (buq:AC233_05760 [6.2.1.1],     buq:AC233_15850 [6.2.1.3])      => [3.1.2.-]
    (buq:AC233_09565 [6.2.1.1],     buq:AC233_09270 [6.2.1.3])      => [3.1.2.-]
    (buq:AC233_09565 [6.2.1.1],     buq:AC233_15850 [6.2.1.3])      => [3.1.2.-]
    (buq:AC233_09565 [6.2.1.1],     buq:AC233_29570 [6.2.1.3])      => [3.1.2.-]
    (buq:AC233_21460 [6.2.1.1],     buq:AC233_09270 [6.2.1.3])      => [3.1.2.-]
    (buq:AC233_21460 [6.2.1.1],     buq:AC233_15850 [6.2.1.3])      => [3.1.2.-]
    (buq:AC233_21460 [6.2.1.1],     buq:AC233_29570 [6.2.1.3])      => [3.1.2.-]
    (buq:AC233_31115 [6.2.1.1],     buq:AC233_09270 [6.2.1.3])      => [3.1.2.-]
    (buq:AC233_31115 [6.2.1.1],     buq:AC233_15850 [6.2.1.3])      => [3.1.2.-]
    (bur:Bcep18194_A4459 [6.2.1.1], bur:Bcep18194_A3633 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_A4459 [6.2.1.1], bur:Bcep18194_A4674 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_A4459 [6.2.1.1], bur:Bcep18194_C6739 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_A4459 [6.2.1.1], bur:Bcep18194_C6801 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_A4459 [6.2.1.1], bur:Bcep18194_C6813 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_A5520 [6.2.1.1], bur:Bcep18194_A3633 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_A5520 [6.2.1.1], bur:Bcep18194_A4674 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_A5520 [6.2.1.1], bur:Bcep18194_C6739 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_A5520 [6.2.1.1], bur:Bcep18194_C6801 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_A5520 [6.2.1.1], bur:Bcep18194_C6813 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_B0715 [6.2.1.1], bur:Bcep18194_A3633 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_B0715 [6.2.1.1], bur:Bcep18194_A4674 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_B0715 [6.2.1.1], bur:Bcep18194_C6739 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_B0715 [6.2.1.1], bur:Bcep18194_C6801 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_B0715 [6.2.1.1], bur:Bcep18194_C6813 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_C6650 [6.2.1.1], bur:Bcep18194_A3633 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_C6650 [6.2.1.1], bur:Bcep18194_A4674 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_C6650 [6.2.1.1], bur:Bcep18194_C6739 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_C6650 [6.2.1.1], bur:Bcep18194_C6801 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_C6650 [6.2.1.1], bur:Bcep18194_C6813 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_C7155 [6.2.1.1], bur:Bcep18194_A3633 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_C7155 [6.2.1.1], bur:Bcep18194_A4674 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_C7155 [6.2.1.1], bur:Bcep18194_C6739 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_C7155 [6.2.1.1], bur:Bcep18194_C6801 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_C7155 [6.2.1.1], bur:Bcep18194_C6813 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_C7333 [6.2.1.1], bur:Bcep18194_A3633 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_C7333 [6.2.1.1], bur:Bcep18194_A4674 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_C7333 [6.2.1.1], bur:Bcep18194_C6739 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_C7333 [6.2.1.1], bur:Bcep18194_C6801 [6.2.1.3])  => [3.1.2.-]
    (bur:Bcep18194_C7333 [6.2.1.1], bur:Bcep18194_C6813 [6.2.1.3])  => [3.1.2.-]
    (buz:AYM40_05675 [6.2.1.1],     buz:AYM40_08245 [6.2.1.3])      => [3.1.2.-]
    (buz:AYM40_05675 [6.2.1.1],     buz:AYM40_18185 [6.2.1.3])      => [3.1.2.-]
    (buz:AYM40_05675 [6.2.1.1],     buz:AYM40_27575 [6.2.1.3])      => [3.1.2.-]
    (buz:AYM40_10310 [6.2.1.1],     buz:AYM40_08245 [6.2.1.3])      => [3.1.2.-]
    (buz:AYM40_10310 [6.2.1.1],     buz:AYM40_18185 [6.2.1.3])      => [3.1.2.-]
    (buz:AYM40_10310 [6.2.1.1],     buz:AYM40_27575 [6.2.1.3])      => [3.1.2.-]
    (buz:AYM40_27855 [6.2.1.1],     buz:AYM40_08245 [6.2.1.3])      => [3.1.2.-]
    (buz:AYM40_27855 [6.2.1.1],     buz:AYM40_18185 [6.2.1.3])      => [3.1.2.-]
    (buz:AYM40_27855 [6.2.1.1],     buz:AYM40_27575 [6.2.1.3])      => [3.1.2.-]
    (buz:AYM40_28435 [6.2.1.1],     buz:AYM40_08245 [6.2.1.3])      => [3.1.2.-]
    (buz:AYM40_28435 [6.2.1.1],     buz:AYM40_18185 [6.2.1.3])      => [3.1.2.-]
    (buz:AYM40_28435 [6.2.1.1],     buz:AYM40_27575 [6.2.1.3])      => [3.1.2.-]
    (buz:AYM40_32775 [6.2.1.1],     buz:AYM40_08245 [6.2.1.3])      => [3.1.2.-]
    (buz:AYM40_32775 [6.2.1.1],     buz:AYM40_18185 [6.2.1.3])      => [3.1.2.-]
    (buz:AYM40_32775 [6.2.1.1],     buz:AYM40_27575 [6.2.1.3])      => [3.1.2.-]
    (buz:AYM40_36710 [6.2.1.1],     buz:AYM40_08245 [6.2.1.3])      => [3.1.2.-]
    (buz:AYM40_36710 [6.2.1.1],     buz:AYM40_18185 [6.2.1.3])      => [3.1.2.-]
    (buz:AYM40_36710 [6.2.1.1],     buz:AYM40_27575 [6.2.1.3])      => [3.1.2.-]
    (bvi:Bcep1808_2277 [6.2.1.1],   bvi:Bcep1808_0523 [6.2.1.3])    => [3.1.2.-]
    (bvi:Bcep1808_2277 [6.2.1.1],   bvi:Bcep1808_1500 [6.2.1.3])    => [3.1.2.-]
    (bvi:Bcep1808_2277 [6.2.1.1],   bvi:Bcep1808_5638 [6.2.1.3])    => [3.1.2.-]
    (bvi:Bcep1808_3336 [6.2.1.1],   bvi:Bcep1808_0523 [6.2.1.3])    => [3.1.2.-]
    (bvi:Bcep1808_3336 [6.2.1.1],   bvi:Bcep1808_1500 [6.2.1.3])    => [3.1.2.-]
    (bvi:Bcep1808_3336 [6.2.1.1],   bvi:Bcep1808_5638 [6.2.1.3])    => [3.1.2.-]
    (bvi:Bcep1808_5505 [6.2.1.1],   bvi:Bcep1808_0523 [6.2.1.3])    => [3.1.2.-]
    (bvi:Bcep1808_5505 [6.2.1.1],   bvi:Bcep1808_1500 [6.2.1.3])    => [3.1.2.-]
    (bvi:Bcep1808_5505 [6.2.1.1],   bvi:Bcep1808_5638 [6.2.1.3])    => [3.1.2.-]
    (bvi:Bcep1808_6566 [6.2.1.1],   bvi:Bcep1808_0523 [6.2.1.3])    => [3.1.2.-]
    (bvi:Bcep1808_6566 [6.2.1.1],   bvi:Bcep1808_1500 [6.2.1.3])    => [3.1.2.-]
    (bvi:Bcep1808_6566 [6.2.1.1],   bvi:Bcep1808_5638 [6.2.1.3])    => [3.1.2.-]
    (bxe:Bxe_A1395 [6.2.1.1],       bxe:Bxe_A0474 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A1395 [6.2.1.1],       bxe:Bxe_A2746 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A1395 [6.2.1.1],       bxe:Bxe_A2778 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A1395 [6.2.1.1],       bxe:Bxe_B0702 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A1395 [6.2.1.1],       bxe:Bxe_B2539 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A1395 [6.2.1.1],       bxe:Bxe_C0318 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A1395 [6.2.1.1],       bxe:Bxe_C0707 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A1395 [6.2.1.1],       bxe:Bxe_C0867 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A1862 [6.2.1.1],       bxe:Bxe_A0474 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A1862 [6.2.1.1],       bxe:Bxe_A2746 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A1862 [6.2.1.1],       bxe:Bxe_A2778 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A1862 [6.2.1.1],       bxe:Bxe_B0702 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A1862 [6.2.1.1],       bxe:Bxe_C0318 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A1862 [6.2.1.1],       bxe:Bxe_C0867 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A2769 [6.2.1.1],       bxe:Bxe_A0474 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A2769 [6.2.1.1],       bxe:Bxe_A2778 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A2769 [6.2.1.1],       bxe:Bxe_C0867 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A3113 [6.2.1.1],       bxe:Bxe_A0474 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A3113 [6.2.1.1],       bxe:Bxe_A2746 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A3113 [6.2.1.1],       bxe:Bxe_A2778 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A3113 [6.2.1.1],       bxe:Bxe_B0702 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A3113 [6.2.1.1],       bxe:Bxe_B2539 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A3113 [6.2.1.1],       bxe:Bxe_C0867 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A3573 [6.2.1.1],       bxe:Bxe_A0474 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A3573 [6.2.1.1],       bxe:Bxe_A2746 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A3573 [6.2.1.1],       bxe:Bxe_A2778 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A3573 [6.2.1.1],       bxe:Bxe_B0702 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A3573 [6.2.1.1],       bxe:Bxe_B2539 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A3573 [6.2.1.1],       bxe:Bxe_C0318 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A3573 [6.2.1.1],       bxe:Bxe_C0707 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_A3573 [6.2.1.1],       bxe:Bxe_C0867 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_B1085 [6.2.1.1],       bxe:Bxe_A0474 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_B1085 [6.2.1.1],       bxe:Bxe_A2746 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_B1085 [6.2.1.1],       bxe:Bxe_A2778 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_B1085 [6.2.1.1],       bxe:Bxe_B2539 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_B1085 [6.2.1.1],       bxe:Bxe_C0318 [6.2.1.3])        => [3.1.2.-]
    (bxe:Bxe_B1085 [6.2.1.1],       bxe:Bxe_C0867 [6.2.1.3])        => [3.1.2.-]
    (byi:BYI23_A009340 [6.2.1.1],   byi:BYI23_A016100 [6.2.1.3])    => [3.1.2.-]
    (byi:BYI23_A009340 [6.2.1.1],   byi:BYI23_A023010 [6.2.1.3])    => [3.1.2.-]
    (byi:BYI23_B010190 [6.2.1.1],   byi:BYI23_A016100 [6.2.1.3])    => [3.1.2.-]
    (byi:BYI23_B010190 [6.2.1.1],   byi:BYI23_A023010 [6.2.1.3])    => [3.1.2.-]
    (byi:BYI23_D005770 [6.2.1.1],   byi:BYI23_A023010 [6.2.1.3])    => [3.1.2.-]
    (byi:BYI23_D013080 [6.2.1.1],   byi:BYI23_A016100 [6.2.1.3])    => [3.1.2.-]
    (byi:BYI23_D013080 [6.2.1.1],   byi:BYI23_A023010 [6.2.1.3])    => [3.1.2.-]
    (care:LT85_1494 [6.2.1.1],      care:LT85_4543 [6.2.1.3])       => [3.1.2.-]
    (care:LT85_1494 [6.2.1.1],      care:LT85_4544 [6.2.1.3])       => [3.1.2.-]
    (care:LT85_3863 [6.2.1.1],      care:LT85_4543 [6.2.1.3])       => [3.1.2.-]
    (care:LT85_3863 [6.2.1.1],      care:LT85_4544 [6.2.1.3])       => [3.1.2.-]
    (cbaa:SRAA_1154 [6.2.1.1],      cbaa:SRAA_1887 [6.2.1.3])       => [3.1.2.-]
    (cbaa:SRAA_1154 [6.2.1.1],      cbaa:SRAA_2285 [6.2.1.3])       => [3.1.2.-]
    (cbaa:SRAA_1169 [6.2.1.1],      cbaa:SRAA_1887 [6.2.1.3])       => [3.1.2.-]
    (cbaa:SRAA_1169 [6.2.1.1],      cbaa:SRAA_2285 [6.2.1.3])       => [3.1.2.-]
    (cbab:SMCB_1048 [6.2.1.1],      cbab:SMCB_0206 [6.2.1.3])       => [3.1.2.-]
    (cbab:SMCB_1048 [6.2.1.1],      cbab:SMCB_2068 [6.2.1.3])       => [3.1.2.-]
    (cbab:SMCB_1048 [6.2.1.1],      cbab:SMCB_2310 [6.2.1.3])       => [3.1.2.-]
    (cbab:SMCB_1063 [6.2.1.1],      cbab:SMCB_0206 [6.2.1.3])       => [3.1.2.-]
    (cbab:SMCB_1063 [6.2.1.1],      cbab:SMCB_2310 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_m1282 [6.2.1.1],      cbw:RR42_m1900 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_m1282 [6.2.1.1],      cbw:RR42_m3695 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_m1282 [6.2.1.1],      cbw:RR42_m3772 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_m1282 [6.2.1.1],      cbw:RR42_s0903 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_m1282 [6.2.1.1],      cbw:RR42_s1721 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_m1282 [6.2.1.1],      cbw:RR42_s1812 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_m2146 [6.2.1.1],      cbw:RR42_m1900 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_m2146 [6.2.1.1],      cbw:RR42_m3695 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_m2146 [6.2.1.1],      cbw:RR42_m3772 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_m2146 [6.2.1.1],      cbw:RR42_s0903 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_m2146 [6.2.1.1],      cbw:RR42_s1721 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_m2146 [6.2.1.1],      cbw:RR42_s1812 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_m2818 [6.2.1.1],      cbw:RR42_m1900 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_m2818 [6.2.1.1],      cbw:RR42_m3695 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_m2818 [6.2.1.1],      cbw:RR42_m3772 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_m2818 [6.2.1.1],      cbw:RR42_s0903 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_m2818 [6.2.1.1],      cbw:RR42_s1721 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_s0395 [6.2.1.1],      cbw:RR42_m1900 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_s0395 [6.2.1.1],      cbw:RR42_m3695 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_s0395 [6.2.1.1],      cbw:RR42_m3772 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_s0395 [6.2.1.1],      cbw:RR42_s0903 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_s0395 [6.2.1.1],      cbw:RR42_s1721 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_s0838 [6.2.1.1],      cbw:RR42_m1900 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_s0838 [6.2.1.1],      cbw:RR42_m3695 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_s0838 [6.2.1.1],      cbw:RR42_m3772 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_s0838 [6.2.1.1],      cbw:RR42_s0903 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_s0838 [6.2.1.1],      cbw:RR42_s1721 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_s3042 [1.1.1.35],     cbw:RR42_m1900 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_s3042 [1.1.1.35],     cbw:RR42_m3695 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_s3042 [1.1.1.35],     cbw:RR42_m3772 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_s3042 [1.1.1.35],     cbw:RR42_s0903 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_s3042 [1.1.1.35],     cbw:RR42_s1721 [6.2.1.3])       => [3.1.2.-]
    (cbw:RR42_s3042 [1.1.1.35],     cbw:RR42_s1812 [6.2.1.3])       => [3.1.2.-]
    (ccup:BKK81_08790 [6.2.1.1],    ccup:BKK81_17645 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_08790 [6.2.1.1],    ccup:BKK81_18280 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_08790 [6.2.1.1],    ccup:BKK81_30420 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_08790 [6.2.1.1],    ccup:BKK81_30470 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_08790 [6.2.1.1],    ccup:BKK81_30825 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_08790 [6.2.1.1],    ccup:BKK81_33775 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_14455 [6.2.1.1],    ccup:BKK81_17645 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_14455 [6.2.1.1],    ccup:BKK81_18280 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_14455 [6.2.1.1],    ccup:BKK81_30420 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_14455 [6.2.1.1],    ccup:BKK81_30470 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_14455 [6.2.1.1],    ccup:BKK81_30825 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_19195 [6.2.1.1],    ccup:BKK81_17645 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_19195 [6.2.1.1],    ccup:BKK81_18280 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_19195 [6.2.1.1],    ccup:BKK81_30420 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_19195 [6.2.1.1],    ccup:BKK81_30470 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_19195 [6.2.1.1],    ccup:BKK81_30825 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_19195 [6.2.1.1],    ccup:BKK81_33775 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_31020 [6.2.1.1],    ccup:BKK81_17645 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_31020 [6.2.1.1],    ccup:BKK81_18280 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_31020 [6.2.1.1],    ccup:BKK81_30420 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_31020 [6.2.1.1],    ccup:BKK81_30470 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_31020 [6.2.1.1],    ccup:BKK81_30825 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_31020 [6.2.1.1],    ccup:BKK81_33775 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_33765 [6.2.1.1],    ccup:BKK81_08345 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_33765 [6.2.1.1],    ccup:BKK81_17645 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_33765 [6.2.1.1],    ccup:BKK81_18280 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_33765 [6.2.1.1],    ccup:BKK81_30420 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_33765 [6.2.1.1],    ccup:BKK81_30470 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_33765 [6.2.1.1],    ccup:BKK81_30825 [6.2.1.3])     => [3.1.2.-]
    (ccup:BKK81_33765 [6.2.1.1],    ccup:BKK81_33775 [6.2.1.3])     => [3.1.2.-]
    (cdn:BN940_04501 [6.2.1.1],     cdn:BN940_00571 [6.2.1.3])      => [3.1.2.-]
    (cdn:BN940_04501 [6.2.1.1],     cdn:BN940_03141 [6.2.1.3])      => [3.1.2.-]
    (cdn:BN940_04501 [6.2.1.1],     cdn:BN940_05616 [6.2.1.3])      => [3.1.2.-]
    (cdn:BN940_05571 [6.2.1.1],     cdn:BN940_00571 [6.2.1.3])      => [3.1.2.-]
    (cfu:CFU_3071 [6.2.1.1],        cfu:CFU_3992 [6.2.1.3])         => [3.1.2.-]
    (cfu:CFU_3350 [6.2.1.1],        cfu:CFU_3992 [6.2.1.3])         => [3.1.2.-]
    (cfu:CFU_3350 [6.2.1.1],        cfu:CFU_3993 [6.2.1.3])         => [3.1.2.-]
    (cgd:CR3_1824 [6.2.1.1],        cgd:CR3_0016 [6.2.1.3])         => [3.1.2.-]
    (cgd:CR3_1824 [6.2.1.1],        cgd:CR3_2422 [6.2.1.3])         => [3.1.2.-]
    (cgd:CR3_1824 [6.2.1.1],        cgd:CR3_2491 [6.2.1.3])         => [3.1.2.-]
    (chro:CXB49_05110 [6.2.1.1],    chro:CXB49_20175 [6.2.1.3])     => [3.1.2.-]
    (cke:B5M06_16310 [6.2.1.1],     cke:B5M06_05915 [6.2.1.3])      => [3.1.2.-]
    (cpra:CPter91_1450 [6.2.1.1],   cpra:CPter91_4969 [6.2.1.3])    => [3.1.2.-]
    (cpra:CPter91_1450 [6.2.1.1],   cpra:CPter91_4970 [6.2.1.3])    => [3.1.2.-]
    (cpra:CPter91_4119 [6.2.1.1],   cpra:CPter91_4969 [6.2.1.3])    => [3.1.2.-]
    (cpra:CPter91_4119 [6.2.1.1],   cpra:CPter91_4970 [6.2.1.3])    => [3.1.2.-]
    (cser:CCO03_12400 [6.2.1.1],    cser:CCO03_06145 [6.2.1.3])     => [3.1.2.-]
    (cser:CCO03_15840 [6.2.1.1],    cser:CCO03_06145 [6.2.1.3])     => [3.1.2.-]
    (cti:RALTA_A1174 [6.2.1.1],     cti:RALTA_A0225 [6.2.1.3])      => [3.1.2.-]
    (cti:RALTA_A1174 [6.2.1.1],     cti:RALTA_A2744 [6.2.1.3])      => [3.1.2.-]
    (cti:RALTA_A1174 [6.2.1.1],     cti:RALTA_A2808 [6.2.1.3])      => [3.1.2.-]
    (cti:RALTA_A1174 [6.2.1.1],     cti:RALTA_A2852 [6.2.1.3])      => [3.1.2.-]
    (cti:RALTA_A1174 [6.2.1.1],     cti:RALTA_B1144 [6.2.1.3])      => [3.1.2.-]
    (cti:RALTA_A2028 [6.2.1.1],     cti:RALTA_A2744 [6.2.1.3])      => [3.1.2.-]
    (cti:RALTA_A2028 [6.2.1.1],     cti:RALTA_A2808 [6.2.1.3])      => [3.1.2.-]
    (cti:RALTA_A2028 [6.2.1.1],     cti:RALTA_A2852 [6.2.1.3])      => [3.1.2.-]
    (cti:RALTA_A2028 [6.2.1.1],     cti:RALTA_B1144 [6.2.1.3])      => [3.1.2.-]
    (cti:RALTA_B0925 [6.2.1.1],     cti:RALTA_A2744 [6.2.1.3])      => [3.1.2.-]
    (cti:RALTA_B0925 [6.2.1.1],     cti:RALTA_A2808 [6.2.1.3])      => [3.1.2.-]
    (cti:RALTA_B0925 [6.2.1.1],     cti:RALTA_A2852 [6.2.1.3])      => [3.1.2.-]
    (cti:RALTA_B0925 [6.2.1.1],     cti:RALTA_B1144 [6.2.1.3])      => [3.1.2.-]
    (ctt:CtCNB1_1397 [6.2.1.1],     ctt:CtCNB1_4404 [6.2.1.3])      => [3.1.2.-]
    (ctt:CtCNB1_1397 [6.2.1.1],     ctt:CtCNB1_4619 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_06290 [6.2.1.1],     cuh:BJN34_15765 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_06290 [6.2.1.1],     cuh:BJN34_17615 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_06290 [6.2.1.1],     cuh:BJN34_17950 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_06290 [6.2.1.1],     cuh:BJN34_25525 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_06290 [6.2.1.1],     cuh:BJN34_26490 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_06290 [6.2.1.1],     cuh:BJN34_27820 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_09830 [6.2.1.1],     cuh:BJN34_15765 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_09830 [6.2.1.1],     cuh:BJN34_17615 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_09830 [6.2.1.1],     cuh:BJN34_26490 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_09830 [6.2.1.1],     cuh:BJN34_27820 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_13560 [6.2.1.1],     cuh:BJN34_15765 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_13560 [6.2.1.1],     cuh:BJN34_17615 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_13560 [6.2.1.1],     cuh:BJN34_17950 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_13560 [6.2.1.1],     cuh:BJN34_25525 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_13560 [6.2.1.1],     cuh:BJN34_26490 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_13560 [6.2.1.1],     cuh:BJN34_27820 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_22305 [6.2.1.1],     cuh:BJN34_15765 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_22305 [6.2.1.1],     cuh:BJN34_17615 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_22305 [6.2.1.1],     cuh:BJN34_17950 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_22305 [6.2.1.1],     cuh:BJN34_25525 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_22305 [6.2.1.1],     cuh:BJN34_26490 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_22305 [6.2.1.1],     cuh:BJN34_27820 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_27195 [6.2.1.1],     cuh:BJN34_15765 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_27195 [6.2.1.1],     cuh:BJN34_17615 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_27195 [6.2.1.1],     cuh:BJN34_17950 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_27195 [6.2.1.1],     cuh:BJN34_25525 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_27195 [6.2.1.1],     cuh:BJN34_26490 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_27195 [6.2.1.1],     cuh:BJN34_27820 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_31265 [6.2.1.1],     cuh:BJN34_17615 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_31265 [6.2.1.1],     cuh:BJN34_17950 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_31265 [6.2.1.1],     cuh:BJN34_25525 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_31265 [6.2.1.1],     cuh:BJN34_26490 [6.2.1.3])      => [3.1.2.-]
    (cuh:BJN34_31265 [6.2.1.1],     cuh:BJN34_27820 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_08100 [6.2.1.1],     cup:BKK80_18655 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_08100 [6.2.1.1],     cup:BKK80_19135 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_08100 [6.2.1.1],     cup:BKK80_23215 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_08100 [6.2.1.1],     cup:BKK80_25530 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_08100 [6.2.1.1],     cup:BKK80_25885 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_08100 [6.2.1.1],     cup:BKK80_25935 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_15405 [6.2.1.1],     cup:BKK80_18655 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_15405 [6.2.1.1],     cup:BKK80_19135 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_15405 [6.2.1.1],     cup:BKK80_23215 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_15405 [6.2.1.1],     cup:BKK80_25530 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_15405 [6.2.1.1],     cup:BKK80_25885 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_15405 [6.2.1.1],     cup:BKK80_25935 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_22745 [6.2.1.1],     cup:BKK80_18655 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_22745 [6.2.1.1],     cup:BKK80_19135 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_22745 [6.2.1.1],     cup:BKK80_23215 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_22745 [6.2.1.1],     cup:BKK80_25530 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_22745 [6.2.1.1],     cup:BKK80_25885 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_22745 [6.2.1.1],     cup:BKK80_25935 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_25330 [6.2.1.1],     cup:BKK80_18655 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_25330 [6.2.1.1],     cup:BKK80_19135 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_25330 [6.2.1.1],     cup:BKK80_23215 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_25330 [6.2.1.1],     cup:BKK80_25530 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_25330 [6.2.1.1],     cup:BKK80_25885 [6.2.1.3])      => [3.1.2.-]
    (cup:BKK80_25330 [6.2.1.1],     cup:BKK80_25935 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_04040 [6.2.1.1],     cuu:BKK79_12910 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_04040 [6.2.1.1],     cuu:BKK79_13395 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_04040 [6.2.1.1],     cuu:BKK79_28520 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_04040 [6.2.1.1],     cuu:BKK79_31405 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_04040 [6.2.1.1],     cuu:BKK79_31760 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_04040 [6.2.1.1],     cuu:BKK79_31810 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_17545 [6.2.1.1],     cuu:BKK79_12910 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_17545 [6.2.1.1],     cuu:BKK79_13395 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_17545 [6.2.1.1],     cuu:BKK79_28520 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_17545 [6.2.1.1],     cuu:BKK79_31405 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_17545 [6.2.1.1],     cuu:BKK79_31760 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_17545 [6.2.1.1],     cuu:BKK79_31810 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_28020 [6.2.1.1],     cuu:BKK79_12910 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_28020 [6.2.1.1],     cuu:BKK79_13395 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_28020 [6.2.1.1],     cuu:BKK79_28520 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_28020 [6.2.1.1],     cuu:BKK79_31405 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_28020 [6.2.1.1],     cuu:BKK79_31760 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_28020 [6.2.1.1],     cuu:BKK79_31810 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_31040 [6.2.1.1],     cuu:BKK79_12910 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_31040 [6.2.1.1],     cuu:BKK79_13395 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_31040 [6.2.1.1],     cuu:BKK79_28520 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_31040 [6.2.1.1],     cuu:BKK79_31405 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_31040 [6.2.1.1],     cuu:BKK79_31760 [6.2.1.3])      => [3.1.2.-]
    (cuu:BKK79_31040 [6.2.1.1],     cuu:BKK79_31810 [6.2.1.3])      => [3.1.2.-]
    (cvc:BKX93_07155 [6.2.1.1],     cvc:BKX93_14975 [6.2.1.3])      => [3.1.2.-]
    (cvc:BKX93_07155 [6.2.1.1],     cvc:BKX93_20305 [6.2.1.3])      => [3.1.2.-]
    (cvi:CV_3282 [6.2.1.1],         cvi:CV_0093 [6.2.1.3])          => [3.1.2.-]
    (cvi:CV_3282 [6.2.1.1],         cvi:CV_1459 [6.2.1.3])          => [3.1.2.-]
    (dac:Daci_1761 [6.2.1.1],       dac:Daci_0928 [6.2.1.3])        => [3.1.2.-]
    (dac:Daci_1761 [6.2.1.1],       dac:Daci_0946 [6.2.1.3])        => [3.1.2.-]
    (dac:Daci_1761 [6.2.1.1],       dac:Daci_1072 [6.2.1.3])        => [3.1.2.-]
    (dac:Daci_1761 [6.2.1.1],       dac:Daci_3166 [6.2.1.3])        => [3.1.2.-]
    (dac:Daci_2747 [6.2.1.1],       dac:Daci_0928 [6.2.1.3])        => [3.1.2.-]
    (dac:Daci_2747 [6.2.1.1],       dac:Daci_0946 [6.2.1.3])        => [3.1.2.-]
    (dac:Daci_2747 [6.2.1.1],       dac:Daci_1072 [6.2.1.3])        => [3.1.2.-]
    (dac:Daci_2747 [6.2.1.1],       dac:Daci_3166 [6.2.1.3])        => [3.1.2.-]
    (dar:Daro_1629 [6.2.1.1],       dar:Daro_1553 [6.2.1.3])        => [3.1.2.-]
    (dar:Daro_2708 [6.2.1.1],       dar:Daro_1553 [6.2.1.3])        => [3.1.2.-]
    (del:DelCs14_4005 [6.2.1.1],    del:DelCs14_3549 [6.2.1.3])     => [3.1.2.-]
    (del:DelCs14_4005 [6.2.1.1],    del:DelCs14_5449 [6.2.1.3])     => [3.1.2.-]
    (del:DelCs14_4005 [6.2.1.1],    del:DelCs14_5581 [6.2.1.3])     => [3.1.2.-]
    (del:DelCs14_4005 [6.2.1.1],    del:DelCs14_5598 [6.2.1.3])     => [3.1.2.-]
    (del:DelCs14_4879 [6.2.1.1],    del:DelCs14_3549 [6.2.1.3])     => [3.1.2.-]
    (del:DelCs14_4879 [6.2.1.1],    del:DelCs14_5449 [6.2.1.3])     => [3.1.2.-]
    (del:DelCs14_4879 [6.2.1.1],    del:DelCs14_5581 [6.2.1.3])     => [3.1.2.-]
    (del:DelCs14_4879 [6.2.1.1],    del:DelCs14_5598 [6.2.1.3])     => [3.1.2.-]
    (dhk:BO996_08310 [6.2.1.1],     dhk:BO996_04700 [6.2.1.3])      => [3.1.2.-]
    (dhk:BO996_08310 [6.2.1.1],     dhk:BO996_04790 [6.2.1.3])      => [3.1.2.-]
    (dhk:BO996_08310 [6.2.1.1],     dhk:BO996_05445 [6.2.1.3])      => [3.1.2.-]
    (dhk:BO996_08310 [6.2.1.1],     dhk:BO996_14635 [6.2.1.3])      => [3.1.2.-]
    (dhk:BO996_12685 [6.2.1.1],     dhk:BO996_04700 [6.2.1.3])      => [3.1.2.-]
    (dhk:BO996_12685 [6.2.1.1],     dhk:BO996_04790 [6.2.1.3])      => [3.1.2.-]
    (dhk:BO996_12685 [6.2.1.1],     dhk:BO996_05445 [6.2.1.3])      => [3.1.2.-]
    (dhk:BO996_12685 [6.2.1.1],     dhk:BO996_14635 [6.2.1.3])      => [3.1.2.-]
    (dia:Dtpsy_0983 [6.2.1.1],      dia:Dtpsy_3299 [6.2.1.3])       => [3.1.2.-]
    (dpy:BA022_09880 [6.2.1.1],     dpy:BA022_16095 [6.2.1.3])      => [3.1.2.-]
    (dsu:Dsui_2003 [6.2.1.1],       dsu:Dsui_3212 [6.2.1.3])        => [3.1.2.-]
    (dsu:Dsui_2187 [6.2.1.1],       dsu:Dsui_3212 [6.2.1.3])        => [3.1.2.-]
    (dts:BI380_09925 [6.2.1.1],     dts:BI380_01785 [6.2.1.3])      => [3.1.2.-]
    (dts:BI380_09925 [6.2.1.1],     dts:BI380_19335 [6.2.1.3])      => [3.1.2.-]
    (dts:BI380_09925 [6.2.1.1],     dts:BI380_19980 [6.2.1.3])      => [3.1.2.-]
    (eba:ebA1206 [6.2.1.1],         eba:ebA4749 [6.2.1.3])          => [3.1.2.-]
    (eba:ebA172 [6.2.1.1],          eba:ebA4749 [6.2.1.3])          => [3.1.2.-]
    (eba:ebA4717 [6.2.1.1],         eba:ebA4749 [6.2.1.3])          => [3.1.2.-]
    (har:HEAR0921 [6.2.1.1],        har:HEAR0221 [6.2.1.3])         => [3.1.2.-]
    (hee:hmeg3_05060 [6.2.1.1],     hee:hmeg3_04630 [6.2.1.3])      => [3.1.2.-]
    (hee:hmeg3_15885 [6.2.1.1],     hee:hmeg3_04630 [6.2.1.3])      => [3.1.2.-]
    (hht:F506_05995 [6.2.1.1],      hht:F506_02120 [6.2.1.3])       => [3.1.2.-]
    (hht:F506_09885 [6.2.1.1],      hht:F506_02120 [6.2.1.3])       => [3.1.2.-]
    (hrb:Hrubri_0038 [6.2.1.1],     hrb:Hrubri_3826 [6.2.1.3])      => [3.1.2.-]
    (hrb:Hrubri_1391 [6.2.1.1],     hrb:Hrubri_3826 [6.2.1.3])      => [3.1.2.-]
    (hrb:Hrubri_2885 [6.2.1.1],     hrb:Hrubri_3826 [6.2.1.3])      => [3.1.2.-]
    (hse:Hsero_0019 [6.2.1.1],      hse:Hsero_3863 [6.2.1.3])       => [3.1.2.-]
    (hse:Hsero_0924 [6.2.1.1],      hse:Hsero_3863 [6.2.1.3])       => [3.1.2.-]
    (hse:Hsero_1545 [6.2.1.1],      hse:Hsero_3863 [6.2.1.3])       => [3.1.2.-]
    (hyb:Q5W_03760 [6.2.1.1],       hyb:Q5W_11410 [6.2.1.3])        => [3.1.2.-]
    (hyb:Q5W_03760 [6.2.1.1],       hyb:Q5W_24170 [6.2.1.3])        => [3.1.2.-]
    (hyb:Q5W_10430 [6.2.1.1],       hyb:Q5W_24170 [6.2.1.3])        => [3.1.2.-]
    (hyb:Q5W_13100 [6.2.1.1],       hyb:Q5W_24170 [6.2.1.3])        => [3.1.2.-]
    (hyl:LPB072_05340 [6.2.1.1],    hyl:LPB072_02370 [6.2.1.3])     => [3.1.2.-]
    (hyl:LPB072_13390 [6.2.1.1],    hyl:LPB072_02370 [6.2.1.3])     => [3.1.2.-]
    (hyr:BSY239_1420 [6.2.1.1],     hyr:BSY239_3863 [6.2.1.3])      => [3.1.2.-]
    (hyr:BSY239_208 [6.2.1.1],      hyr:BSY239_242 [6.2.1.3])       => [3.1.2.-]
    (hyr:BSY239_208 [6.2.1.1],      hyr:BSY239_3863 [6.2.1.3])      => [3.1.2.-]
    (hyr:BSY239_2575 [6.2.1.1],     hyr:BSY239_3863 [6.2.1.3])      => [3.1.2.-]
    (hyr:BSY239_2806 [6.2.1.1],     hyr:BSY239_3863 [6.2.1.3])      => [3.1.2.-]
    (hyr:BSY239_862 [6.2.1.1],      hyr:BSY239_3863 [6.2.1.3])      => [3.1.2.-]
    (jab:VN23_20665 [6.2.1.1],      jab:VN23_04400 [6.2.1.3])       => [3.1.2.-]
    (jag:GJA_4262 [6.2.1.1],        jag:GJA_267 [6.2.1.3])          => [3.1.2.-]
    (jag:GJA_4262 [6.2.1.1],        jag:GJA_268 [6.2.1.3])          => [3.1.2.-]
    (jag:GJA_4262 [6.2.1.1],        jag:GJA_4080 [6.2.1.3])         => [3.1.2.-]
    (jal:BZG29_06755 [6.2.1.1],     jal:BZG29_06345 [6.2.1.3])      => [3.1.2.-]
    (jal:BZG29_06755 [6.2.1.1],     jal:BZG29_27375 [6.2.1.3])      => [3.1.2.-]
    (jal:BZG29_06755 [6.2.1.1],     jal:BZG29_27380 [6.2.1.3])      => [3.1.2.-]
    (jaz:YQ44_21335 [6.2.1.1],      jaz:YQ44_00265 [6.2.1.3])       => [3.1.2.-]
    (jaz:YQ44_21335 [6.2.1.1],      jaz:YQ44_00270 [6.2.1.3])       => [3.1.2.-]
    (jeu:BJP62_15215 [6.2.1.1],     jeu:BJP62_03110 [6.2.1.3])      => [3.1.2.-]
    (jsv:CNX70_06965 [6.2.1.1],     jsv:CNX70_27655 [6.2.1.3])      => [3.1.2.-]
    (jsv:CNX70_06965 [6.2.1.1],     jsv:CNX70_27660 [6.2.1.3])      => [3.1.2.-]
    (lch:Lcho_3063 [6.2.1.1],       lch:Lcho_0424 [6.2.1.3])        => [3.1.2.-]
    (lhk:LHK_01225 [6.2.1.1],       lhk:LHK_01931 [6.2.1.3])        => [3.1.2.-]
    (lih:L63ED372_01051 [6.2.1.1],  lih:L63ED372_00452 [6.2.1.3])   => [3.1.2.-]
    (lih:L63ED372_01051 [6.2.1.1],  lih:L63ED372_02281 [6.2.1.3])   => [3.1.2.-]
    (lih:L63ED372_01330 [6.2.1.1],  lih:L63ED372_00452 [6.2.1.3])   => [3.1.2.-]
    (lih:L63ED372_01330 [6.2.1.1],  lih:L63ED372_02281 [6.2.1.3])   => [3.1.2.-]
    (lih:L63ED372_01862 [6.2.1.1],  lih:L63ED372_00452 [6.2.1.3])   => [3.1.2.-]
    (lih:L63ED372_01862 [6.2.1.1],  lih:L63ED372_02281 [6.2.1.3])   => [3.1.2.-]
    (lim:L103DPR2_02152 [6.2.1.1],  lim:L103DPR2_00134 [6.2.1.3])   => [3.1.2.-]
    (lim:L103DPR2_02348 [6.2.1.1],  lim:L103DPR2_00134 [6.2.1.3])   => [3.1.2.-]
    (masw:AM586_07040 [6.2.1.1],    masw:AM586_14865 [6.2.1.3])     => [3.1.2.-]
    (masw:AM586_07040 [6.2.1.1],    masw:AM586_26465 [6.2.1.3])     => [3.1.2.-]
    (masw:AM586_07040 [6.2.1.1],    masw:AM586_26470 [6.2.1.3])     => [3.1.2.-]
    (masw:AM586_18300 [6.2.1.1],    masw:AM586_14865 [6.2.1.3])     => [3.1.2.-]
    (masw:AM586_18300 [6.2.1.1],    masw:AM586_26465 [6.2.1.3])     => [3.1.2.-]
    (masw:AM586_18300 [6.2.1.1],    masw:AM586_26470 [6.2.1.3])     => [3.1.2.-]
    (masw:AM586_20075 [6.2.1.1],    masw:AM586_14865 [6.2.1.3])     => [3.1.2.-]
    (masw:AM586_20075 [6.2.1.1],    masw:AM586_26465 [6.2.1.3])     => [3.1.2.-]
    (masw:AM586_20075 [6.2.1.1],    masw:AM586_26470 [6.2.1.3])     => [3.1.2.-]
    (metr:BSY238_112 [6.2.1.1],     metr:BSY238_2622 [6.2.1.3])     => [3.1.2.-]
    (miu:ABE85_02665 [6.2.1.1],     miu:ABE85_24065 [6.2.1.3])      => [3.1.2.-]
    (miu:ABE85_26380 [6.2.1.1],     miu:ABE85_24065 [6.2.1.3])      => [3.1.2.-]
    (mms:mma_0882 [6.2.1.1],        mms:mma_0275 [6.2.1.3])         => [3.1.2.-]
    (mnr:ACZ75_12925 [6.2.1.1],     mnr:ACZ75_20990 [6.2.1.3])      => [3.1.2.-]
    (mnr:ACZ75_12925 [6.2.1.1],     mnr:ACZ75_20995 [6.2.1.3])      => [3.1.2.-]
    (mpt:Mpe_A0343 [6.2.1.1],       mpt:Mpe_A0353 [6.2.1.3])        => [3.1.2.-]
    (mpt:Mpe_A0343 [6.2.1.1],       mpt:Mpe_A2687 [6.2.1.3])        => [3.1.2.-]
    (mpt:Mpe_A0343 [6.2.1.1],       mpt:Mpe_A3572 [6.2.1.3])        => [3.1.2.-]
    (mpt:Mpe_A1385 [6.2.1.1],       mpt:Mpe_A0353 [6.2.1.3])        => [3.1.2.-]
    (mpt:Mpe_A1385 [6.2.1.1],       mpt:Mpe_A2687 [6.2.1.3])        => [3.1.2.-]
    (mpt:Mpe_A1385 [6.2.1.1],       mpt:Mpe_A3572 [6.2.1.3])        => [3.1.2.-]
    (nlc:EBAPG3_014425 [6.2.1.1],   nlc:EBAPG3_002355 [6.2.1.3])    => [3.1.2.-]
    (odi:ODI_R1455 [6.2.1.1],       odi:ODI_R0965 [6.2.1.3])        => [3.1.2.-]
    (odi:ODI_R1475 [6.2.1.1],       odi:ODI_R0420 [6.2.1.3])        => [3.1.2.-]
    (odi:ODI_R1475 [6.2.1.1],       odi:ODI_R0965 [6.2.1.3])        => [3.1.2.-]
    (papi:SG18_13465 [6.2.1.1],     papi:SG18_01660 [6.2.1.3])      => [3.1.2.-]
    (papi:SG18_13465 [6.2.1.1],     papi:SG18_21670 [6.2.1.3])      => [3.1.2.-]
    (papi:SG18_15225 [6.2.1.1],     papi:SG18_01660 [6.2.1.3])      => [3.1.2.-]
    (papi:SG18_15225 [6.2.1.1],     papi:SG18_21670 [6.2.1.3])      => [3.1.2.-]
    (papi:SG18_22545 [6.2.1.1],     papi:SG18_01660 [6.2.1.3])      => [3.1.2.-]
    (papi:SG18_22545 [6.2.1.1],     papi:SG18_21670 [6.2.1.3])      => [3.1.2.-]
    (papi:SG18_23210 [6.2.1.1],     papi:SG18_01660 [6.2.1.3])      => [3.1.2.-]
    (papi:SG18_23210 [6.2.1.1],     papi:SG18_21670 [6.2.1.3])      => [3.1.2.-]
    (papi:SG18_23210 [6.2.1.1],     papi:SG18_23430 [6.2.1.3])      => [3.1.2.-]
    (para:BTO02_14005 [6.2.1.1],    para:BTO02_13220 [6.2.1.3])     => [3.1.2.-]
    (para:BTO02_14005 [6.2.1.1],    para:BTO02_18380 [6.2.1.3])     => [3.1.2.-]
    (para:BTO02_14005 [6.2.1.1],    para:BTO02_30340 [6.2.1.3])     => [3.1.2.-]
    (para:BTO02_19585 [6.2.1.1],    para:BTO02_13220 [6.2.1.3])     => [3.1.2.-]
    (para:BTO02_19585 [6.2.1.1],    para:BTO02_18380 [6.2.1.3])     => [3.1.2.-]
    (para:BTO02_19585 [6.2.1.1],    para:BTO02_30340 [6.2.1.3])     => [3.1.2.-]
    (para:BTO02_31640 [6.2.1.1],    para:BTO02_13220 [6.2.1.3])     => [3.1.2.-]
    (para:BTO02_31640 [6.2.1.1],    para:BTO02_18380 [6.2.1.3])     => [3.1.2.-]
    (para:BTO02_31640 [6.2.1.1],    para:BTO02_30340 [6.2.1.3])     => [3.1.2.-]
    (parb:CJU94_11275 [6.2.1.1],    parb:CJU94_07555 [6.2.1.3])     => [3.1.2.-]
    (parb:CJU94_11275 [6.2.1.1],    parb:CJU94_16760 [6.2.1.3])     => [3.1.2.-]
    (parb:CJU94_11275 [6.2.1.1],    parb:CJU94_33365 [6.2.1.3])     => [3.1.2.-]
    (parb:CJU94_13285 [6.2.1.1],    parb:CJU94_07555 [6.2.1.3])     => [3.1.2.-]
    (parb:CJU94_13285 [6.2.1.1],    parb:CJU94_16760 [6.2.1.3])     => [3.1.2.-]
    (parb:CJU94_18040 [6.2.1.1],    parb:CJU94_07555 [6.2.1.3])     => [3.1.2.-]
    (parb:CJU94_18040 [6.2.1.1],    parb:CJU94_16760 [6.2.1.3])     => [3.1.2.-]
    (parb:CJU94_23590 [6.2.1.1],    parb:CJU94_07555 [6.2.1.3])     => [3.1.2.-]
    (parb:CJU94_23590 [6.2.1.1],    parb:CJU94_16760 [6.2.1.3])     => [3.1.2.-]
    (parb:CJU94_23590 [6.2.1.1],    parb:CJU94_33365 [6.2.1.3])     => [3.1.2.-]
    (pbh:AAW51_1716 [6.2.1.1],      pbh:AAW51_0196 [6.2.1.3])       => [3.1.2.-]
    (pbh:AAW51_1716 [6.2.1.1],      pbh:AAW51_0774 [6.2.1.3])       => [3.1.2.-]
    (pbh:AAW51_1716 [6.2.1.1],      pbh:AAW51_4756 [6.2.1.3])       => [3.1.2.-]
    (pfg:AB870_01500 [6.2.1.1],     pfg:AB870_00895 [6.2.1.3])      => [3.1.2.-]
    (pfg:AB870_01500 [6.2.1.1],     pfg:AB870_04785 [6.2.1.3])      => [3.1.2.-]
    (pfg:AB870_02135 [6.2.1.1],     pfg:AB870_00895 [6.2.1.3])      => [3.1.2.-]
    (pfg:AB870_02135 [6.2.1.1],     pfg:AB870_04785 [6.2.1.3])      => [3.1.2.-]
    (pfg:AB870_15915 [6.2.1.1],     pfg:AB870_00895 [6.2.1.3])      => [3.1.2.-]
    (pfg:AB870_15915 [6.2.1.1],     pfg:AB870_04785 [6.2.1.3])      => [3.1.2.-]
    (pfg:AB870_18295 [6.2.1.1],     pfg:AB870_00895 [6.2.1.3])      => [3.1.2.-]
    (pfg:AB870_18295 [6.2.1.1],     pfg:AB870_04785 [6.2.1.3])      => [3.1.2.-]
    (phs:C2L64_10990 [6.2.1.1],     phs:C2L64_09960 [6.2.1.3])      => [3.1.2.-]
    (phs:C2L64_10990 [6.2.1.1],     phs:C2L64_15970 [6.2.1.3])      => [3.1.2.-]
    (phs:C2L64_10990 [6.2.1.1],     phs:C2L64_40120 [6.2.1.3])      => [3.1.2.-]
    (phs:C2L64_10990 [6.2.1.1],     phs:C2L64_42020 [6.2.1.3])      => [3.1.2.-]
    (phs:C2L64_10990 [6.2.1.1],     phs:C2L64_52585 [6.2.1.3])      => [3.1.2.-]
    (phs:C2L64_11060 [6.2.1.1],     phs:C2L64_09960 [6.2.1.3])      => [3.1.2.-]
    (phs:C2L64_11060 [6.2.1.1],     phs:C2L64_15970 [6.2.1.3])      => [3.1.2.-]
    (phs:C2L64_11060 [6.2.1.1],     phs:C2L64_40120 [6.2.1.3])      => [3.1.2.-]
    (phs:C2L64_21175 [6.2.1.1],     phs:C2L64_09960 [6.2.1.3])      => [3.1.2.-]
    (phs:C2L64_21175 [6.2.1.1],     phs:C2L64_15970 [6.2.1.3])      => [3.1.2.-]
    (phs:C2L64_21175 [6.2.1.1],     phs:C2L64_40120 [6.2.1.3])      => [3.1.2.-]
    (phs:C2L64_28080 [6.2.1.1],     phs:C2L64_09960 [6.2.1.3])      => [3.1.2.-]
    (phs:C2L64_28080 [6.2.1.1],     phs:C2L64_15970 [6.2.1.3])      => [3.1.2.-]
    (phs:C2L64_28080 [6.2.1.1],     phs:C2L64_40120 [6.2.1.3])      => [3.1.2.-]
    (phs:C2L64_28080 [6.2.1.1],     phs:C2L64_42020 [6.2.1.3])      => [3.1.2.-]
    (pkt:AT984_05505 [6.2.1.1],     pkt:AT984_00025 [6.2.1.3])      => [3.1.2.-]
    (pkt:AT984_05505 [6.2.1.1],     pkt:AT984_17090 [6.2.1.3])      => [3.1.2.-]
    (pna:Pnap_2880 [6.2.1.1],       pna:Pnap_3797 [6.2.1.3])        => [3.1.2.-]
    (pne:Pnec_0756 [6.2.1.1],       pne:Pnec_0959 [6.2.1.3])        => [3.1.2.-]
    (pnr:AT302_13210 [6.2.1.1],     pnr:AT302_14335 [6.2.1.3])      => [3.1.2.-]
    (pnr:AT302_13210 [6.2.1.1],     pnr:AT302_18235 [6.2.1.3])      => [3.1.2.-]
    (pnr:AT302_16795 [6.2.1.1],     pnr:AT302_14335 [6.2.1.3])      => [3.1.2.-]
    (pnr:AT302_16795 [6.2.1.1],     pnr:AT302_18235 [6.2.1.3])      => [3.1.2.-]
    (pnr:AT302_17500 [6.2.1.1],     pnr:AT302_14335 [6.2.1.3])      => [3.1.2.-]
    (pnr:AT302_17500 [6.2.1.1],     pnr:AT302_18235 [6.2.1.3])      => [3.1.2.-]
    (pnr:AT302_26415 [6.2.1.1],     pnr:AT302_14335 [6.2.1.3])      => [3.1.2.-]
    (pnr:AT302_26415 [6.2.1.1],     pnr:AT302_18235 [6.2.1.3])      => [3.1.2.-]
    (pol:Bpro_0761 [6.2.1.1],       pol:Bpro_4543 [6.2.1.3])        => [3.1.2.-]
    (pol:Bpro_1590 [6.2.1.1],       pol:Bpro_4543 [6.2.1.3])        => [3.1.2.-]
    (pol:Bpro_2049 [6.2.1.1],       pol:Bpro_4543 [6.2.1.3])        => [3.1.2.-]
    (pol:Bpro_3358 [6.2.1.1],       pol:Bpro_4543 [6.2.1.3])        => [3.1.2.-]
    (pox:MB84_09360 [6.2.1.1],      pox:MB84_18475 [6.2.1.3])       => [3.1.2.-]
    (pox:MB84_09360 [6.2.1.1],      pox:MB84_22535 [6.2.1.3])       => [3.1.2.-]
    (pox:MB84_11965 [6.2.1.1],      pox:MB84_18475 [6.2.1.3])       => [3.1.2.-]
    (pox:MB84_11965 [6.2.1.1],      pox:MB84_22535 [6.2.1.3])       => [3.1.2.-]
    (pox:MB84_19035 [6.2.1.1],      pox:MB84_18475 [6.2.1.3])       => [3.1.2.-]
    (pox:MB84_19035 [6.2.1.1],      pox:MB84_22535 [6.2.1.3])       => [3.1.2.-]
    (pox:MB84_19680 [6.2.1.1],      pox:MB84_18475 [6.2.1.3])       => [3.1.2.-]
    (pox:MB84_19680 [6.2.1.1],      pox:MB84_22535 [6.2.1.3])       => [3.1.2.-]
    (ppk:U875_08745 [6.2.1.1],      ppk:U875_06300 [6.2.1.3])       => [3.1.2.-]
    (ppk:U875_08745 [6.2.1.1],      ppk:U875_08570 [6.2.1.3])       => [3.1.2.-]
    (ppk:U875_09770 [6.2.1.1],      ppk:U875_06300 [6.2.1.3])       => [3.1.2.-]
    (ppk:U875_16760 [6.2.1.1],      ppk:U875_06300 [6.2.1.3])       => [3.1.2.-]
    (ppk:U875_19165 [6.2.1.1],      ppk:U875_06300 [6.2.1.3])       => [3.1.2.-]
    (ppul:RO07_13145 [6.2.1.1],     ppul:RO07_01525 [6.2.1.3])      => [3.1.2.-]
    (ppul:RO07_13145 [6.2.1.1],     ppul:RO07_22430 [6.2.1.3])      => [3.1.2.-]
    (ppul:RO07_16390 [6.2.1.1],     ppul:RO07_01525 [6.2.1.3])      => [3.1.2.-]
    (ppul:RO07_16390 [6.2.1.1],     ppul:RO07_22430 [6.2.1.3])      => [3.1.2.-]
    (ppul:RO07_23175 [6.2.1.1],     ppul:RO07_01525 [6.2.1.3])      => [3.1.2.-]
    (ppul:RO07_23175 [6.2.1.1],     ppul:RO07_22430 [6.2.1.3])      => [3.1.2.-]
    (ppul:RO07_23865 [6.2.1.1],     ppul:RO07_01525 [6.2.1.3])      => [3.1.2.-]
    (ppul:RO07_23865 [6.2.1.1],     ppul:RO07_22430 [6.2.1.3])      => [3.1.2.-]
    (ppul:RO07_23865 [6.2.1.1],     ppul:RO07_24030 [6.2.1.3])      => [3.1.2.-]
    (pse:NH8B_1762 [6.2.1.1],       pse:NH8B_2855 [6.2.1.3])        => [3.1.2.-]
    (pse:NH8B_2199 [6.2.1.1],       pse:NH8B_2855 [6.2.1.3])        => [3.1.2.-]
    (pse:NH8B_2257 [6.2.1.1],       pse:NH8B_2855 [6.2.1.3])        => [3.1.2.-]
    (pse:NH8B_2997 [6.2.1.1],       pse:NH8B_2855 [6.2.1.3])        => [3.1.2.-]
    (pspu:NA29_09215 [6.2.1.1],     pspu:NA29_10135 [6.2.1.3])      => [3.1.2.-]
    (pspu:NA29_09215 [6.2.1.1],     pspu:NA29_14500 [6.2.1.3])      => [3.1.2.-]
    (pspu:NA29_13090 [6.2.1.1],     pspu:NA29_10135 [6.2.1.3])      => [3.1.2.-]
    (pspu:NA29_13090 [6.2.1.1],     pspu:NA29_12860 [6.2.1.3])      => [3.1.2.-]
    (pspu:NA29_13090 [6.2.1.1],     pspu:NA29_14500 [6.2.1.3])      => [3.1.2.-]
    (pspu:NA29_13895 [6.2.1.1],     pspu:NA29_10135 [6.2.1.3])      => [3.1.2.-]
    (pspu:NA29_13895 [6.2.1.1],     pspu:NA29_14500 [6.2.1.3])      => [3.1.2.-]
    (pspu:NA29_20785 [6.2.1.1],     pspu:NA29_10135 [6.2.1.3])      => [3.1.2.-]
    (pspu:NA29_20785 [6.2.1.1],     pspu:NA29_14500 [6.2.1.3])      => [3.1.2.-]
    (pspw:BJG93_07510 [6.2.1.1],    pspw:BJG93_06735 [6.2.1.3])     => [3.1.2.-]
    (pspw:BJG93_07510 [6.2.1.1],    pspw:BJG93_14935 [6.2.1.3])     => [3.1.2.-]
    (pspw:BJG93_25740 [6.2.1.1],    pspw:BJG93_06735 [6.2.1.3])     => [3.1.2.-]
    (pspw:BJG93_25740 [6.2.1.1],    pspw:BJG93_14935 [6.2.1.3])     => [3.1.2.-]
    (pspw:BJG93_25740 [6.2.1.1],    pspw:BJG93_34000 [6.2.1.3])     => [3.1.2.-]
    (pspw:BJG93_32490 [6.2.1.1],    pspw:BJG93_06735 [6.2.1.3])     => [3.1.2.-]
    (pspw:BJG93_32490 [6.2.1.1],    pspw:BJG93_14935 [6.2.1.3])     => [3.1.2.-]
    (pspw:BJG93_32490 [6.2.1.1],    pspw:BJG93_34000 [6.2.1.3])     => [3.1.2.-]
    (pspw:BJG93_33350 [6.2.1.1],    pspw:BJG93_06735 [6.2.1.3])     => [3.1.2.-]
    (pspw:BJG93_33350 [6.2.1.1],    pspw:BJG93_14935 [6.2.1.3])     => [3.1.2.-]
    (pspw:BJG93_33350 [6.2.1.1],    pspw:BJG93_34000 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_10135 [6.2.1.1],    pter:C2L65_09270 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_10135 [6.2.1.1],    pter:C2L65_13860 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_10135 [6.2.1.1],    pter:C2L65_37360 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_10135 [6.2.1.1],    pter:C2L65_39140 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_10135 [6.2.1.1],    pter:C2L65_44665 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_10220 [6.2.1.1],    pter:C2L65_09270 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_10220 [6.2.1.1],    pter:C2L65_13860 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_10220 [6.2.1.1],    pter:C2L65_37360 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_10220 [6.2.1.1],    pter:C2L65_44665 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_20430 [6.2.1.1],    pter:C2L65_09270 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_20430 [6.2.1.1],    pter:C2L65_13860 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_20430 [6.2.1.1],    pter:C2L65_37360 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_20430 [6.2.1.1],    pter:C2L65_39140 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_20430 [6.2.1.1],    pter:C2L65_44665 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_42195 [6.2.1.1],    pter:C2L65_09270 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_42195 [6.2.1.1],    pter:C2L65_13860 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_42195 [6.2.1.1],    pter:C2L65_37360 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_42195 [6.2.1.1],    pter:C2L65_44665 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_44135 [6.2.1.1],    pter:C2L65_09270 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_44135 [6.2.1.1],    pter:C2L65_13860 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_44135 [6.2.1.1],    pter:C2L65_37360 [6.2.1.3])     => [3.1.2.-]
    (pter:C2L65_44135 [6.2.1.1],    pter:C2L65_44665 [6.2.1.3])     => [3.1.2.-]
    (ptx:ABW99_00335 [6.2.1.1],     ptx:ABW99_20595 [6.2.1.3])      => [3.1.2.-]
    (ptx:ABW99_07275 [6.2.1.1],     ptx:ABW99_20595 [6.2.1.3])      => [3.1.2.-]
    (ptx:ABW99_09370 [6.2.1.1],     ptx:ABW99_20595 [6.2.1.3])      => [3.1.2.-]
    (ptx:ABW99_11010 [6.2.1.1],     ptx:ABW99_20595 [6.2.1.3])      => [3.1.2.-]
    (ptx:ABW99_13945 [6.2.1.1],     ptx:ABW99_20595 [6.2.1.3])      => [3.1.2.-]
    (put:PT7_0129 [6.2.1.1],        put:PT7_2583 [6.2.1.3])         => [3.1.2.-]
    (put:PT7_0129 [6.2.1.1],        put:PT7_2885 [6.2.1.3])         => [3.1.2.-]
    (put:PT7_1650 [6.2.1.1],        put:PT7_2583 [6.2.1.3])         => [3.1.2.-]
    (put:PT7_1665 [6.2.1.1],        put:PT7_2885 [6.2.1.3])         => [3.1.2.-]
    (pve:UC34_04915 [6.2.1.1],      pve:UC34_13920 [6.2.1.3])       => [3.1.2.-]
    (pve:UC34_04915 [6.2.1.1],      pve:UC34_17755 [6.2.1.3])       => [3.1.2.-]
    (pve:UC34_07590 [6.2.1.1],      pve:UC34_13920 [6.2.1.3])       => [3.1.2.-]
    (pve:UC34_07590 [6.2.1.1],      pve:UC34_17755 [6.2.1.3])       => [3.1.2.-]
    (pve:UC34_14590 [6.2.1.1],      pve:UC34_13920 [6.2.1.3])       => [3.1.2.-]
    (pve:UC34_14590 [6.2.1.1],      pve:UC34_17755 [6.2.1.3])       => [3.1.2.-]
    (pve:UC34_15325 [6.2.1.1],      pve:UC34_13920 [6.2.1.3])       => [3.1.2.-]
    (pve:UC34_15325 [6.2.1.1],      pve:UC34_15475 [6.2.1.3])       => [3.1.2.-]
    (pve:UC34_15325 [6.2.1.1],      pve:UC34_17755 [6.2.1.3])       => [3.1.2.-]
    (rac:RA876_06960 [6.2.1.1],     rac:RA876_14920 [6.2.1.3])      => [3.1.2.-]
    (rac:RA876_06960 [6.2.1.1],     rac:RA876_17480 [6.2.1.3])      => [3.1.2.-]
    (rbn:RBXJA2T_05853 [6.2.1.1],   rbn:RBXJA2T_09037 [6.2.1.3])    => [3.1.2.-]
    (rbn:RBXJA2T_05853 [6.2.1.1],   rbn:RBXJA2T_13294 [6.2.1.3])    => [3.1.2.-]
    (rbn:RBXJA2T_05853 [6.2.1.1],   rbn:RBXJA2T_17162 [6.2.1.3])    => [3.1.2.-]
    (rbn:RBXJA2T_05903 [6.2.1.1],   rbn:RBXJA2T_09037 [6.2.1.3])    => [3.1.2.-]
    (rbn:RBXJA2T_05903 [6.2.1.1],   rbn:RBXJA2T_13294 [6.2.1.3])    => [3.1.2.-]
    (rbu:PG1C_06520 [6.2.1.1],      rbu:PG1C_05420 [6.2.1.3])       => [3.1.2.-]
    (rdp:RD2015_1620 [6.2.1.1],     rdp:RD2015_4432 [6.2.1.3])      => [3.1.2.-]
    (rdp:RD2015_1620 [6.2.1.1],     rdp:RD2015_4649 [6.2.1.3])      => [3.1.2.-]
    (rdp:RD2015_1980 [6.2.1.1],     rdp:RD2015_4432 [6.2.1.3])      => [3.1.2.-]
    (rdp:RD2015_1980 [6.2.1.1],     rdp:RD2015_4649 [6.2.1.3])      => [3.1.2.-]
    (reh:H16_A1197 [6.2.1.1],       reh:H16_A1295 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A1197 [6.2.1.1],       reh:H16_A2150 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A1197 [6.2.1.1],       reh:H16_A2748 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A1197 [6.2.1.1],       reh:H16_A2947 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A1197 [6.2.1.1],       reh:H16_A3288 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A1197 [6.2.1.1],       reh:H16_A3351 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A1197 [6.2.1.1],       reh:H16_B0753 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A1197 [6.2.1.1],       reh:H16_B1239 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A1197 [6.2.1.1],       reh:H16_B1736 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A1197 [6.2.1.1],       reh:PHG399 [6.2.1.3])           => [3.1.2.-]
    (reh:H16_A1616 [6.2.1.1],       reh:H16_A2748 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A1616 [6.2.1.1],       reh:H16_A2947 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A1616 [6.2.1.1],       reh:H16_A3288 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A1616 [6.2.1.1],       reh:H16_B1239 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A2525 [6.2.1.1],       reh:H16_A1295 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A2525 [6.2.1.1],       reh:H16_A2150 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A2525 [6.2.1.1],       reh:H16_A2748 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A2525 [6.2.1.1],       reh:H16_A2947 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A2525 [6.2.1.1],       reh:H16_A3288 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A2525 [6.2.1.1],       reh:H16_A3351 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A2525 [6.2.1.1],       reh:H16_B0753 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A2525 [6.2.1.1],       reh:H16_B1239 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_A2525 [6.2.1.1],       reh:PHG399 [6.2.1.3])           => [3.1.2.-]
    (reh:H16_B0834 [6.2.1.1],       reh:H16_A1295 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_B0834 [6.2.1.1],       reh:H16_A2150 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_B0834 [6.2.1.1],       reh:H16_A2748 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_B0834 [6.2.1.1],       reh:H16_A2947 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_B0834 [6.2.1.1],       reh:H16_A3288 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_B0834 [6.2.1.1],       reh:H16_A3351 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_B0834 [6.2.1.1],       reh:H16_B1239 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_B0834 [6.2.1.1],       reh:PHG399 [6.2.1.3])           => [3.1.2.-]
    (reh:H16_B1102 [6.2.1.1],       reh:H16_A1295 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_B1102 [6.2.1.1],       reh:H16_A2150 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_B1102 [6.2.1.1],       reh:H16_A2748 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_B1102 [6.2.1.1],       reh:H16_A2947 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_B1102 [6.2.1.1],       reh:H16_A3288 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_B1102 [6.2.1.1],       reh:H16_A3351 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_B1102 [6.2.1.1],       reh:H16_B0753 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_B1102 [6.2.1.1],       reh:H16_B1239 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_B1102 [6.2.1.1],       reh:H16_B1736 [6.2.1.3])        => [3.1.2.-]
    (reh:H16_B1102 [6.2.1.1],       reh:PHG399 [6.2.1.3])           => [3.1.2.-]
    (reu:Reut_A1097 [6.2.1.1],      reu:Reut_A2994 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1097 [6.2.1.1],      reu:Reut_A3057 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1097 [6.2.1.1],      reu:Reut_B3549 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1097 [6.2.1.1],      reu:Reut_B3565 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1097 [6.2.1.1],      reu:Reut_B3605 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1097 [6.2.1.1],      reu:Reut_B4042 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1097 [6.2.1.1],      reu:Reut_B4155 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1097 [6.2.1.1],      reu:Reut_B4758 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1097 [6.2.1.1],      reu:Reut_C6056 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1097 [6.2.1.1],      reu:Reut_C6065 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1097 [6.2.1.1],      reu:Reut_C6185 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1097 [6.2.1.1],      reu:Reut_D6480 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1821 [6.2.1.1],      reu:Reut_A2994 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1821 [6.2.1.1],      reu:Reut_A3057 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1821 [6.2.1.1],      reu:Reut_B3549 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1821 [6.2.1.1],      reu:Reut_B3565 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1821 [6.2.1.1],      reu:Reut_B4042 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1821 [6.2.1.1],      reu:Reut_B4155 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1821 [6.2.1.1],      reu:Reut_B4758 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1821 [6.2.1.1],      reu:Reut_C6065 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1821 [6.2.1.1],      reu:Reut_C6185 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A1821 [6.2.1.1],      reu:Reut_D6480 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A2229 [6.2.1.1],      reu:Reut_A2994 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A2229 [6.2.1.1],      reu:Reut_A3057 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A2229 [6.2.1.1],      reu:Reut_B3549 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A2229 [6.2.1.1],      reu:Reut_B3565 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A2229 [6.2.1.1],      reu:Reut_B4042 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A2229 [6.2.1.1],      reu:Reut_B4155 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A2229 [6.2.1.1],      reu:Reut_B4758 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A2229 [6.2.1.1],      reu:Reut_C6056 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A2229 [6.2.1.1],      reu:Reut_C6065 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A2229 [6.2.1.1],      reu:Reut_C6185 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_A2229 [6.2.1.1],      reu:Reut_D6480 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_B4371 [6.2.1.1],      reu:Reut_A2994 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_B4371 [6.2.1.1],      reu:Reut_A3057 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_B4371 [6.2.1.1],      reu:Reut_B3549 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_B4371 [6.2.1.1],      reu:Reut_B3565 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_B4371 [6.2.1.1],      reu:Reut_B3605 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_B4371 [6.2.1.1],      reu:Reut_B4042 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_B4371 [6.2.1.1],      reu:Reut_B4155 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_B4371 [6.2.1.1],      reu:Reut_B4758 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_B4371 [6.2.1.1],      reu:Reut_C6056 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_B4371 [6.2.1.1],      reu:Reut_C6065 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_B4371 [6.2.1.1],      reu:Reut_C6185 [6.2.1.3])       => [3.1.2.-]
    (reu:Reut_B4371 [6.2.1.1],      reu:Reut_D6480 [6.2.1.3])       => [3.1.2.-]
    (rfr:Rfer_0388 [6.2.1.1],       rfr:Rfer_2283 [6.2.1.3])        => [3.1.2.-]
    (rfr:Rfer_0388 [6.2.1.1],       rfr:Rfer_3503 [6.2.1.3])        => [3.1.2.-]
    (rfr:Rfer_0388 [6.2.1.1],       rfr:Rfer_3752 [6.2.1.3])        => [3.1.2.-]
    (rfr:Rfer_0388 [6.2.1.1],       rfr:Rfer_3775 [6.2.1.3])        => [3.1.2.-]
    (rfr:Rfer_0388 [6.2.1.1],       rfr:Rfer_3898 [6.2.1.3])        => [3.1.2.-]
    (rfr:Rfer_2581 [6.2.1.1],       rfr:Rfer_2283 [6.2.1.3])        => [3.1.2.-]
    (rfr:Rfer_2581 [6.2.1.1],       rfr:Rfer_3752 [6.2.1.3])        => [3.1.2.-]
    (rfr:Rfer_2581 [6.2.1.1],       rfr:Rfer_3775 [6.2.1.3])        => [3.1.2.-]
    (rfr:Rfer_2581 [6.2.1.1],       rfr:Rfer_3898 [6.2.1.3])        => [3.1.2.-]
    (rfr:Rfer_2698 [6.2.1.1],       rfr:Rfer_2283 [6.2.1.3])        => [3.1.2.-]
    (rfr:Rfer_2698 [6.2.1.1],       rfr:Rfer_3752 [6.2.1.3])        => [3.1.2.-]
    (rfr:Rfer_2698 [6.2.1.1],       rfr:Rfer_3775 [6.2.1.3])        => [3.1.2.-]
    (rfr:Rfer_2698 [6.2.1.1],       rfr:Rfer_3898 [6.2.1.3])        => [3.1.2.-]
    (rge:RGE_18530 [6.2.1.1],       rge:RGE_06000 [6.2.1.3])        => [3.1.2.-]
    (rge:RGE_18530 [6.2.1.1],       rge:RGE_07750 [6.2.1.3])        => [3.1.2.-]
    (rge:RGE_18530 [6.2.1.1],       rge:RGE_46110 [6.2.1.3])        => [3.1.2.-]
    (rge:RGE_18640 [6.2.1.1],       rge:RGE_06000 [6.2.1.3])        => [3.1.2.-]
    (rge:RGE_18640 [6.2.1.1],       rge:RGE_46110 [6.2.1.3])        => [3.1.2.-]
    (rgu:A4W93_12320 [6.2.1.1],     rgu:A4W93_02100 [6.2.1.3])      => [3.1.2.-]
    (rgu:A4W93_12320 [6.2.1.1],     rgu:A4W93_06455 [6.2.1.3])      => [3.1.2.-]
    (rgu:A4W93_12320 [6.2.1.1],     rgu:A4W93_06910 [6.2.1.3])      => [3.1.2.-]
    (rgu:A4W93_12320 [6.2.1.1],     rgu:A4W93_17050 [6.2.1.3])      => [3.1.2.-]
    (rgu:A4W93_12320 [6.2.1.1],     rgu:A4W93_25930 [6.2.1.3])      => [3.1.2.-]
    (rhy:RD110_11125 [6.2.1.1],     rhy:RD110_25205 [6.2.1.3])      => [3.1.2.-]
    (rin:ACS15_1222 [6.2.1.1],      rin:ACS15_0549 [6.2.1.3])       => [3.1.2.-]
    (rin:ACS15_1222 [6.2.1.1],      rin:ACS15_3158 [6.2.1.3])       => [3.1.2.-]
    (rin:ACS15_1222 [6.2.1.1],      rin:ACS15_3830 [6.2.1.3])       => [3.1.2.-]
    (rin:ACS15_1222 [6.2.1.1],      rin:ACS15_5721 [6.2.1.3])       => [3.1.2.-]
    (rin:ACS15_4031 [6.2.1.1],      rin:ACS15_0549 [6.2.1.3])       => [3.1.2.-]
    (rin:ACS15_4031 [6.2.1.1],      rin:ACS15_3158 [6.2.1.3])       => [3.1.2.-]
    (rin:ACS15_4031 [6.2.1.1],      rin:ACS15_3830 [6.2.1.3])       => [3.1.2.-]
    (rin:ACS15_4031 [6.2.1.1],      rin:ACS15_5721 [6.2.1.3])       => [3.1.2.-]
    (rin:ACS15_5715 [6.2.1.1],      rin:ACS15_0549 [6.2.1.3])       => [3.1.2.-]
    (rin:ACS15_5715 [6.2.1.1],      rin:ACS15_3158 [6.2.1.3])       => [3.1.2.-]
    (rin:ACS15_5715 [6.2.1.1],      rin:ACS15_3830 [6.2.1.3])       => [3.1.2.-]
    (rin:ACS15_5715 [6.2.1.1],      rin:ACS15_5721 [6.2.1.3])       => [3.1.2.-]
    (rme:Rmet_1061 [6.2.1.1],       rme:Rmet_2525 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_1061 [6.2.1.1],       rme:Rmet_3148 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_1061 [6.2.1.1],       rme:Rmet_3215 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_1061 [6.2.1.1],       rme:Rmet_4068 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_1061 [6.2.1.1],       rme:Rmet_4454 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_1061 [6.2.1.1],       rme:Rmet_4502 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_1061 [6.2.1.1],       rme:Rmet_4746 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_1061 [6.2.1.1],       rme:Rmet_5140 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_1061 [6.2.1.1],       rme:Rmet_5528 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_1061 [6.2.1.1],       rme:Rmet_5827 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_2270 [6.2.1.1],       rme:Rmet_2525 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_2270 [6.2.1.1],       rme:Rmet_3148 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_2270 [6.2.1.1],       rme:Rmet_3215 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_2270 [6.2.1.1],       rme:Rmet_4068 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_2270 [6.2.1.1],       rme:Rmet_4454 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_2270 [6.2.1.1],       rme:Rmet_4502 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_2270 [6.2.1.1],       rme:Rmet_4746 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_2270 [6.2.1.1],       rme:Rmet_5140 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_2270 [6.2.1.1],       rme:Rmet_5528 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_2270 [6.2.1.1],       rme:Rmet_5827 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_5743 [6.2.1.1],       rme:Rmet_2525 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_5743 [6.2.1.1],       rme:Rmet_3148 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_5743 [6.2.1.1],       rme:Rmet_3215 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_5743 [6.2.1.1],       rme:Rmet_4068 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_5743 [6.2.1.1],       rme:Rmet_4454 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_5743 [6.2.1.1],       rme:Rmet_4502 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_5743 [6.2.1.1],       rme:Rmet_4746 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_5743 [6.2.1.1],       rme:Rmet_5140 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_5743 [6.2.1.1],       rme:Rmet_5528 [6.2.1.3])        => [3.1.2.-]
    (rme:Rmet_5743 [6.2.1.1],       rme:Rmet_5827 [6.2.1.3])        => [3.1.2.-]
    (rmn:TK49_13410 [6.2.1.1],      rmn:TK49_03220 [6.2.1.3])       => [3.1.2.-]
    (rmn:TK49_13410 [6.2.1.1],      rmn:TK49_05770 [6.2.1.3])       => [3.1.2.-]
    (rmn:TK49_13410 [6.2.1.1],      rmn:TK49_06095 [6.2.1.3])       => [3.1.2.-]
    (rmn:TK49_13410 [6.2.1.1],      rmn:TK49_20335 [6.2.1.3])       => [3.1.2.-]
    (rmn:TK49_20305 [6.2.1.1],      rmn:TK49_03220 [6.2.1.3])       => [3.1.2.-]
    (rmn:TK49_20305 [6.2.1.1],      rmn:TK49_05770 [6.2.1.3])       => [3.1.2.-]
    (rmn:TK49_20305 [6.2.1.1],      rmn:TK49_06095 [6.2.1.3])       => [3.1.2.-]
    (rmn:TK49_20305 [6.2.1.1],      rmn:TK49_20335 [6.2.1.3])       => [3.1.2.-]
    (rmn:TK49_21165 [6.2.1.1],      rmn:TK49_03220 [6.2.1.3])       => [3.1.2.-]
    (rmn:TK49_21165 [6.2.1.1],      rmn:TK49_05770 [6.2.1.3])       => [3.1.2.-]
    (rmn:TK49_21165 [6.2.1.1],      rmn:TK49_06095 [6.2.1.3])       => [3.1.2.-]
    (rmn:TK49_21165 [6.2.1.1],      rmn:TK49_20335 [6.2.1.3])       => [3.1.2.-]
    (rpi:Rpic_2099 [6.2.1.1],       rpi:Rpic_0109 [6.2.1.3])        => [3.1.2.-]
    (rpi:Rpic_2099 [6.2.1.1],       rpi:Rpic_0413 [6.2.1.3])        => [3.1.2.-]
    (rpi:Rpic_2099 [6.2.1.1],       rpi:Rpic_3104 [6.2.1.3])        => [3.1.2.-]
    (rpi:Rpic_2099 [6.2.1.1],       rpi:Rpic_3685 [6.2.1.3])        => [3.1.2.-]
    (rpi:Rpic_2099 [6.2.1.1],       rpi:Rpic_3980 [6.2.1.3])        => [3.1.2.-]
    (rpi:Rpic_3974 [6.2.1.1],       rpi:Rpic_0109 [6.2.1.3])        => [3.1.2.-]
    (rpi:Rpic_3974 [6.2.1.1],       rpi:Rpic_0413 [6.2.1.3])        => [3.1.2.-]
    (rpi:Rpic_3974 [6.2.1.1],       rpi:Rpic_3104 [6.2.1.3])        => [3.1.2.-]
    (rpi:Rpic_3974 [6.2.1.1],       rpi:Rpic_3685 [6.2.1.3])        => [3.1.2.-]
    (rpi:Rpic_3974 [6.2.1.1],       rpi:Rpic_3980 [6.2.1.3])        => [3.1.2.-]
    (rpi:Rpic_4143 [6.2.1.1],       rpi:Rpic_0109 [6.2.1.3])        => [3.1.2.-]
    (rpi:Rpic_4143 [6.2.1.1],       rpi:Rpic_0413 [6.2.1.3])        => [3.1.2.-]
    (rpi:Rpic_4143 [6.2.1.1],       rpi:Rpic_3104 [6.2.1.3])        => [3.1.2.-]
    (rpi:Rpic_4143 [6.2.1.1],       rpi:Rpic_3685 [6.2.1.3])        => [3.1.2.-]
    (rpi:Rpic_4143 [6.2.1.1],       rpi:Rpic_3980 [6.2.1.3])        => [3.1.2.-]
    (rpi:Rpic_4644 [6.2.1.1],       rpi:Rpic_0109 [6.2.1.3])        => [3.1.2.-]
    (rpi:Rpic_4644 [6.2.1.1],       rpi:Rpic_0413 [6.2.1.3])        => [3.1.2.-]
    (rpi:Rpic_4644 [6.2.1.1],       rpi:Rpic_3104 [6.2.1.3])        => [3.1.2.-]
    (rpi:Rpic_4644 [6.2.1.1],       rpi:Rpic_3685 [6.2.1.3])        => [3.1.2.-]
    (rpi:Rpic_4644 [6.2.1.1],       rpi:Rpic_3980 [6.2.1.3])        => [3.1.2.-]
    (rsb:RS694_05140 [6.2.1.1],     rsb:RS694_14185 [6.2.1.3])      => [3.1.2.-]
    (rsb:RS694_05140 [6.2.1.1],     rsb:RS694_18870 [6.2.1.3])      => [3.1.2.-]
    (rsb:RS694_07695 [6.2.1.1],     rsb:RS694_18870 [6.2.1.3])      => [3.1.2.-]
    (rso:RSc1952 [6.2.1.1],         rso:RSc0064 [6.2.1.3])          => [3.1.2.-]
    (rso:RSc1952 [6.2.1.1],         rso:RSc2857 [6.2.1.3])          => [3.1.2.-]
    (rso:RSp0651 [6.2.1.1],         rso:RSc0064 [6.2.1.3])          => [3.1.2.-]
    (rso:RSp0651 [6.2.1.1],         rso:RSc2857 [6.2.1.3])          => [3.1.2.-]
    (rso:RSp1265 [6.2.1.1],         rso:RSc0064 [6.2.1.3])          => [3.1.2.-]
    (rso:RSp1265 [6.2.1.1],         rso:RSc2857 [6.2.1.3])          => [3.1.2.-]
    (rta:Rta_10430 [6.2.1.1],       rta:Rta_02130 [6.2.1.3])        => [3.1.2.-]
    (rta:Rta_15940 [6.2.1.1],       rta:Rta_02130 [6.2.1.3])        => [3.1.2.-]
    (shd:SUTH_02307 [6.2.1.1],      shd:SUTH_00250 [6.2.1.3])       => [3.1.2.-]
    (shd:SUTH_02307 [6.2.1.1],      shd:SUTH_00507 [6.2.1.3])       => [3.1.2.-]
    (shd:SUTH_02307 [6.2.1.1],      shd:SUTH_02599 [6.2.1.3])       => [3.1.2.-]
    (shd:SUTH_02929 [6.2.1.1],      shd:SUTH_00250 [6.2.1.3])       => [3.1.2.-]
    (shd:SUTH_02929 [6.2.1.1],      shd:SUTH_00507 [6.2.1.3])       => [3.1.2.-]
    (shd:SUTH_02929 [6.2.1.1],      shd:SUTH_00625 [6.2.1.3])       => [3.1.2.-]
    (shd:SUTH_02929 [6.2.1.1],      shd:SUTH_02599 [6.2.1.3])       => [3.1.2.-]
    (shd:SUTH_02977 [6.2.1.1],      shd:SUTH_00096 [6.2.1.3])       => [3.1.2.-]
    (shd:SUTH_02977 [6.2.1.1],      shd:SUTH_00250 [6.2.1.3])       => [3.1.2.-]
    (shd:SUTH_02977 [6.2.1.1],      shd:SUTH_00507 [6.2.1.3])       => [3.1.2.-]
    (shd:SUTH_02977 [6.2.1.1],      shd:SUTH_02599 [6.2.1.3])       => [3.1.2.-]
    (sulf:CAP31_04890 [6.2.1.1],    sulf:CAP31_12695 [6.2.1.3])     => [3.1.2.-]
    (tcl:Tchl_1007 [6.2.1.1],       tcl:Tchl_3371 [6.2.1.3])        => [3.1.2.-]
    (tcl:Tchl_2541 [6.2.1.1],       tcl:Tchl_3371 [6.2.1.3])        => [3.1.2.-]
    (thi:THI_1197 [6.2.1.1],        thi:THI_2917 [6.2.1.3])         => [3.1.2.-]
    (thi:THI_2397 [6.2.1.1],        thi:THI_2917 [6.2.1.3])         => [3.1.2.-]
    (thk:CCZ27_01710 [6.2.1.1],     thk:CCZ27_04350 [6.2.1.3])      => [3.1.2.-]
    (thk:CCZ27_11050 [6.2.1.1],     thk:CCZ27_04350 [6.2.1.3])      => [3.1.2.-]
    (thu:AC731_003990 [6.2.1.1],    thu:AC731_000675 [6.2.1.3])     => [3.1.2.-]
    (thu:AC731_018930 [6.2.1.1],    thu:AC731_000675 [6.2.1.3])     => [3.1.2.-]
    (thu:AC731_019020 [6.2.1.1],    thu:AC731_000675 [6.2.1.3])     => [3.1.2.-]
    (tin:Tint_0943 [6.2.1.1],       tin:Tint_2518 [6.2.1.3])        => [3.1.2.-]
    (tin:Tint_2070 [6.2.1.1],       tin:Tint_2518 [6.2.1.3])        => [3.1.2.-]
    (tmz:Tmz1t_1162 [6.2.1.1],      tmz:Tmz1t_3077 [6.2.1.3])       => [3.1.2.-]
    (tmz:Tmz1t_1412 [6.2.1.1],      tmz:Tmz1t_3077 [6.2.1.3])       => [3.1.2.-]
    (tmz:Tmz1t_2652 [6.2.1.1],      tmz:Tmz1t_3077 [6.2.1.3])       => [3.1.2.-]
    (tmz:Tmz1t_3467 [6.2.1.1],      tmz:Tmz1t_3077 [6.2.1.3])       => [3.1.2.-]
    (vaa:AX767_18465 [6.2.1.1],     vaa:AX767_07095 [6.2.1.3])      => [3.1.2.-]
    (vaa:AX767_18465 [6.2.1.1],     vaa:AX767_08370 [6.2.1.3])      => [3.1.2.-]
    (vaa:AX767_18465 [6.2.1.1],     vaa:AX767_11705 [6.2.1.3])      => [3.1.2.-]
    (vaa:AX767_18465 [6.2.1.1],     vaa:AX767_11750 [6.2.1.3])      => [3.1.2.-]
    (vaa:AX767_18465 [6.2.1.1],     vaa:AX767_17410 [6.2.1.3])      => [3.1.2.-]
    (vaa:AX767_18465 [6.2.1.1],     vaa:AX767_17515 [6.2.1.3])      => [3.1.2.-]
    (vaa:AX767_18465 [6.2.1.1],     vaa:AX767_19120 [6.2.1.3])      => [3.1.2.-]
    (vaa:AX767_18465 [6.2.1.1],     vaa:AX767_20040 [6.2.1.3])      => [3.1.2.-]
    (vap:Vapar_2526 [6.2.1.1],      vap:Vapar_0394 [6.2.1.3])       => [3.1.2.-]
    (vap:Vapar_2526 [6.2.1.1],      vap:Vapar_4793 [6.2.1.3])       => [3.1.2.-]
    (vap:Vapar_2526 [6.2.1.1],      vap:Vapar_5352 [6.2.1.3])       => [3.1.2.-]
    (vap:Vapar_5367 [6.2.1.1],      vap:Vapar_0394 [6.2.1.3])       => [3.1.2.-]
    (vap:Vapar_5367 [6.2.1.1],      vap:Vapar_4793 [6.2.1.3])       => [3.1.2.-]
    (vap:Vapar_5367 [6.2.1.1],      vap:Vapar_5352 [6.2.1.3])       => [3.1.2.-]
    (vap:Vapar_6251 [6.2.1.1],      vap:Vapar_0394 [6.2.1.3])       => [3.1.2.-]
    (vap:Vapar_6251 [6.2.1.1],      vap:Vapar_4793 [6.2.1.3])       => [3.1.2.-]
    (vap:Vapar_6251 [6.2.1.1],      vap:Vapar_5352 [6.2.1.3])       => [3.1.2.-]
    (vbo:CKY39_15680 [6.2.1.1],     vbo:CKY39_02235 [6.2.1.3])      => [3.1.2.-]
    (vbo:CKY39_15680 [6.2.1.1],     vbo:CKY39_02280 [6.2.1.3])      => [3.1.2.-]
    (vbo:CKY39_15680 [6.2.1.1],     vbo:CKY39_27080 [6.2.1.3])      => [3.1.2.-]
    (vbo:CKY39_15680 [6.2.1.1],     vbo:CKY39_29675 [6.2.1.3])      => [3.1.2.-]
    (vei:Veis_3218 [6.2.1.1],       vei:Veis_1683 [6.2.1.3])        => [3.1.2.-]
    (vei:Veis_3218 [6.2.1.1],       vei:Veis_2551 [6.2.1.3])        => [3.1.2.-]
    (vei:Veis_3218 [6.2.1.1],       vei:Veis_3437 [6.2.1.3])        => [3.1.2.-]
    (vei:Veis_3218 [6.2.1.1],       vei:Veis_3839 [6.2.1.3])        => [3.1.2.-]
    (vei:Veis_3218 [6.2.1.1],       vei:Veis_3874 [6.2.1.3])        => [3.1.2.-]
    (vff:VITFI_CDS2558 [6.2.1.1],   vff:VITFI_CDS1234 [6.2.1.3])    => [3.1.2.-]
    (vei:Veis_4861 [2.4.2.-],       vei:Veis_4553 [5.1.1.7])        => [4.1.3.-]
    (zin:ZICARI_050 [2.7.7.6],      zin:ZICARI_026 [6.1.1.20])      => [6.3.4.2]
    (zin:ZICARI_050 [2.7.7.6],      zin:ZICARI_041 [2.7.7.7])       => [6.3.4.2]
    (zin:ZICARI_050 [2.7.7.6],      zin:ZICARI_071 [6.1.1.10])      => [6.3.4.2]
    (zin:ZICARI_050 [2.7.7.6],      zin:ZICARI_127 [6.1.1.5])       => [6.3.4.2]
    (zin:ZICARI_050 [2.7.7.6],      zin:ZICARI_151 [6.1.1.4])       => [6.3.4.2]
    (zin:ZICARI_050 [2.7.7.6],      zin:ZICARI_177 [6.1.1.15])      => [6.3.4.2]
    (zin:ZICARI_050 [2.7.7.6],      zin:ZICARI_189 [6.1.1.14])      => [6.3.4.2]
    (zin:ZICARI_050 [2.7.7.6],      zin:ZICARI_193 [4.1.99.17])     => [6.3.4.2]
    (zin:ZICARI_050 [2.7.7.6],      zin:ZICARI_194 [6.1.1.9])       => [6.3.4.2]
    (zin:ZICARI_052 [2.7.7.6],      zin:ZICARI_026 [6.1.1.20])      => [6.3.4.2]
    (zin:ZICARI_052 [2.7.7.6],      zin:ZICARI_189 [6.1.1.14])      => [6.3.4.2]
    (zin:ZICARI_163 [1.2.4.2],      zin:ZICARI_050 [2.7.7.6])       => [6.3.4.2]

Conclusion
----------
Alphaproteobacteria and Betaproteobacteria are very comparable in the percentage of neofunctionalisations contributing to robustness.
In total numbers, however, Betaproteobacteria have more neofunctionalisations. But they also have the larger core metabolism.
"""

from FEV_KEGG.KEGG.File import cache
from FEV_KEGG.Evolution.Clade import Clade
from FEV_KEGG.Robustness.Topology.Redundancy import RedundancyType, Redundancy, RedundancyContribution
from FEV_KEGG.Util.Util import prettySortDict
from FEV_KEGG.Statistics import Percent

@cache(folder_path='experiments', file_name='alphaproteobacteria_clade')
def getCladeA():
    clade = Clade('Alphaproteobacteria')
    # pre-fetch collective metabolism into memory
    clade.collectiveMetabolism(excludeMultifunctionalEnzymes=True)
    # pre-fetch collective enzyme metabolism into memory
    clade.collectiveMetabolismEnzymes(excludeMultifunctionalEnzymes=True)
    return clade

@cache(folder_path='experiments', file_name='betaproteobacteria_clade')
def getCladeB():
    clade = Clade('Betaproteobacteria')
    # pre-fetch collective metabolism into memory
    clade.collectiveMetabolism(excludeMultifunctionalEnzymes=True)
    # pre-fetch collective enzyme metabolism into memory
    clade.collectiveMetabolismEnzymes(excludeMultifunctionalEnzymes=True)
    return clade

if __name__ == '__main__':

    output = ['']

    #- get clades
    cladeA = getCladeA()
    cladeB = getCladeB()
    
    majorityPercentageCoreMetabolism = 80
    majorityPercentageNeofunctionalisation = 0
    redundancyType = RedundancyType.ROBUSTNESS
    
    output.append( 'core metabolism majority: ' + str(majorityPercentageCoreMetabolism) + '%' )
    output.append( 'neofunctionalisation majority: ' + str(majorityPercentageNeofunctionalisation) + '% (this means that gene duplication within a single organism is enough)' )
    output.append( 'type of redundancy: ' + str(redundancyType.name) )
    output.append('')
    
    #- REPEAT for each clade
    for clade in (cladeA, cladeB):
    
        output.append(', '.join(clade.ncbiNames) + ':')
        output.append('')
        
        #-     print size of each core metabolism and "neofunctionalised" ECs, including their contribution to redundancy
        cladeAEcGraph = clade.coreMetabolism(majorityPercentageCoreMetabolism)
        cladeAEcCount = len(cladeAEcGraph.getECs())
        output.append( 'core metabolism ECs: ' + str(cladeAEcCount) )
        output.append('')
        
        neofunctionalisedMetabolismSet = clade.neofunctionalisedECs(majorityPercentageCoreMetabolism, majorityPercentageNeofunctionalisation).getECs()
        neofunctionalisationsForFunctionChange = clade.neofunctionalisationsForFunctionChange(majorityPercentageCoreMetabolism, majorityPercentageNeofunctionalisation)
        
        output.append( '"neofunctionalised" ECs: ' + str(len(neofunctionalisedMetabolismSet)) + ' (' + str(Percent.getPercentStringShort(len(neofunctionalisedMetabolismSet), cladeAEcCount, 0)) + '%)' )
        for ec in sorted(neofunctionalisedMetabolismSet):
            output.append( str(ec) )
        output.append('')
        
        redundancy = Redundancy(cladeAEcGraph, onlyType = redundancyType)
        redundancyContribution = RedundancyContribution(redundancy, neofunctionalisedMetabolismSet)
        
        contributedECsForContributingNeofunctionalisedEC = redundancyContribution.getContributedKeysForSpecial(redundancyType)
        contributingNeofunctionalisedECs = set(contributedECsForContributingNeofunctionalisedEC.keys())
        
        output.append( '"neofunctionalised" ECs contributing to redundancy: ' + str(len(contributingNeofunctionalisedECs)) + ' (' + str(Percent.getPercentStringShort(len(contributingNeofunctionalisedECs), cladeAEcCount, 0)) + '%)' )
        for neofunctionalisedEc, contributedECs in prettySortDict(contributedECsForContributingNeofunctionalisedEC, byValueFirst = False):
            output.append( str(neofunctionalisedEc) + '\t=> ' + str(contributedECs))
        output.append('')
        
        #-     print enzyme pairs of neofunctionalisations, which caused the EC to be considered "neofunctionalised", and are in return contributing to redundancy
        redundantECsForContributingNeofunctionalisation = dict()
        
        for functionChange, neofunctionalisations in neofunctionalisationsForFunctionChange.items():        
            
            if functionChange.ecA in contributingNeofunctionalisedECs or functionChange.ecB in contributingNeofunctionalisedECs: # function change contributes to redundancy
                
                for neofunctionalisation in neofunctionalisations:
                    currentSetOfContributedECs = redundantECsForContributingNeofunctionalisation.get(neofunctionalisation, None)
                    
                    if currentSetOfContributedECs is None:
                        currentSetOfContributedECs = set()
                        redundantECsForContributingNeofunctionalisation[neofunctionalisation] = currentSetOfContributedECs
                    
                    for ec in functionChange.ecPair:
                        contributedECs = contributedECsForContributingNeofunctionalisedEC.get(ec, None)
                        if contributedECs is not None:
                            currentSetOfContributedECs.update(contributedECs)
        
        neofunctionalisations = clade.neofunctionalisations(majorityPercentageCoreMetabolism)
        output.append( 'Neofunctionalisations contributing to redundancy: ' + str(len(redundantECsForContributingNeofunctionalisation)) + ' (' + str(Percent.getPercentStringShort(len(redundantECsForContributingNeofunctionalisation), len(neofunctionalisations), 0)) + '%)' )
        
        for neofunctionalisation, contributedECs in prettySortDict(redundantECsForContributingNeofunctionalisation, byValueFirst = True):
            output.append( str(neofunctionalisation) + '\t=> ' + str(contributedECs))
        
        output.append('')
        output.append('')

    
    
    for line in output:
        print( line )
